      processor 6502

;VCS equates
VSYNC   =  $00
VBLANK  =  $01
WSYNC   =  $02
NUSIZ0  =  $04
NUSIZ1  =  $05
COLUP0  =  $06
COLUP1  =  $07
COLUPF  =  $08
COLUBK  =  $09
CTRLPF  =  $0A
PF0     =  $0D
PF1     =  $0E
PF2     =  $0F
RESP0   =  $10
RESP1   =  $11
AUDC0   =  $15
AUDC1   =  $16
AUDF0   =  $17
AUDF1   =  $18
AUDV0   =  $19
AUDV1   =  $1A
GRP0    =  $1B
GRP1    =  $1C
HMP0    =  $20
HMP1    =  $21
HMOVE   =  $2A
HMCLR   =  $2B
INPT4   =  $3C
SWCHA   =  $0280
SWCHB   =  $0282
INTIM   =  $0284
TIM64T  =  $0296

;ram
OldStick          =  $80 ;status of SWCHA on previous frame
RamDots           =  $81 ;81-AA = dots, AB-AE = energizers, AF = energizer control
DifSw             =  $B0 ;status of SWCHB on previous frame
Level             =  $B4 ;bits 0-4...bits 5-7 unused
MonsterX          =  $B5 ;B5-B8, pre-HPOS
PlayerX           =  $B9 ;pre-HPOS
MonsterY          =  $BA ;BA-BD (scanline offset)
PlayerY           =  $BE ;(scanline offset)
EnergizerTime     =  $BF ;lower nybble = timer. upper nybble = maze color
PrintTemp         =  $DC ;DC-E7...used as pointer to sprites in current frame
TempX             =  PrintTemp+3 ;current monster X (copy of B5-B8 used in generic routines)
TempY             =  PrintTemp+4 ;current monster Y (copy of BA-BD used in generic routines)
TempC             =  PrintTemp+5 ;current monster color(copy of ED-F0 used in generic routines)
Lives             =  $E8 ;low 3 bits = lives, upper 5 = game mode
DotCount          =  $E9 ;DEC counter, 00=no dots left
Score             =  $EA ;EA-EC...BCD
Color             =  $ED ;ED-F0...monster color/control: 00=eyes, - = vulnerable, + = lethal
Control           =  $F1
;bit 4- = board finished timer
;bit 4+ = player killed timer
;bit 5 = fruit active
;bit 6 = player slowdown this frame
;bit 7 = game inactive

PacOffset         =  $F2 ;current frame offset to GFX...corrupted in kernal
LoTimer           =  $F3 ;frame counter
Temp              =  $F4
SoundDur          =  $F5 ;sound data table pointer (low nybble), beep counter (high nybble)
MonsterDirs       =  $F6 ;2 bits per monster
HiTimer           =  $F7 ;\...shared, lower 3 bits = monster count, upper nybble = game timer
TotEatenMonsters  =  $F7 ;/           and bit 3 = intermission control
IndExit           =  $F8 ;address pointer for indirect exit point jump
IndAdr            =  $FE ;address pointer for indirect entry point jump

;options
TEST              = 0 ;When set, only need to clear 2 dots to pass boards
EQUALPT           = 0 ;When set, boards have equal point value to arcade(i.e.cherry=14,600max)
FILLDOT           = 0 ;When set, more open areas have dots (NOTE: not updated)
CHEAT             = 0 ;when set, player invulnerable to monsters

;constants
;Time              = $1A
Time              = $1A ;time spent in display kernal (bank1)

;Tim2              = $2F
Tim2              = $31 ;time spent out of display kernal (bank2)

  ORG  $1000
  RORG  $D000

;reposition routine...
GoBack:
       LDY    $1FF9   ;4
;entry point
       lda    XposTbl,y               ;4 <-PosX
       bne    GoBack                  ;2 

;flip banks
LFC4C1:
       LDA    $1FF9   ;4

       lda    Level                   ;3
       and    #$01                    ;2 
       sta    Temp                    ;3

Retrace_Wait:
       lda    INTIM                   ;4 
       bne    Retrace_Wait            ;2 
       sta    WSYNC                   ;3 
       sta    VBLANK                  ;3 
       sta    WSYNC                   ;3 
       lda    #$06                    ;2 <-Score size
       sta    $DA                     ;3 
       ldx    #$0A                    ;2 
WaitLoop10:
       dex                            ;2 
       bne    WaitLoop10              ;2 
       NOP                            ;2 
       NOP                            ;2 
       NOP                            ;2 
Display_Score_loop:
       ldy    $DA                     ;3 
       lda    (PrintTemp),y           ;5 
       sta    GRP0                    ;3 
       bit    VSYNC                   ;3 
       lda    (PrintTemp+2),y         ;5 
       sta    GRP1                    ;3 
       lda    (PrintTemp+10),y        ;5 
       tax                            ;2 
       txs                            ;2 
       lda    (PrintTemp+4),y         ;5 
       sta    $DB                     ;3 
       lda    (PrintTemp+6),y         ;5 
       tax                            ;2 
       lda    (PrintTemp+8),y         ;5 
       ldy    $DB                     ;3 
       sty    GRP0                    ;3 
       stx    GRP1                    ;3 
       sta    GRP0                    ;3 
       tsx                            ;2 
       stx    GRP1                    ;3 
       dec    $DA                     ;5 
       bpl    Display_Score_loop      ;2 
       ldy    PlayerX                 ;3 
       lda    XposTbl,y               ;4 <-PosX
       tay                            ;2 
       and    #$0F                    ;2 
       sta    WSYNC                   ;3 
       tax                            ;2 
       lda    #$00                    ;2 
       sta    COLUP0                  ;3 
       sta    COLUP1                  ;3 
       sty    HMP1                    ;3 
       NOP                            ;2 
       dex                            ;2 
Score_Done_wait1:
       dex                            ;2 
       bpl    Score_Done_wait1        ;2 
       sta    RESP1                   ;3 
       txs                            ;2 
       inx                            ;2 
       sta    WSYNC                   ;3 
       sta    HMOVE                   ;3 
       stx    NUSIZ0                  ;3 
       stx    NUSIZ1                  ;3 
;       stx    GRP0                    ;3 
;       stx    GRP1                    ;3 
       stx    $FD                     ;3 
       stx    $B1                     ;3 
       stx    $B2                     ;3 
       stx    $B3                     ;3 
       stx    PrintTemp+10            ;3 

       lda    DifSw                   ;3 check diff.
       and    #$08                    ;2 B&W switch only
       bne    yeOriginal              ;2 flip it
       bit    Temp                    ;3
       beq    screen1                 ;2
       jmp    screen2                 ;3 <-patch here
yeOriginal:
       jmp    screen3                 ;3 <-patch here

;indirect jump low byte values
IndLowTab:
       .byte <Ind1 ; $F0F6
       .byte <Ind1 ; $F0F7
       .byte <Ind2 ; $F0F8
       .byte <Ind3 ; $F0F9
       .byte <Ind4 ; $F0FA
       .byte <Ind5 ; $F0FB
       .byte <Ind6 ; $F0FC
       .byte <Ind7 ; $F0FD
       .byte <Ind8 ; $F0FE
       .byte <Ind9 ; $F0FF

Extra_Life_Tab:
       .byte $38 ; |  XXX   | $F21A
       .byte $7C ; | XXXXX  | $F21B
       .byte $F0 ; |XXXX    | $F21C
       .byte $E0 ; |XXX     | $F21D
       .byte $F0 ; |XXXX    | $F21E
       .byte $7C ; | XXXXX  | $F21F
       .byte $38 ; |  XXX   | $F220






;alternate:
screen1:
       lda    $C0                     ;3 
       cmp    #$FF                    ;2 
       bne    LF8F1                   ;2 
       ldy    $D0                     ;3 
       lda    XposTbl,y               ;4 <-PosX
       sta    PrintTemp+9             ;3 
       and    #$0F                    ;2 
       sta    PrintTemp+8             ;3 
       tay                            ;2 
       lda    PrintTemp+9             ;3 
       sta    HMP0                    ;3 
       stx    HMP1                    ;3 
       stx    WSYNC                   ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    $B1                     ;3 
       sta    GRP0                    ;3 
;start maze display
Maze_Display_Wait:
       dey                            ;2 
       bpl    Maze_Display_Wait       ;2 
       sty    RESP0                   ;3 
       sta    WSYNC                   ;3 
       sta    HMOVE                   ;3 
       ldx    #$00                    ;2 
       stx    HMP1                    ;3 
       lda    #$1A                    ;2 
       sta    COLUP1                  ;3 
       lda    PlayerY                 ;3 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       sta    $B1                     ;3 
       lda    $CB                     ;3 
       sta    COLUP0                  ;3 
       ldy    $D5                     ;3 
       lda    Monster2tab,y           ;4 
       sta    PrintTemp+1             ;3 
       lda    Monster3tab,y           ;4 
       sta    PrintTemp+2             ;3 
       lda    Monster4tab,y           ;4 
       sta    PrintTemp+3             ;3 
       lda    Monster5tab,y           ;4 
       sta    PrintTemp+4             ;3 
       lda    Monster6tab,y           ;4 
       sta    PrintTemp+5             ;3 
       lda    Maze2aTab               ;4 
       sta    PF1                     ;3 
       lda    Maze3aTab               ;4 
       sta    PF2                     ;3 
       lda    RamDots+46              ;3 energizer control shared for maze color??
       sta    COLUPF                  ;3 
       lda    Maze1aTab               ;4 
       sta    PF0                     ;3 
       lda    Monster7tab,y           ;4 
       sta    PrintTemp+6             ;3 
       lda    Monster8tab,y           ;4 
       sta    PrintTemp+7             ;3 
       lda    #$01                    ;2 
       sta    PrintTemp+11            ;3 
       bne    LF95D                   ;2 
LF8F1:
       sta    WSYNC                   ;3 
       sta    WSYNC                   ;3 
       ldy    #$E0                    ;2 
       nop                            ;2 
       lda    #$1A                    ;2 
       stx    GRP1                    ;3 X=0
       stx    GRP0                    ;3 
       stx    PrintTemp+11            ;3 
       stx    $DA                     ;3 
       stx    $DB                     ;3 
       stx    PrintTemp               ;3 
       stx    PrintTemp+1             ;3 
       stx    PrintTemp+2             ;3 
       stx    PrintTemp+3             ;3 
       stx    PrintTemp+4             ;3 
       stx    PrintTemp+5             ;3 
       stx    HMP1                    ;3 
       sta    COLUP1                  ;3 
       sta    WSYNC                   ;3 
       bne    LF92D                   ;2 
LF91A:
       lda    #$00                    ;2 
       sta    PrintTemp+10            ;3 
       beq    LF985                   ;2 
LF920:
       ldy    Maze1aTab,x             ;4 
       lda    $B3                     ;3 
       sta    WSYNC                   ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp               ;3 
       sta    GRP0                    ;3 
LF92D:
       lda    RamDots+46              ;3 energizer control shared for maze color??
       sta    COLUPF                  ;3 
       sty    PF0                     ;3 
       lda    Maze2aTab,x             ;4 
       sta    PF1                     ;3 
       lda    $CB                     ;3 
       sta    COLUP0                  ;3 
       lda    Maze3aTab,x             ;4 
       sta    PF2                     ;3 
       lda    #$01                    ;2 
       sta    CTRLPF                  ;3 
       lda    PlayerY                 ;3 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       sta    $B1                     ;3 
       lda    $DA                     ;3 
       sta    PrintTemp+6             ;3 
       lda    $DB                     ;3 
       sta    PrintTemp+7             ;3 
       ldy    $FD                     ;3 
       sta    WSYNC                   ;3 
       lda    Pac7tab,y               ;4 
       sta    GRP1                    ;3 
LF95D:
       lda    PrintTemp+1             ;3 
       sta    GRP0                    ;3 
       ldy    PrintTemp+11            ;3 
       txa                            ;2 
       sec                            ;2 
       sbc.wy $C0,y                   ;4 
       bne    LF91A                   ;2 
       tya                            ;2 
       lsr                            ;2 
       bcs    LF91A                   ;2 
       iny                            ;2 
       sty    PrintTemp+10            ;3 
       tay                            ;2 
       lda.wy $D0,y                   ;4 
       tay                            ;2 
       lda    XposTbl,y               ;4 <-PosX
       sta    PrintTemp+9             ;3 
       and    #$0F                    ;2 
       sta    PrintTemp+8             ;3 
       tay                            ;2 
       lda    IndLowTab-1,y           ;4 load low jump vector
       sta    IndAdr                  ;3 
LF985:
       ldy    $FD                     ;3 
       sta    WSYNC                   ;3 
       lda    Pac8tab,y               ;4 
       sta    GRP1                    ;3 
       lda    PrintTemp+2             ;3 
       sta    GRP0                    ;3 
       lda    Maze1bTab,x             ;4 
       sta    PF0                     ;3 
       lda    Maze2bTab,x             ;4 
       sta    PF1                     ;3 
       lda    Maze3bTab,x             ;4 
       sta    PF2                     ;3 
       cpx    $B1                     ;3 
       bne    LF9B7                   ;2 
       lda    PlayerY                 ;3 
       and    #$07                    ;2 
       sta    $FD                     ;3 
       lda    #$08                    ;2 
       sbc    $FD                     ;3 
       jmp    LF9C8                   ;3 
LF9B3:
       lda    #$00                    ;2 
       beq    LF9C8                   ;2 
LF9B7:
       inc    $B1                     ;5 
       cpx    $B1                     ;3 
       bne    LF9B3                   ;2 
       lda    PlayerY                 ;3 
       and    #$07                    ;2 
       sta    $FD                     ;3 
       lda    #$10                    ;2 
       sbc    $FD                     ;3 
LF9C8:
       clc                            ;2 do not remove
       adc    PacOffset               ;3 
       sta    $FD                     ;3 
       sta    WSYNC                   ;3 
       tay                            ;2 
       lda    Pac1tab,y               ;4 
       sta    GRP1                    ;3 
       lda    PrintTemp+3             ;3 
       sta    GRP0                    ;3 
       ldy    $FD                     ;3 
       lda    Pac2tab,y               ;4 
       sta    $B1                     ;3 
       lda    PrintTemp+11            ;3 
       lsr                            ;2 
       tay                            ;2 
       bcs    LF9F1                   ;2 
       lda    PrintTemp+10            ;3 
       beq    LF9F7                   ;2 
       lda.wy $D5,y                   ;4 
       jmp    LF9F7                   ;3 
LF9F1:
       lda.wy $D5,y                   ;4 
       clc                            ;2 
       adc    #$08                    ;2 
LF9F7:
       tay                            ;2 
       lda    Monster1tab,y           ;4 
       sta    PrintTemp               ;3 
       lda    Monster2tab,y           ;4 
       sta    PrintTemp+1             ;3 
       lda    Monster3tab,y           ;4 
       sta    PrintTemp+2             ;3 
       lda    Monster4tab,y           ;4 
       sta    PrintTemp+3             ;3 
       lda    Monster8tab,y           ;4 
       sta    $DB                     ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+4             ;3 
       sta    GRP0                    ;3 
       lda    Monster5tab,y           ;4 
       sta    PrintTemp+4             ;3 
       lda    PrintTemp+5             ;3 
       sta    $B1                     ;3 
       lda    Monster6tab,y           ;4 
       sta    PrintTemp+5             ;3 
       lda    Monster7tab,y           ;4 
       sta    $DA                     ;3 
       lda    PrintTemp+10            ;3 
       bne    LFA40                   ;2 
       lda    PrintTemp+11            ;3 
       lsr                            ;2 
       bcc    LFA39                   ;2 
       inc    PrintTemp+11            ;5 
       bcs    LFA49                   ;2 
LFA39:
       ldy    #$01                    ;2 
LFA3B:
       dey                            ;2 
       bpl    LFA3B                   ;2 
       bmi    LFA49                   ;2 
LFA40:
       lsr                            ;2 
       tay                            ;2 
       lda.wy $CB,y                   ;4 
       sta    $CB                     ;3 
       inc    PrintTemp+11            ;5 
LFA49:
       ldy    $FD                     ;3 
       lda    Pac3tab,y               ;4 
       sta    GRP1                    ;3 
       lda    $B1                     ;3 
       sta    GRP0                    ;3 
       lda    Maze1cTab,x             ;4 
       sta    PF0                     ;3 
       lda    Maze2cTab,x             ;4 
       sta    PF1                     ;3 
       lda    Maze3cTab,x             ;4 
       sta    PF2                     ;3 
       ldy    $FD                     ;3 
       lda    Pac4tab,y               ;4 
       sta    $B1                     ;3 
       lda    Pac5tab,y               ;4 
       sta    $B2                     ;3 
       cpx    #$15                    ;2 <-adjust X
       beq    Playfield_no_dots       ;2 
       lda    PrintTemp+10            ;3 
       beq    LFAB9                   ;2 
       ldy    PrintTemp+8             ;3 
       lda    IndHighTab-1,y          ;4 load high jump vector
       sta    IndAdr+1                ;3 
       jmp.ind (IndAdr)               ;5 

LFAB9:
       ldy    $FD                     ;3 
       lda    Pac6tab,y               ;4 
       sta    $B3                     ;3 
       lda    $B1                     ;3 
       sta    WSYNC                   ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+6             ;3 
       sta    GRP0                    ;3 
       ldy    #$08                    ;2 
LFACC:
       dey                            ;2 
       bne    LFACC                   ;2 
LFA81:
       lda    RamDots,x               ;4 
       tay                            ;2 
       and    #$2A                    ;2 
       sta    PF2                     ;3 
       tya                            ;2 
       and    #$80                    ;2 
       sta    WSYNC                   ;3 
       sta    PF0                     ;3 
       lda    #$0E                    ;2 
       sta    COLUPF                  ;3 
       lda    $B2                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+7             ;3 
       sta    GRP0                    ;3 
       tya                            ;2 
       and    #$55                    ;2 
       sta    PF1                     ;3 
       lda    #$00                    ;2 
LFAA2:
       sta    CTRLPF                  ;3 
       lda    RamDots+21,x            ;4 
       tay                            ;2 
       and    #$40                    ;2 
       sta    PF0                     ;3 
       tya                            ;2 
       and    #$AA                    ;2 
       sta    PF1                     ;3 
       tya                            ;2 
       and    #$15                    ;2 
       sta    PF2                     ;3 
       inx                            ;2 
       jmp    LF920                   ;3 
Playfield_no_dots:
       sta    WSYNC                   ;3 
       lda    #$00                    ;2 
       sta    GRP0                    ;3 
       sta    GRP1                    ;3 
       sta    HMP1                    ;3 
       lda    #$80                    ;2 
       sta    HMP0                    ;3 
       sta    $B1                     ;3 
       nop                            ;2 
       sta    RESP1                   ;3 
       ldy    #$07                    ;2 
       dey                            ;2 
Display_skipline: ;x=0
       dey                            ;2 
       bpl    Display_skipline        ;2 
       sta    RESP0                   ;3 x=0,y=FF
       sta    WSYNC                   ;3 
       sta    HMOVE                   ;3 
       iny                            ;2 
       sty    GRP1                    ;3 
       sty    PF0                     ;3 
       sty    PF1                     ;3 
       sty    PF2                     ;3 
       lda    Lives                   ;3 
       and    #$0F                    ;2 
       tax                            ;2 
       cpx    #$02                    ;2 
       bcs    Lower_Display_prep      ;2 
       sty    COLUP1                  ;3 
Lower_Display_prep:
       lda    Byte_test1_tab,x        ;4 
       sta    NUSIZ1                  ;3 
       stx    WSYNC                   ;3 
Set_Lower_Display:
       ldx    Level                   ;3 
       lda    FruitColorTab,x         ;4 
       sta    COLUP0                  ;3 
       tya                            ;2 
       clc                            ;2 
       adc    Mid_Fruit_lo_tab,x      ;4 
       tax                            ;2 
       lda    LowerFruitOffset,x      ;4 
       ldx    Extra_Life_Tab,y        ;4 
       stx    WSYNC                   ;3 
       stx    GRP1                    ;3 
       sta    GRP0                    ;3 
       iny                            ;2 
       cpy    #$07                    ;2 <-lower scanlines
       bne    Set_Lower_Display       ;3 
       stx    $2E                     ;3 waste
;Overscan1:
       ldx    #$00                    ;2 
       stx    WSYNC                   ;3 
       stx    GRP1                    ;3 
       stx    GRP0                    ;3 
;critical timing over
KernalDone:
       stx    PrintTemp+9             ;3 
       stx    PrintTemp+8             ;3 
       stx    $DA                     ;3 
       lda    MonsterY                ;3 
       sta    PrintTemp               ;3 
       lda    MonsterY+1              ;3 
       sta    PrintTemp+1             ;3 
       lda    MonsterY+2              ;3 
       sta    PrintTemp+2             ;3 
       lda    MonsterY+3              ;3 
       sta    PrintTemp+3             ;3 
       ldx    #$F0                    ;2 
       lda    #Time                   ;2 <-extra time if needed
       sta    TIM64T                  ;4 
       lda    Control                 ;3 
       and    #$20                    ;2 
       beq    LFB64                   ;2 
       ldx    #$60                    ;2 
LFB64:
       stx    PrintTemp+4             ;3 
       lda    #$F0                    ;2 
       sta    PrintTemp+5             ;3 

LFB68:
       ldx    #$04                    ;2 
       lda    #$F0                    ;2 
       sta    PrintTemp+11            ;3 
       sta    PrintTemp+10            ;3 
LFB70:
       lda    PrintTemp,x             ;4 
       cmp    PrintTemp+10            ;3 
       bcs    LFB7A                   ;2 
       sta    PrintTemp+10            ;3 
       stx    PrintTemp+11            ;3 
LFB7A:
       dex                            ;2 
       bpl    LFB70                   ;2 
       lda    PrintTemp+10            ;3 x=ff
       cmp    #$F0                    ;2 
       beq    LFB8B                   ;2 
       lda    PrintTemp+11            ;3 
       cmp    #$F0                    ;2 
       bne    LFB8E                   ;2 
LFB8B:
       jmp    LFC4C1                  ;3 exit
LFB8E:
       ldy    PrintTemp+9             ;3 
       beq    LFBAF                   ;2 
       lda    PrintTemp+10            ;3 
       sec                            ;2 
       sbc    PrintTemp+8             ;3 
       cmp    #$10                    ;2 
       bcs    LFBB3                   ;2 
       lda    LoTimer                 ;3 
       ldx    $DA                     ;3 
       beq    LFBA5                   ;2 
LFBA1:
       lsr                            ;2 
       dex                            ;2 
       bne    LFBA1                   ;2 
LFBA5:
       dec    PrintTemp+9             ;5 
       inc    $DA                     ;5 
       lsr                            ;2 
       bcs    LFBB3                   ;2 
       jmp    LFC3B                   ;3 
LFBAF:
       lda    #$00                    ;2 
       sta    $DA                     ;3 
LFBB3:
       lda    PrintTemp+10            ;3 
       sta    PrintTemp+8             ;3 
       ldx    PrintTemp+11            ;3 
       cpx    #$04                    ;2 
       bne    LFBE1                   ;2 
       ldy    PrintTemp+9             ;3 
       lda    #$42                    ;2 
       sta.wy $D0,y                   ;5 
       lda    Control                 ;3
       beq    Fdisplay                ;2
       cmp    #$7F                    ;2 
       bcs    Fdisplay                ;2
       ldx    #$00                    ;2 
       stx    $D5,y                   ;4 
       beq    ColorOKFruit            ;2
Fdisplay:
       lda    #$FF                    ;2 
       ldx    Level                   ;3 
       bit    Control                 ;3
       bmi    NoFruit                 ;2
       lda    LoTimer                 ;3 
       and    #$08                    ;2 
       ora    #$F0                    ;2 
       ldx    #$12                    ;2 
NoFruit:
       sta    Temp                    ;3 
       lda    Mid_Fruit_lo_tab,x      ;4 
       sta.wy $D5,y                   ;5 
       lda    FruitColorTab,x         ;4 
       and    Temp                    ;3 
       tax                            ;2 
       lda    Lives                   ;3 Check for PacPlus
       and    #$07                    ;2 
       bne    ColorOKFruit            ;2
       ldx    #$00                    ;2 
ColorOKFruit:
       stx    $CB,y                   ;4
       tya                            ;2 
       asl                            ;2 
       tay                            ;2 
       lda    #$0B                    ;2 
       sta.wy $C0,y                   ;5 
       lda    #$0C                    ;2 
       bne    LFC33                   ;2 
LFBE1:
       ldy    PrintTemp+9             ;3 
       ldx    PrintTemp+11            ;3 
       lda    MonsterX,x              ;4 
       sta.wy $D0,y                   ;5 
       lda    PrintTemp+10            ;3 
;offset
       adc    #$03                    ;2 
       and    #$07                    ;2 
       sta    PrintTemp+7             ;3 
       lda    Color,x                 ;4 check monster's blue flag
       tax                            ;2 save for monster color
       bne    NoEyes                  ;2 
       lda    #<Monster7tab+$67       ;2 Eyes bitmap (+64 & 2nd jump = choppy)
       ldx    #$0E                    ;2 load white color instead
       bne    Animate_start           ;2 ...and skip ahead (no animation)
NoEyes:
       lda    LoTimer                 ;3 
       and    #$04                    ;3 keep bit 2
       php                            ;2 save for animation
       lda    #<Monster7tab+1         ;2 
       inx                            ;2 
       bpl    Animate_start0          ;2 branch to use normal color if not set
       bit    Lives                   ;3 Check for PacPlus
       bvc    RegularBlue             ;2 branch if regular
       adc    #$45                    ;2 change to flagged monsters
       jmp    Animate_start0          ;3 
RegularBlue:
       adc    #$22                    ;2 change to flagged monsters
Animate_start0:
       plp                            ;3 
       beq    Animate_start           ;2 
       adc    #$11                    ;3 Load the next bitmap if the timer had bit 2 set
Animate_start:
       ldy    PrintTemp+9             ;3 
       sec                            ;2 
       sbc    PrintTemp+7             ;3 
       sta.wy $D5,y                   ;5 
       txa                            ;2 
       sta.wy $CB,y                   ;5 
       tya                            ;2 
       asl                            ;2 
       tay                            ;2 
       lda    PrintTemp+10            ;3 
;offset
       adc    #$03                    ;2 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       sec                            ;2 
       sbc    #$01                    ;2 
       sta.wy $C0,y                   ;5 
       clc                            ;2 
       adc    #$01                    ;2 
LFC33:
       sta.wy $C1,y                   ;5 
       lda    #$F0                    ;2 
       sta.wy $C2,y                   ;5 
LFC3B:
       inc    PrintTemp+9             ;5 
       lda    PrintTemp+9             ;3 
       cmp    #$05                    ;2 
       bne    LFC4Cno                 ;2 
       jmp    LFC4C1                  ;2 exit

LFC4Cno:
       ldx    PrintTemp+11            ;3 
       lda    #$F0                    ;2 
       sta    PrintTemp,x             ;4 
       jmp    LFB68                   ;3 








Ind1:
       sta    WSYNC                   ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+6             ;3 
       sta    GRP0                    ;3 
Ind1a:
       dey                            ;2 
       bpl    Ind1a                   ;2 
       sty    RESP0                   ;3 
       lda    PrintTemp+9             ;3 
       sta    HMP0                    ;3 
       ldy    $FD                     ;3 
       lda    Pac6tab,y               ;4 
       sta    $B3                     ;3 
       lda    RamDots,x               ;4 
       tay                            ;2 
       stx    $B1                     ;3 
Ind1b:
       and    #$55                    ;2 
       tax                            ;2 
       tya                            ;2 
       and    #$2A                    ;2 
       jmp    Ind8c                   ;3 


Ind2:
       sta    WSYNC                   ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+6             ;3 
       sta    GRP0                    ;3 
       dey                            ;2 
       dey                            ;2 
       lda    PrintTemp+9             ;3 
       sta    HMP0                    ;3 
Ind2a:
       dey                            ;2 
       bpl    Ind2a                   ;2 
       sty    RESP0                   ;3 
       ldy    $FD                     ;3 
       lda    Pac6tab,y               ;4 
       sta    $B3                     ;3 
       lda    RamDots,x               ;4 
       tay                            ;2 
       stx    $B1                     ;3 
       and    #$55                    ;2 
       tax                            ;2 
       tya                            ;2 
       and    #$2A                    ;2 
       jmp    Ind8c                   ;3 


Ind3:
       sta    WSYNC                   ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+6             ;3 
       sta    GRP0                    ;3 
       lda    PrintTemp+9             ;3 
       sta    HMP0                    ;3 
       lda    $B1,x                   ;4 waste
       ldy    $FD                     ;3 
       lda    Pac6tab,y               ;4 
       sta    $B3                     ;3 
       lda    RamDots,x               ;4 
       sta    RESP0                   ;3 
       jmp    Ind4a                   ;3 


Ind4:
       sta    WSYNC                   ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+6             ;3 
       sta    GRP0                    ;3 
       lda    PrintTemp+9             ;3 
       sta    HMP0                    ;3 
       PHA                            ;3 
       PLA                            ;4 
       ldy    $FD                     ;3 
       lda    Pac6tab,y               ;4 
       sta    $B3                     ;3 
       lda    RamDots,x               ;4 
       NOP                            ;2 
       sta    RESP0                   ;3 
Ind4a:
       bit    VSYNC                   ;3 
       tay                            ;2 
       stx    $B1                     ;3 
       and    #$55                    ;2 
       tax                            ;2 
       tya                            ;2 
       and    #$2A                    ;2 
       jmp    Ind8c                   ;3 


Ind5:
       sta    WSYNC                   ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+6             ;3 
       sta    GRP0                    ;3 
       lda    PrintTemp+9             ;3 
       sta    HMP0                    ;3 
       ldy    $FD                     ;3 
       lda    Pac6tab,y               ;4 
       sta    $B3                     ;3 
       lda    RamDots,x               ;4 
       stx    $B1                     ;3 
       tay                            ;2 
       and    #$55                    ;2 
       tax                            ;2 
       tya                            ;2 
       bit    VSYNC                   ;3 
       sta    RESP0                   ;3 
       jmp    Ind6a                   ;2 


Ind6:
       sta    WSYNC                   ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+6             ;3 
       sta    GRP0                    ;3 
       lda    PrintTemp+9             ;3 
       sta    HMP0                    ;3 
       ldy    $FD                     ;3 
       lda    Pac6tab,y               ;4 
       sta    $B3                     ;3 
       lda    RamDots,x               ;4 
       stx.w  $B1                     ;4 
       tay                            ;2 
       and    #$55                    ;2 
       tax                            ;2 
       tya                            ;2 
       PHA                            ;3 
       PLA                            ;4 
       sta    RESP0                   ;3 
Ind6a:
       NOP                            ;2 
       NOP                            ;2 
       and    #$2A                    ;2 
       jmp    Ind8c                   ;3 


Ind7:
       sta    WSYNC                   ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+6             ;3 
       sta    GRP0                    ;3 
       lda    PrintTemp+9             ;3 
       sta    HMP0                    ;3 
       lda    $B1,x                   ;4 waste
       jmp    Ind8b                   ;3 

Ind8:
       sta    WSYNC                   ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+6             ;3 
       sta    GRP0                    ;3 
       lda    PrintTemp+9             ;3 
       sta    HMP0                    ;3 
       jsr    L12_1                   ;12 
Ind8b:
       ldy    $FD                     ;3 
       lda    Pac6tab,y               ;4 
       sta    $B3                     ;3 
       lda    RamDots,x               ;4 
       stx    $B1                     ;3 
       tay                            ;2 
       and    #$55                    ;2 
       tax                            ;2 
       tya                            ;2 
       and    #$2A                    ;2 
       NOP                            ;2 
       NOP                            ;2 
       sta    RESP0                   ;3 
Ind8c:
       sta    PF2                     ;3 
       tya                            ;2 
       and    #$80                    ;2 
       sta    WSYNC                   ;3 
       sta    HMOVE                   ;3 
       sta    PF0                     ;3 
       lda    $B2                     ;3 
       sta    GRP1                    ;3 

       sta    GRP0                    ;3 

       lda    #$0E                    ;2 
       sta    COLUPF                  ;3 
       stx    PF1                     ;3 
;       lda    #$00                    ;2 
;       sta    GRP0                    ;3 
       ldx    $B1                     ;3 
       jmp.ind (IndExit)              ;5 

Ind9:
       sta    WSYNC                   ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+6             ;3 
       sta    GRP0                    ;3 
       lda    PrintTemp+9             ;3 
       sta    HMP0                    ;3 
       ldy    $FD                     ;3 
       lda    Pac6tab,y               ;4 
       sta    $B3                     ;3 
       lda    RamDots,x               ;4 
       stx    $B1                     ;3 
       tay                            ;2 
       and    #$55                    ;2 
       jsr    L16X                    ;16 
       tax                            ;2 
       tya                            ;2 
       and    #$2A                    ;2 
       sta    PF2                     ;3 
       tya                            ;2 
       sta    RESP0                   ;3 
       and    #$80                    ;2 
       sta    WSYNC                   ;3 
       sta    HMOVE                   ;3 
       sta    PF0                     ;3 
       lda    $B2                     ;3 
       sta    GRP1                    ;3 
       lda    #$0E                    ;2 
       sta    COLUPF                  ;3 
       stx    PF1                     ;3 
       lda    #$00                    ;2 
       sta    GRP0                    ;3 
       ldx    $B1                     ;3 
       jmp.ind (IndExit)              ;5 



;  ORG $16EA
;  RORG $D6EA

screen2:
       lda    $C0                     ;3 
       cmp    #$FF                    ;2 
       bne    LLF8F1                  ;2 
       ldy    $D0                     ;3 
       lda    XposTbl,y               ;4 <-PosX
       sta    PrintTemp+9             ;3 
       and    #$0F                    ;2 
       sta    PrintTemp+8             ;3 
       tay                            ;2 
       lda    PrintTemp+9             ;3 
       sta    HMP0                    ;3 
       stx    HMP1                    ;3 
       stx    WSYNC                   ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    $B1                     ;3 
       sta    GRP0                    ;3 
;start maze display
MMaze_Display_Wait:
       dey                            ;2 
       bpl    MMaze_Display_Wait      ;2 
       sty    RESP0                   ;3 
       sta    WSYNC                   ;3 
       sta    HMOVE                   ;3 
       ldx    #$00                    ;2 
       stx    HMP1                    ;3 
       lda    #$1A                    ;2 
       sta    COLUP1                  ;3 
       lda    PlayerY                 ;3 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       sta    $B1                     ;3 
       lda    $CB                     ;3 
       sta    COLUP0                  ;3 
       ldy    $D5                     ;3 
       lda    Monster2tab,y           ;4 
       sta    PrintTemp+1             ;3 
       lda    Monster3tab,y           ;4 
       sta    PrintTemp+2             ;3 
       lda    Monster4tab,y           ;4 
       sta    PrintTemp+3             ;3 
       lda    Monster5tab,y           ;4 
       sta    PrintTemp+4             ;3 
       lda    Monster6tab,y           ;4 
       sta    PrintTemp+5             ;3 
       lda    MMaze2aTab              ;4 
       sta    PF1                     ;3 
       lda    MMaze3aTab              ;4 
       sta    PF2                     ;3 
       lda    RamDots+46              ;3 energizer control shared for maze color??
       sta    COLUPF                  ;3 
       lda    MMaze1aTab              ;4 
       sta    PF0                     ;3 
       lda    Monster7tab,y           ;4 
       sta    PrintTemp+6             ;3 
       lda    Monster8tab,y           ;4 
       sta    PrintTemp+7             ;3 
       lda    #$01                    ;2 
       sta    PrintTemp+11            ;3 
       bne    LLF95D                  ;2 
LLF8F1:
       sta    WSYNC                   ;3 
       sta    WSYNC                   ;3 
       ldy    #$E0                    ;2 
       nop                            ;2 
       lda    #$1A                    ;2 
       stx    GRP1                    ;3 X=0
       stx    GRP0                    ;3 
       stx    PrintTemp+11            ;3 
       stx    $DA                     ;3 
       stx    $DB                     ;3 
       stx    PrintTemp               ;3 
       stx    PrintTemp+1             ;3 
       stx    PrintTemp+2             ;3 
       stx    PrintTemp+3             ;3 
       stx    PrintTemp+4             ;3 
       stx    PrintTemp+5             ;3 
       stx    HMP1                    ;3 
       sta    COLUP1                  ;3 
       sta    WSYNC                   ;3 
       bne    LLF92D                  ;2 
LLF91A:
       lda    #$00                    ;2 
       sta    PrintTemp+10            ;3 
       beq    LLF985                  ;2 
LLF920:
       ldy    MMaze1aTab,x            ;4 
       lda    $B3                     ;3 
       sta    WSYNC                   ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp               ;3 
       sta    GRP0                    ;3 
LLF92D:
       lda    RamDots+46              ;3 energizer control shared for maze color??
       sta    COLUPF                  ;3 
       sty    PF0                     ;3 
       lda    MMaze2aTab,x            ;4 
       sta    PF1                     ;3 
       lda    $CB                     ;3 
       sta    COLUP0                  ;3 
       lda    MMaze3aTab,x            ;4 
       sta    PF2                     ;3 
       lda    #$01                    ;2 
       sta    CTRLPF                  ;3 
       lda    PlayerY                 ;3 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       sta    $B1                     ;3 
       lda    $DA                     ;3 
       sta    PrintTemp+6             ;3 
       lda    $DB                     ;3 
       sta    PrintTemp+7             ;3 
       ldy    $FD                     ;3 
       sta    WSYNC                   ;3 
       lda    Pac7tab,y               ;4 
       sta    GRP1                    ;3 
LLF95D:
       lda    PrintTemp+1             ;3 
       sta    GRP0                    ;3 
       ldy    PrintTemp+11            ;3 
       txa                            ;2 
       sec                            ;2 
       sbc.wy $C0,y                   ;4 
       bne    LLF91A                  ;2 
       tya                            ;2 
       lsr                            ;2 
       bcs    LLF91A                  ;2 
       iny                            ;2 
       sty    PrintTemp+10            ;3 
       tay                            ;2 
       lda.wy $D0,y                   ;4 
       tay                            ;2 
       lda    XposTbl,y               ;4 <-PosX
       sta    PrintTemp+9             ;3 
       and    #$0F                    ;2 
       sta    PrintTemp+8             ;3 
       tay                            ;2 
       lda    IndLowTab-1,y           ;4 load low jump vector
       sta    IndAdr                  ;3 
LLF985:
       ldy    $FD                     ;3 
       sta    WSYNC                   ;3 
       lda    Pac8tab,y               ;4 
       sta    GRP1                    ;3 
       lda    PrintTemp+2             ;3 
       sta    GRP0                    ;3 
       lda    MMaze1bTab,x            ;4 
       sta    PF0                     ;3 
       lda    MMaze2bTab,x            ;4 
       sta    PF1                     ;3 
       lda    MMaze3bTab,x            ;4 
       sta    PF2                     ;3 
       cpx    $B1                     ;3 
       bne    LLF9B7                  ;2 
       lda    PlayerY                 ;3 
       and    #$07                    ;2 
       sta    $FD                     ;3 
       lda    #$08                    ;2 
       sbc    $FD                     ;3 
       jmp    LLF9C8                  ;3 
LLF9B3:
       lda    #$00                    ;2 
       beq    LLF9C8                  ;2 
LLF9B7:
       inc    $B1                     ;5 
       cpx    $B1                     ;3 
       bne    LLF9B3                  ;2 
       lda    PlayerY                 ;3 
       and    #$07                    ;2 
       sta    $FD                     ;3 
       lda    #$10                    ;2 
       sbc    $FD                     ;3 
LLF9C8:
       clc                            ;2 do not remove
       adc    PacOffset               ;3 
       sta    $FD                     ;3 
       sta    WSYNC                   ;3 
       tay                            ;2 
       lda    Pac1tab,y               ;4 
       sta    GRP1                    ;3 
       lda    PrintTemp+3             ;3 
       sta    GRP0                    ;3 
       ldy    $FD                     ;3 
       lda    Pac2tab,y               ;4 
       sta    $B1                     ;3 
       lda    PrintTemp+11            ;3 
       lsr                            ;2 
       tay                            ;2 
       bcs    LLF9F1                  ;2 
       lda    PrintTemp+10            ;3 
       beq    LLF9F7                  ;2 
       lda.wy $D5,y                   ;4 
       jmp    LLF9F7                  ;3 
LLF9F1:
       lda.wy $D5,y                   ;4 
       clc                            ;2 
       adc    #$08                    ;2 
LLF9F7:
       tay                            ;2 
       lda    Monster1tab,y           ;4 
       sta    PrintTemp               ;3 
       lda    Monster2tab,y           ;4 
       sta    PrintTemp+1             ;3 
       lda    Monster3tab,y           ;4 
       sta    PrintTemp+2             ;3 
       lda    Monster4tab,y           ;4 
       sta    PrintTemp+3             ;3 
       lda    Monster8tab,y           ;4 
       sta    $DB                     ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+4             ;3 
       sta    GRP0                    ;3 
       lda    Monster5tab,y           ;4 
       sta    PrintTemp+4             ;3 
       lda    PrintTemp+5             ;3 
       sta    $B1                     ;3 
       lda    Monster6tab,y           ;4 
       sta    PrintTemp+5             ;3 
       lda    Monster7tab,y           ;4 
       sta    $DA                     ;3 
       lda    PrintTemp+10            ;3 
       bne    LLFA40                  ;2 
       lda    PrintTemp+11            ;3 
       lsr                            ;2 
       bcc    LLFA39                  ;2 
       inc    PrintTemp+11            ;5 
       bcs    LLFA49                  ;2 
LLFA39:
       ldy    #$01                    ;2 
LLFA3B:
       dey                            ;2 
       bpl    LLFA3B                  ;2 
       bmi    LLFA49                  ;2 
LLFA40:
       lsr                            ;2 
       tay                            ;2 
       lda.wy $CB,y                   ;4 
       sta    $CB                     ;3 
       inc    PrintTemp+11            ;5 
LLFA49:
       ldy    $FD                     ;3 
       lda    Pac3tab,y               ;4 
       sta    GRP1                    ;3 
       lda    $B1                     ;3 
       sta    GRP0                    ;3 
       lda    MMaze1cTab,x            ;4 
       sta    PF0                     ;3 
       lda    MMaze2cTab,x            ;4 
       sta    PF1                     ;3 
       lda    MMaze3cTab,x            ;4 
       sta    PF2                     ;3 
       ldy    $FD                     ;3 
       lda    Pac4tab,y               ;4 
       sta    $B1                     ;3 
       lda    Pac5tab,y               ;4 
       sta    $B2                     ;3 
       cpx    #$15                    ;2 <-adjust X
       beq    PPlayfield_no_dots      ;2 
       lda    PrintTemp+10            ;3 
       beq    LLFAB9                  ;2 
       ldy    PrintTemp+8             ;3 
       lda    IndHighTab-1,y          ;4 load high jump vector
       sta    IndAdr+1                ;3 
       jmp.ind (IndAdr)               ;5 
LLFAB9:
       ldy    $FD                     ;3 
       lda    Pac6tab,y               ;4 
       sta    $B3                     ;3 
       lda    $B1                     ;3 
       sta    WSYNC                   ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+6             ;3 
       sta    GRP0                    ;3 
       ldy    #$08                    ;2 
LLFACC:
       dey                            ;2 
       bne    LLFACC                  ;2 
LLFA81:
       lda    RamDots,x               ;4 
       tay                            ;2 
       and    #$2A                    ;2 
       sta    PF2                     ;3 
       tya                            ;2 
       and    #$80                    ;2 
       sta    WSYNC                   ;3 
       sta    PF0                     ;3 
       lda    #$0E                    ;2 
       sta    COLUPF                  ;3 
       lda    $B2                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+7             ;3 
       sta    GRP0                    ;3 
       tya                            ;2 
       and    #$55                    ;2 
       sta    PF1                     ;3 
       lda    #$00                    ;2 
LLFAA2:
       sta    CTRLPF                  ;3 
       lda    RamDots+21,x            ;4 
       tay                            ;2 
       and    #$40                    ;2 
       sta    PF0                     ;3 
       tya                            ;2 
       and    #$AA                    ;2 
       sta    PF1                     ;3 
       tya                            ;2 
       and    #$15                    ;2 
       sta    PF2                     ;3 
       inx                            ;2 
       jmp    LLF920                  ;3 

PPlayfield_no_dots:
       sta    WSYNC                   ;3 
       lda    #$00                    ;2 
       sta    GRP0                    ;3 
       sta    GRP1                    ;3 
       sta    HMP1                    ;3 
       lda    #$80                    ;2 
       sta    HMP0                    ;3 
       sta    $B1                     ;3 
       nop                            ;2 
       sta    RESP1                   ;3 
       nop                            ;2 
       nop                            ;2 
       ldy    #$05                    ;2 
       jmp    Display_skipline        ;3 




















screen3:
       lda    $C0                     ;3 
       cmp    #$FF                    ;2 
       bne    MLF8F1                  ;2 
       ldy    $D0                     ;3 
       lda    XposTbl,y               ;4 <-PosX
       sta    PrintTemp+9             ;3 
       and    #$0F                    ;2 
       sta    PrintTemp+8             ;3 
       tay                            ;2 
       lda    PrintTemp+9             ;3 
       sta    HMP0                    ;3 
       stx    HMP1                    ;3 
       stx    WSYNC                   ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    $B1                     ;3 
       sta    GRP0                    ;3 
;start maze display
NMaze_Display_Wait:
       dey                            ;2 
       bpl    NMaze_Display_Wait      ;2 
       sty    RESP0                   ;3 
       sta    WSYNC                   ;3 
       sta    HMOVE                   ;3 
       ldx    #$00                    ;2 
       stx    HMP1                    ;3 
       lda    #$1A                    ;2 
       sta    COLUP1                  ;3 
       lda    PlayerY                 ;3 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       sta    $B1                     ;3 
       lda    $CB                     ;3 
       sta    COLUP0                  ;3 
       ldy    $D5                     ;3 
       lda    Monster2tab,y           ;4 
       sta    PrintTemp+1             ;3 
       lda    Monster3tab,y           ;4 
       sta    PrintTemp+2             ;3 
       lda    Monster4tab,y           ;4 
       sta    PrintTemp+3             ;3 
       lda    Monster5tab,y           ;4 
       sta    PrintTemp+4             ;3 
       lda    Monster6tab,y           ;4 
       sta    PrintTemp+5             ;3 
       lda    NMaze2aTab              ;4 
       sta    PF1                     ;3 
       lda    NMaze3aTab              ;4 
       sta    PF2                     ;3 
       lda    RamDots+46              ;3 energizer control shared for maze color??
       sta    COLUPF                  ;3 
       lda    NMaze1aTab              ;4 
       sta    PF0                     ;3 
       lda    Monster7tab,y           ;4 
       sta    PrintTemp+6             ;3 
       lda    Monster8tab,y           ;4 
       sta    PrintTemp+7             ;3 
       lda    #$01                    ;2 
       sta    PrintTemp+11            ;3 
       bne    MLF95D                  ;2 
MLF8F1:
       sta    WSYNC                   ;3 
       sta    WSYNC                   ;3 
       ldy    #$E0                    ;2 
       nop                            ;2 
       lda    #$1A                    ;2 
       stx    GRP1                    ;3 X=0
       stx    GRP0                    ;3 
       stx    PrintTemp+11            ;3 
       stx    $DA                     ;3 
       stx    $DB                     ;3 
       stx    PrintTemp               ;3 
       stx    PrintTemp+1             ;3 
       stx    PrintTemp+2             ;3 
       stx    PrintTemp+3             ;3 
       stx    PrintTemp+4             ;3 
       stx    PrintTemp+5             ;3 
       stx    HMP1                    ;3 
       sta    COLUP1                  ;3 
       sta    WSYNC                   ;3 
       bne    MLF92D                  ;2 
MLF91A:
       lda    #$00                    ;2 
       sta    PrintTemp+10            ;3 
       beq    MLF985                  ;2 
MLF920:
       ldy    NMaze1aTab,x            ;4 
       lda    $B3                     ;3 
       sta    WSYNC                   ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp               ;3 
       sta    GRP0                    ;3 
MLF92D:
       lda    RamDots+46              ;3 energizer control shared for maze color??
       sta    COLUPF                  ;3 
       sty    PF0                     ;3 
       lda    NMaze2aTab,x            ;4 
       sta    PF1                     ;3 
       lda    $CB                     ;3 
       sta    COLUP0                  ;3 
       lda    NMaze3aTab,x            ;4 
       sta    PF2                     ;3 
       lda    #$01                    ;2 
       sta    CTRLPF                  ;3 
       lda    PlayerY                 ;3 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       sta    $B1                     ;3 
       lda    $DA                     ;3 
       sta    PrintTemp+6             ;3 
       lda    $DB                     ;3 
       sta    PrintTemp+7             ;3 
       ldy    $FD                     ;3 
       sta    WSYNC                   ;3 
       lda    Pac7tab,y               ;4 
       sta    GRP1                    ;3 
MLF95D:
       lda    PrintTemp+1             ;3 
       sta    GRP0                    ;3 
       ldy    PrintTemp+11            ;3 
       txa                            ;2 
       sec                            ;2 
       sbc.wy $C0,y                   ;4 
       bne    MLF91A                  ;2 
       tya                            ;2 
       lsr                            ;2 
       bcs    MLF91A                  ;2 
       iny                            ;2 
       sty    PrintTemp+10            ;3 
       tay                            ;2 
       lda.wy $D0,y                   ;4 
       tay                            ;2 
       lda    XposTbl,y               ;4 <-PosX
       sta    PrintTemp+9             ;3 
       and    #$0F                    ;2 
       sta    PrintTemp+8             ;3 
       tay                            ;2 
       lda    IndLowTab-1,y           ;4 load low jump vector
       sta    IndAdr                  ;3 
MLF985:
       ldy    $FD                     ;3 
       sta    WSYNC                   ;3 
       lda    Pac8tab,y               ;4 
       sta    GRP1                    ;3 
       lda    PrintTemp+2             ;3 
       sta    GRP0                    ;3 
       lda    NMaze1bTab,x            ;4 
       sta    PF0                     ;3 
       lda    NMaze2bTab,x            ;4 
       sta    PF1                     ;3 
       lda    NMaze3bTab,x            ;4 
       sta    PF2                     ;3 
       cpx    $B1                     ;3 
       bne    MLF9B7                  ;2 
       lda    PlayerY                 ;3 
       and    #$07                    ;2 
       sta    $FD                     ;3 
       lda    #$08                    ;2 
       sbc    $FD                     ;3 
       jmp    MLF9C8                  ;3 
MLF9B3:
       lda    #$00                    ;2 
       beq    MLF9C8                  ;2 
MLF9B7:
       inc    $B1                     ;5 
       cpx    $B1                     ;3 
       bne    MLF9B3                  ;2 
       lda    PlayerY                 ;3 
       and    #$07                    ;2 
       sta    $FD                     ;3 
       lda    #$10                    ;2 
       sbc    $FD                     ;3 
MLF9C8:
       clc                            ;2 do not remove
       adc    PacOffset               ;3 
       sta    $FD                     ;3 
       sta    WSYNC                   ;3 
       tay                            ;2 
       lda    Pac1tab,y               ;4 
       sta    GRP1                    ;3 
       lda    PrintTemp+3             ;3 
       sta    GRP0                    ;3 
       ldy    $FD                     ;3 
       lda    Pac2tab,y               ;4 
       sta    $B1                     ;3 
       lda    PrintTemp+11            ;3 
       lsr                            ;2 
       tay                            ;2 
       bcs    MLF9F1                  ;2 
       lda    PrintTemp+10            ;3 
       beq    MLF9F7                  ;2 
       lda.wy $D5,y                   ;4 
       jmp    MLF9F7                  ;3 
MLF9F1:
       lda.wy $D5,y                   ;4 
       clc                            ;2 
       adc    #$08                    ;2 
MLF9F7:
       tay                            ;2 
       lda    Monster1tab,y           ;4 
       sta    PrintTemp               ;3 
       lda    Monster2tab,y           ;4 
       sta    PrintTemp+1             ;3 
       lda    Monster3tab,y           ;4 
       sta    PrintTemp+2             ;3 
       lda    Monster4tab,y           ;4 
       sta    PrintTemp+3             ;3 
       lda    Monster8tab,y           ;4 
       sta    $DB                     ;3 
       lda    $B1                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+4             ;3 
       sta    GRP0                    ;3 
       lda    Monster5tab,y           ;4 
       sta    PrintTemp+4             ;3 
       lda    PrintTemp+5             ;3 
       sta    $B1                     ;3 
       lda    Monster6tab,y           ;4 
       sta    PrintTemp+5             ;3 
       lda    Monster7tab,y           ;4 
       sta    $DA                     ;3 
       lda    PrintTemp+10            ;3 
       bne    MLFA40                  ;2 
       lda    PrintTemp+11            ;3 
       lsr                            ;2 
       bcc    MLFA39                  ;2 
       inc    PrintTemp+11            ;5 
       bcs    MLFA49                  ;2 
MLFA39:
       ldy    #$01                    ;2 
MLFA3B:
       dey                            ;2 
       bpl    MLFA3B                  ;2 
       bmi    MLFA49                  ;2 
MLFA40:
       lsr                            ;2 
       tay                            ;2 
       lda.wy $CB,y                   ;4 
       sta    $CB                     ;3 
       inc    PrintTemp+11            ;5 
MLFA49:
       ldy    $FD                     ;3 
       lda    Pac3tab,y               ;4 
       sta    GRP1                    ;3 
       lda    $B1                     ;3 
       sta    GRP0                    ;3 
       lda    NMaze1cTab,x            ;4 
       sta    PF0                     ;3 
       lda    NMaze2cTab,x            ;4 
       sta    PF1                     ;3 
       lda    NMaze3cTab,x            ;4 
       sta    PF2                     ;3 
       ldy    $FD                     ;3 
       lda    Pac4tab,y               ;4 
       sta    $B1                     ;3 
       lda    Pac5tab,y               ;4 
       sta    $B2                     ;3 
       cpx    #$15                    ;2 <-adjust X
       beq    QPlayfield_no_dots      ;2 
       lda    PrintTemp+10            ;3 
       beq    MLFAB9                  ;2 
       ldy    PrintTemp+8             ;3 
       lda    IndHighTab-1,y          ;4 load high jump vector
       sta    IndAdr+1                ;3 
       jmp.ind (IndAdr)               ;5 
MLFAB9:
       ldy    $FD                     ;3 
       lda    Pac6tab,y               ;4 
       sta    $B3                     ;3 
       lda    $B1                     ;3 
       sta    WSYNC                   ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+6             ;3 
       sta    GRP0                    ;3 
       ldy    #$08                    ;2 
MLFACC:
       dey                            ;2 
       bne    MLFACC                  ;2 
MLFA81:
       lda    RamDots,x               ;4 
       tay                            ;2 
       and    #$2A                    ;2 
       sta    PF2                     ;3 
       tya                            ;2 
       and    #$80                    ;2 
       sta    WSYNC                   ;3 
       sta    PF0                     ;3 
       lda    #$0E                    ;2 
       sta    COLUPF                  ;3 
       lda    $B2                     ;3 
       sta    GRP1                    ;3 
       lda    PrintTemp+7             ;3 
       sta    GRP0                    ;3 
       tya                            ;2 
       and    #$55                    ;2 
       sta    PF1                     ;3 
       lda    #$00                    ;2 
MLFAA2:
       sta    CTRLPF                  ;3 
       lda    RamDots+21,x            ;4 
       tay                            ;2 
       and    #$40                    ;2 
       sta    PF0                     ;3 
       tya                            ;2 
       and    #$AA                    ;2 
       sta    PF1                     ;3 
       tya                            ;2 
       and    #$15                    ;2 
       sta    PF2                     ;3 
       inx                            ;2 
       jmp    MLF920                  ;3 

QPlayfield_no_dots:
       sta    WSYNC                   ;3 
       lda    #$00                    ;2 
       sta    GRP0                    ;3 
       sta    GRP1                    ;3 
       sta    HMP1                    ;3 
       lda    #$80                    ;2 
       sta    HMP0                    ;3 
       sta    $B1                     ;3 
       nop                            ;2 
       sta    RESP1                   ;3 
       nop                            ;2 
       nop                            ;2 
       ldy    #$05                    ;2 
       jmp    Display_skipline        ;3 





;  ORG $1AF1
;  RORG $DAF1
;      nop




  ORG $1B11
  RORG $DB11

;maze1a (right side)
NMaze1aTab:
       .byte $E0 ;ff4a |XXX     |
       .byte $20 ;ff4b |  X     |
       .byte $20 ;ff4c |  X     |
       .byte $20 ;ff4d |  X     |
       .byte $20 ;ff4e |  X     |
       .byte $20 ;ff4f |  X     |
       .byte $E0 ;ff50 |XXX     |
       .byte $00 ;fd63 |        |
       .byte $00 ;fd63 |        |
       .byte $00 ;ff51 |        |
       .byte $00 ;ff52 |        |
       .byte $00 ;ff53 |        |
       .byte $E0 ;ff54 |XXX     |
       .byte $00 ;ff55 |        |
       .byte $20 ;ff56 |  X     |
       .byte $20 ;ff57 |  X     |

;maze1b (right side)
NMaze1bTab:
       .byte $20 ;003c |  X     |(shared w/above)
       .byte $20 ;003d |  X     |(shared w/above)
       .byte $20 ;003e |  X     |(shared w/above)
       .byte $20 ;003f |  X     |(shared w/above)
       .byte $20 ;0040 |  X     |(shared w/above)
       .byte $20 ;0041 |  X     |(shared w/above)
       .byte $00 ;0042 |        |
       .byte $00 ;fd63 |        |
       .byte $00 ;fd63 |        |
       .byte $00 ;0043 |        |
       .byte $00 ;0044 |        |
       .byte $00 ;0045 |        |
       .byte $00 ;0046 |        |
       .byte $00 ;0047 |        |
       .byte $20 ;0048 |  X     |
       .byte $20 ;0049 |  X     |

;maze1c (right side)
NMaze1cTab:
       .byte $20 ;0078 |  X     |(shared w/above)
       .byte $20 ;0079 |  X     |(shared w/above)
       .byte $20 ;007a |  X     |(shared w/above)
       .byte $20 ;007b |  X     |(shared w/above)
       .byte $20 ;007c |  X     |(shared w/above)
       .byte $20 ;007d |  X     |(shared w/above)
       .byte $00 ;0080 |        |
       .byte $00 ;0080 |        |
       .byte $00 ;007e |        |
       .byte $E0 ;007f |XXX     |
       .byte $00 ;0080 |        |
       .byte $00 ;0081 |        |
       .byte $00 ;0082 |        |
       .byte $E0 ;0083 |XXX     |
       .byte $20 ;0084 |  X     |
       .byte $20 ;0085 |  X     |
       .byte $20 ;0086 |  X     |
       .byte $E0 ;0087 |XXX     |
       .byte $20 ;0088 |  X     |
       .byte $20 ;0089 |  X     |
       .byte $20 ;008a |  X     |
       .byte $E0 ;008b |XXX     |

;maze3b (right side)
NMaze3bTab:
       .byte $80 ;ff19 |X       |
       .byte $80 ;ff1a |X       |
       .byte $00 ;ff1b |        |
       .byte $00 ;ff1c |        |
       .byte $80 ;ff1d |X       |
       .byte $80 ;ff1e |X       |
       .byte $00 ;ff1f |        |
       .byte $00 ;fd63 |        |
       .byte $88 ;ff21 |X   X   |<-door
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;ff22 |    X   |
       .byte $00 ;ff23 |        |
       .byte $00 ;ff24 |        |

;maze3c (right side)
NMaze3cTab:
       .byte $80 ;ff25 |X       |(shared w/above)
       .byte $80 ;ff26 |X       |(shared w/above)
       .byte $00 ;ff27 |        |(shared w/above)
       .byte $00 ;ff28 |        |(shared w/above)
       .byte $80 ;ff29 |X       |(shared w/above)
       .byte $80 ;ff2a |X       |(shared w/above)
       .byte $00 ;ff2b |        |(shared w/above)
       .byte $00 ;fd63 |        |(shared w/above)
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;ff2d |    X   |
       .byte $F8 ;ff2e |XXXXX   |
       .byte $00 ;ff2f |        |
       .byte $00 ;ff30 |        |
       .byte $80 ;ff31 |X       |
       .byte $80 ;ff32 |X       |
       .byte $00 ;ff33 |        |
       .byte $00 ;ff34 |        |
       .byte $80 ;ff35 |X       |
       .byte $8F ;ff36 |X   XXXX|
       .byte $00 ;fdde |        |
;maze2a (left side)
NMaze2aTab:
       .byte $FF ;fd50 |XXXXXXXX|(shared w/above)
       .byte $00 ;fd51 |        |
       .byte $71 ;fd52 | XXX   X|
       .byte $00 ;fd53 |        |
       .byte $71 ;fd54 | XXX   X|
       .byte $01 ;fd55 |       X|
       .byte $F1 ;fd56 |XXXX   X|
       .byte $11 ;fd57 |   X   X|
       .byte $11 ;fd57 |   X   X|
       .byte $11 ;fd57 |   X   X|
       .byte $00 ;fd58 |        |
       .byte $00 ;fd59 |        |
       .byte $F1 ;fd5a |XXXX   X|
       .byte $11 ;fd5b |   X   X|
       .byte $00 ;fd5c |        |
       .byte $00 ;fd5d |        |
       .byte $71 ;fd5e | XXX   X|
       .byte $10 ;fd5f |   X    |
       .byte $00 ;fd60 |   X    |
       .byte $01 ;fd61 |       X|
;maze2b (left side)
NMaze2bTab:
       .byte $00 ;fdca |        |(shared w/above)
       .byte $00 ;fdcb |        |(shared w/above)
       .byte $00 ;fdcc |        |
       .byte $00 ;fdcd |        |
       .byte $01 ;fdce |       X|
       .byte $01 ;fdcf |       X|
       .byte $11 ;fdd0 |   X   X|
       .byte $11 ;fdd1 |   X   X|
       .byte $11 ;fdd1 |   X   X|
       .byte $11 ;fdd1 |   X   X|
       .byte $00 ;fdd2 |        |
       .byte $00 ;fdd3 |        |
       .byte $11 ;fdd4 |   X   X|
       .byte $11 ;fdd5 |   X   X|
       .byte $00 ;fdd6 |        |
       .byte $00 ;fdd7 |        |
       .byte $10 ;fdd8 |   X    |
       .byte $10 ;fdd9 |   X    |
       .byte $01 ;fdda |       X|
       .byte $01 ;fddb |       X|
;maze2c (left side)
NMaze2cTab:
       .byte $00 ;fdde |        |(shared w/above)
       .byte $00 ;fddf |        |(shared w/above)
       .byte $00 ;fdde |        |
       .byte $00 ;fddf |        |
       .byte $01 ;fde0 |       X|
       .byte $01 ;fde1 |       X|
       .byte $11 ;fde2 |   X   X|
       .byte $11 ;fde2 |   X   X|
       .byte $11 ;fde2 |   X   X|
       .byte $F1 ;fde3 |XXXX   X|
       .byte $00 ;fde4 |        |
       .byte $00 ;fde5 |        |
       .byte $11 ;fde6 |   X   X|
       .byte $F1 ;fde7 |XXXX   X|
       .byte $00 ;fde8 |        |
       .byte $00 ;fde9 |   X    |
       .byte $10 ;fdea |   X    |
       .byte $10 ;fdeb |   X    |
       .byte $01 ;fdec |       X|
       .byte $7F ;fded | XXXXXXX|
       .byte $00 ;fdde |        |

;maze3a (right side)
NMaze3aTab:
       .byte $FF ;fdb8 |XXXXXXXX|(shared w/above)
       .byte $80 ;fdb9 |X       |
       .byte $0F ;fdba |    XXXX|
       .byte $00 ;fdbb |        |
       .byte $F8 ;fdbc |XXXXX   |
       .byte $80 ;fdbd |X       |
       .byte $0F ;fdbe |    XXXX|
       .byte $00 ;fdc7 |        |
       .byte $78 ;fdc0 | XXXX   |<-Bit 7=Small door in box
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;fdc1 |    X   |
       .byte $00 ;fdc2 |        |
       .byte $00 ;fdc3 |        |
       .byte $F8 ;fdc4 |XXXXX   |
       .byte $80 ;fdc5 |X       |
       .byte $0F ;fdc6 |    XXXX|
       .byte $00 ;fdc7 |        |
       .byte $F8 ;fdc8 |XXXXX   |
       .byte $80 ;fdc9 |X       |
Byte_test1_tab:
       .byte $00 ; |        | $F3fe(shared w/above)
       .byte $00 ; |        | $F3ff(shared w/above)
       .byte $00 ; |        | $F36A
       .byte $01 ; |       X| $F3ff
       .byte $03 ; |      XX| $F36A


Digit4tab:
       .byte $0C ;ff7f |    XX  |
       .byte $0C ;ff7f |    XX  |
       .byte $FE ;ff81 |XXXXXXX |
       .byte $4C ;ff83 | X  XX  |
       .byte $2C ;ff83 |  X XX  |
       .byte $1C ;ff83 |   XXX  |
       .byte $0C ;ff7b |    XX  |
Digit1tab:
       .byte $18 ;ff7f |   XX   |
       .byte $18 ;ff7b |   XX   |
       .byte $18 ;ff7b |   XX   |
       .byte $18 ;ff7b |   XX   |
       .byte $18 ;ff7b |   XX   |
       .byte $38 ;ff7b |  XXX   |
Digit7tab:
       .byte $18 ;ff7c |   XX   |(shared w/above)
       .byte $18 ;ff7c |   XX   |
       .byte $18 ;ff7d |   XX   |
       .byte $18 ;ff7e |   XX   |
       .byte $0C ;ff7f |    XX  |
       .byte $06 ;ff7f |     XX |
Digit2tab:
       .byte $7E ;ff84 | XXXXXX |(shared w/above)
       .byte $30 ;ff86 |  XX    |
       .byte $18 ;ff86 |   XX   |
       .byte $0C ;ff87 |    XX  |
       .byte $06 ;ff8b |     XX |
       .byte $66 ;ff89 | XX  XX |
Digit6tab:
       .byte $3C ;ff81 |  XXXX  |(shared w/above)
       .byte $46 ;ff83 | X   XX |
       .byte $46 ;ff83 | X   XX |
       .byte $7C ;ff84 | XXXXX  |
       .byte $40 ;ff86 | X      |
       .byte $40 ;ff86 | X      |
Digit3tab:
       .byte $3C ;ff87 |  XXXX  |(shared w/above)
       .byte $46 ;ff8b | X   XX |
       .byte $06 ;ff89 |     XX |
       .byte $3C ;ff8a |  XXXX  |
       .byte $18 ;ff8b |   XX   |
       .byte $0C ;ff8b |    XX  |
       .byte $7E ;ff8d | XXXXXX |
Digit5tab:
       .byte $3C ;ff8a |  XXXX  |
       .byte $46 ;ff8b | X   XX |
       .byte $06 ;ff8b |     XX |
       .byte $06 ;ff8d |     XX |
       .byte $7C ;ff8f | XXXXX  |
       .byte $40 ;ff8f | X      |
       .byte $7E ;ff9c | XXXXXX |
Digit9tab:
       .byte $06 ;ff7e |     XX |
       .byte $06 ;ff7e |     XX |
       .byte $3E ;ff81 |  XXXXX |
       .byte $46 ;ff81 | X   XX |
       .byte $46 ;ff83 | X   XX |
       .byte $46 ;ff83 | X   XX |
Digit0tab:
       .byte $3C ;ff9c |  XXXX  |(shared w/above)
       .byte $46 ;ff97 | X   XX |
       .byte $46 ;ff9a | X   XX |
       .byte $46 ;ff83 | X   XX |
       .byte $46 ;ff83 | X   XX |
       .byte $46 ;ff9b | X   XX |
Digit8tab:
       .byte $3C ;ff9c |  XXXX  |(shared w/above)
       .byte $62 ;ff83 | XX   X |
       .byte $62 ;ff92 | XX   X |
       .byte $3C ;ff93 |  XXXX  |
       .byte $26 ;ff83 |  X  XX |
       .byte $26 ;ff94 |  X  XX |
       .byte $1C ;ff9c |   XXX  |

  ORG $1C00
  RORG $DC00

;indirect jump high byte values
IndHighTab:
       .byte >Ind1 ; $F101
       .byte >Ind1 ; $F102
       .byte >Ind2 ; $F103
       .byte >Ind3 ; $F104
       .byte >Ind4 ; $F105
       .byte >Ind5 ; $F106
       .byte >Ind6 ; $F107
       .byte >Ind7 ; $F108
       .byte >Ind8 ; $F109
       .byte >Ind9 ; $F10A

;fruit colors
FruitColorTab:
       .byte $32 ;ffd5 |  XX  X | Cherries
       .byte $38 ;ffd6 |  XXX   | Strawberry
       .byte $38 ;ffd7 |XXXX XX | Orange1
       .byte $3A ;ffd8 |XXXX XX | Orange2
       .byte $32 ;ffd9 |  XX X  | Apple1
       .byte $34 ;ffda |  XX X  | Apple2
       .byte $D4 ;ffdb | X X X  | Grapes1
       .byte $D6 ;ffdc | X X X  | Grapes2
       .byte $46 ;ffdd |XX XX   | Lime1
       .byte $48 ;ffde |XX XX   | Lime2
       .byte $18 ;ffdf |   XX X | Grapefruit1
       .byte $1A ;ffe0 |   XX X | Grapefruit2
       .byte $20 ;ffe1 |X X X   | Crabapple1
       .byte $22 ;ffe2 |X X X   | Crabapple2
       .byte $24 ;ffe3 |X X X   | Crabapple3
       .byte $26 ;ffe4 |X X X   | Crabapple4
       .byte $28 ;ffe5 |X X X   | Crabapple5
       .byte $28 ;ffe5 |X X X   | Crabapple6+

L16X:                                 ;  (16 cycle JSR)
       nop                            ;2 
       nop                            ;2 
L12_1:                                ;  (12 cycle JSR)
       rts                            ;6 

DigZ:
       .byte $00
       .byte $73 ;ffbf | XXX  XX|
       .byte $72 ;ffc0 | XXX  X |
       .byte $7E ;ffc1 | XXXXXX |
       .byte $72 ;ffc2 | XXX  X |
       .byte $72 ;ffc3 | XXX  X |
DigP:
       .byte $00 ;(shared w/above)
       .byte $F9 ;ffb2 |XXXXX  X|
       .byte $DB ;ffb3 |XX XX XX|
       .byte $7B ;ffb4 | XXXX XX|
       .byte $3B ;ffb5 |  XXX XX|
       .byte $19 ;ffb7 |   XX  X|
DigK:
       .byte $00 ;(shared w/above)
       .byte $EF ;ff9c |XXX XXXX|
       .byte $0F ;ff9d |    XXXX|
       .byte $CE ;ff9e |XX  XXX |
       .byte $0C ;ff9f |    XX  |
       .byte $E8 ;ffa0 |XXX X   |
DigC:
       .byte $00 ;(shared w/above)
       .byte $63 ;ffab | XX   XX|
       .byte $C3 ;ffac |XX    XX|
       .byte $83 ;ffad |X     XX|
       .byte $C3 ;ffae |XX    XX|
       .byte $6B ;ffaf | XX X XX|
       .byte $0C
DigU:
       .byte $C0
       .byte $EE ;ffa4 |XXX XXX |
       .byte $8E ;ffa5 |X   XXX |
       .byte $0F ;ffa6 |    XXXX|<-bit 0 used for the "K" character
       .byte $8E ;ffa7 |X   XXX |
       .byte $EE ;ffa8 |XXX XXX |
       .byte $C0
DigB:
       .byte $00
       .byte $E8 ;ffb8 |XXX X   |
       .byte $E0 ;ffb9 |XXX     |
       .byte $EC ;ffba |XXX XX  |
       .byte $6E ;ffbb | XX XXX |
       .byte $2F ;ffbc |  X XXXX|
DigT:
       .byte $00 ;(shared w/above)
       .byte $E0 ;ffb8 |XXX     |
       .byte $E0 ;ffc0 |XXX     |
       .byte $EE ;ffc1 |XXX XXX |
       .byte $64 ;ffc2 | XX  X  |
       .byte $22 ;ffc3 |  X   X |
       .byte $0C ;     |    XX  |

;maze3b (right side)
MMaze3bTab:
       .byte $00 ;ff19 |        |
       .byte $00 ;ff1a |        |
       .byte $00 ;ff1b |        |
       .byte $00 ;ff1c |        |
       .byte $00 ;ff1d |        |
       .byte $00 ;ff1e |        |
       .byte $00 ;ff1f |        |
       .byte $00 ;fd63 |        |
       .byte $88 ;ff21 |X   X   |<-door
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;ff22 |    X   |

;maze3c (right side)
MMaze3cTab:
       .byte $00 ;ff25 |        |(shared w/above)
       .byte $00 ;ff26 |        |(shared w/above)
       .byte $00 ;ff27 |        |(shared w/above)
       .byte $00 ;ff28 |        |(shared w/above)
       .byte $00 ;ff29 |        |(shared w/above)
       .byte $00 ;ff2a |        |(shared w/above)
       .byte $00 ;ff2b |        |(shared w/above)
       .byte $00 ;fd63 |        |(shared w/above)
       .byte $08 ;fdc1 |    X   |(shared w/above)
       .byte $08 ;fdc1 |    X   |(shared w/above)
       .byte $08 ;ff2d |    X   |
       .byte $F8 ;ff2e |XXXXX   |
       .byte $00 ;ff2f |        |
       .byte $00 ;ff30 |        |
       .byte $00 ;ff31 |        |
       .byte $00 ;ff32 |        |
       .byte $00 ;ff33 |        |
       .byte $00 ;ff34 |        |
       .byte $00 ;ff35 |        |
       .byte $00 ;ff36 |        |
       .byte $08 ;fdde |    X   |
       .byte $8F ;fddf |X   XXXX|<-add tunnel

;maze2a (left side)
Maze2aTab:
       .byte $FF ;fd50 |XXXXXXXX|(shared w/above)
       .byte $00 ;fd51 |        |
       .byte $71 ;fd52 | XXX   X|
       .byte $00 ;fd53 |        |
       .byte $71 ;fd54 | XXX   X|
       .byte $01 ;fd55 |       X|
       .byte $11 ;fd56 |   X   X|
       .byte $11 ;fd57 |   X   X|
       .byte $00 ;fd57 |        |
       .byte $00 ;fd57 |        |
       .byte $10 ;fd58 |   X    |
       .byte $10 ;fd59 |   X    |
       .byte $11 ;fd5a |   X   X|
       .byte $11 ;fd5b |   X   X|
       .byte $00 ;fd5c |        |
       .byte $00 ;fd5d |        |
       .byte $71 ;fd5e | XXX   X|
       .byte $10 ;fd5f |   X    |
       .byte $00 ;fd60 |   X    |
       .byte $01 ;fd61 |       X|

;maze2b (left side)
Maze2bTab:
       .byte $00 ;fdca |        |(shared w/above)
       .byte $00 ;fdcb |        |(shared w/above)
       .byte $00 ;fdcc |        |
       .byte $00 ;fdcd |        |
       .byte $01 ;fdce |       X|
       .byte $01 ;fdcf |       X|
       .byte $11 ;fdd0 |   X   X|
       .byte $11 ;fdd1 |   X   X|
       .byte $00 ;fdd1 |        |
       .byte $00 ;fdd1 |        |
       .byte $10 ;fdd2 |        |
       .byte $10 ;fdd3 |        |
       .byte $11 ;fdd4 |   X   X|
       .byte $11 ;fdd5 |   X   X|
       .byte $00 ;fdd6 |        |
       .byte $00 ;fdd7 |        |
       .byte $10 ;fdd8 |   X    |
       .byte $10 ;fdd9 |   X    |
       .byte $01 ;fdda |       X|
       .byte $01 ;fddb |       X|

;maze2c (left side)
Maze2cTab:
       .byte $00 ;fdde |        |(shared w/above)
       .byte $00 ;fddf |        |(shared w/above)
       .byte $00 ;fdde |        |
       .byte $00 ;fddf |        |
       .byte $01 ;fde0 |       X|
       .byte $01 ;fde1 |       X|
       .byte $11 ;fde2 |   X   X|
       .byte $11 ;fde2 |   X   X|
       .byte $00 ;fde2 |        |
       .byte $01 ;fde3 |       X|
       .byte $10 ;fde4 |   X    |
       .byte $10 ;fde5 |   X    |
       .byte $11 ;fde6 |   X   X|
       .byte $11 ;fde7 |   X   X|
       .byte $00 ;fde8 |        |
       .byte $00 ;fde9 |   X    |
       .byte $10 ;fdea |   X    |
       .byte $10 ;fdeb |   X    |
       .byte $01 ;fdec |       X|
       .byte $71 ;fded | XXX   X|
       .byte $00 ;fdde |        |

;maze3a (right side)
Maze3aTab:
       .byte $FF ;fdb8 |XXXXXXXX|(shared w/above)
       .byte $00 ;fdb9 |        |
       .byte $0F ;fdba |    XXXX|
       .byte $80 ;fdbb |X       |
       .byte $F8 ;fdbc |XXXXX   |
       .byte $80 ;fdbd |X       |
       .byte $0F ;fdbe |    XXXX|
       .byte $00 ;fdc7 |        |
       .byte $78 ;fdc0 | XXXX   |<-Bit 7=Small door in box
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;fdc1 |    X   |
       .byte $00 ;fdc2 |        |
       .byte $00 ;fdc3 |        |
       .byte $80 ;fdc4 |X       |
       .byte $80 ;fdc5 |X       |
       .byte $0F ;fdc6 |    XXXX|
       .byte $00 ;fdc7 |        |
       .byte $F8 ;fdc8 |XXXXX   |
       .byte $80 ;fdc9 |X       |

;maze3b (right side)
Maze3bTab:
       .byte $00 ;ff19 |        |(shared w/above)
       .byte $00 ;ff1a |        |(shared w/above)
       .byte $80 ;ff1b |X       |
       .byte $80 ;ff1c |X       |
       .byte $80 ;ff1d |X       |
       .byte $80 ;ff1e |X       |
       .byte $00 ;ff1f |        |
       .byte $00 ;fd63 |        |
       .byte $88 ;ff21 |X   X   |<-door
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;ff22 |    X   |
       .byte $00 ;ff23 |        |
       .byte $00 ;ff24 |        |
       .byte $80 ;ff25 |X       |
       .byte $80 ;ff26 |X       |
       .byte $00 ;ff27 |        |
       .byte $00 ;ff28 |        |
       .byte $80 ;ff29 |X       |
       .byte $80 ;ff2a |X       |

;maze3c (right side)
Maze3cTab:
       .byte $00 ;ff25 |        |(shared w/above)
       .byte $00 ;ff26 |        |(shared w/above)
       .byte $80 ;ff27 |X       |
       .byte $80 ;ff28 |X       |
       .byte $80 ;ff29 |X       |
       .byte $80 ;ff2a |X       |
       .byte $00 ;ff2b |        |
       .byte $00 ;fd63 |        |
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;ff2d |    X   |
       .byte $F8 ;ff2e |XXXXX   |
       .byte $00 ;ff2f |        |
       .byte $0F ;ff30 |    XXXX|
       .byte $80 ;ff31 |X       |
       .byte $80 ;ff32 |X       |
       .byte $00 ;ff33 |        |
       .byte $00 ;ff34 |        |
       .byte $80 ;ff35 |X       |
       .byte $88 ;ff36 |X   X   |
       .byte $00 ;fdde |        |

;maze2a (left side)
MMaze2aTab:
       .byte $FF ;fd50 |XXXXXXXX|(shared w/above)

;maze2b (left side)
MMaze2bTab:
       .byte $00 ;fd51 |        |(shared w/above)
;maze2c (left side)
MMaze2cTab:
       .byte $00 ;fd52 |        |(shared w/above)
       .byte $00 ;fd53 |        |(shared w/above)
       .byte $00 ;fd54 |        |(shared w/above)
       .byte $00 ;fd55 |        |(shared w/above)
       .byte $00 ;fd56 |        |(shared w/above)
       .byte $00 ;fd57 |        |(shared w/above)
       .byte $00 ;fd57 |        |(shared w/above)
       .byte $00 ;fd57 |        |(shared w/above)
       .byte $00 ;fd58 |        |(shared w/above)
       .byte $00 ;fd59 |        |(shared w/above)
       .byte $00 ;fd5a |        |(shared w/above)
       .byte $00 ;fd5b |        |(shared w/above)
       .byte $00 ;fd5c |        |(shared w/above)
       .byte $00 ;fd5d |        |(shared w/above)
       .byte $00 ;fd5e |        |(shared w/above)
       .byte $00 ;fd5f |        |(shared w/above)
       .byte $00 ;fd60 |        |(shared w/above)
       .byte $00 ;fd61 |        |(shared w/above)
       .byte $00 ;fd62 |        |(shared w/above)
       .byte $00 ;fd62 |       X|(shared w/above)
       .byte $01 ;fddd |       X|

       .byte $FF ;fd50 |XXXXXXXX|(shared w/above)

  ORG $1D00
  RORG $DD00

Pac1tab:
       .byte $00 ; |        | $F200
Pac2tab:
       .byte $00 ; |        | $F201
Pac3tab:
       .byte $00 ; |        | $F202
Pac4tab:
       .byte $00 ; |        | $F203
Pac5tab:
       .byte $00 ; |        | $F204
Pac6tab:
       .byte $00 ; |        | $F205
Pac7tab:
       .byte $00 ; |        | $F206
Pac8tab:
       .byte $00 ; |        | $F207
       .byte $1C ; |   XXX  | $F208 00
       .byte $3E ; |  XXXXX | $F209
       .byte $7F ; | XXXXXXX| $F20A
       .byte $7F ; | XXXXXXX| $F20B
       .byte $7F ; | XXXXXXX| $F20C
       .byte $7F ; | XXXXXXX| $F20D
       .byte $7F ; | XXXXXXX| $F20E
       .byte $3E ; |  XXXXX | $F20F
       .byte $1C ; |   XXX  | $F210
       .byte $00 ; |        | $F211
       .byte $00 ; |        | $F212
       .byte $00 ; |        | $F213
       .byte $00 ; |        | $F214
       .byte $00 ; |        | $F215
       .byte $00 ; |        | $F216
       .byte $00 ; |        | $F217

       .byte $00 ; |        | $F218
       .byte $1C ; |   XXX  | $F219 11
       .byte $3E ; |  XXXXX | $F21A
       .byte $7F ; | XXXXXXX| $F21B
       .byte $7C ; | XXXXX  | $F21C
       .byte $70 ; | XXX    | $F21D
       .byte $7C ; | XXXXX  | $F21E
       .byte $7F ; | XXXXXXX| $F21F
       .byte $3E ; |  XXXXX | $F220
       .byte $1C ; |   XXX  | $F221
       .byte $00 ; |        | $F222
       .byte $00 ; |        | $F223
       .byte $00 ; |        | $F224
       .byte $00 ; |        | $F225
       .byte $00 ; |        | $F226
       .byte $00 ; |        | $F227
       .byte $00 ; |        | $F228

       .byte $00 ; |        | $F218
       .byte $1C ; |   XXX  | $F219 22
       .byte $3E ; |  XXXXX | $F21A
       .byte $7C ; | XXXXX  | $F21B
       .byte $78 ; | XXXX   | $F21C
       .byte $70 ; | XXX    | $F21D
       .byte $78 ; | XXXX   | $F21E
       .byte $7C ; | XXXXX  | $F21F
       .byte $3E ; |  XXXXX | $F220
       .byte $1C ; |   XXX  | $F221
       .byte $00 ; |        | $F222
       .byte $00 ; |        | $F223
       .byte $00 ; |        | $F224
       .byte $00 ; |        | $F225
       .byte $00 ; |        | $F226
       .byte $00 ; |        | $F227
       .byte $00 ; |        | $F228

       .byte $00 ; |        | $F229
       .byte $1C ; |   XXX  | $F22A 33
       .byte $3E ; |  XXXXX | $F22B
       .byte $7F ; | XXXXXXX| $F22C
       .byte $1F ; |   XXXXX| $F22D
       .byte $07 ; |     XXX| $F22E
       .byte $1F ; |   XXXXX| $F22F
       .byte $7F ; | XXXXXXX| $F230
       .byte $3E ; |  XXXXX | $F231
       .byte $1C ; |   XXX  | $F232
       .byte $00 ; |        | $F233
       .byte $00 ; |        | $F234
       .byte $00 ; |        | $F235
       .byte $00 ; |        | $F236
       .byte $00 ; |        | $F237
       .byte $00 ; |        | $F238
       .byte $00 ; |        | $F239

       .byte $00 ; |        | $F229
       .byte $1C ; |   XXX  | $F22A 44
       .byte $3E ; |  XXXXX | $F22B
       .byte $1F ; |   XXXXX| $F22C
       .byte $0F ; |    XXXX| $F22D
       .byte $07 ; |     XXX| $F22E
       .byte $0F ; |    XXXX| $F22F
       .byte $1F ; |   XXXXX| $F230
       .byte $3E ; |  XXXXX | $F231
       .byte $1C ; |   XXX  | $F232
       .byte $00 ; |        | $F233
       .byte $00 ; |        | $F234
       .byte $00 ; |        | $F235
       .byte $00 ; |        | $F236
       .byte $00 ; |        | $F237
       .byte $00 ; |        | $F238
       .byte $00 ; |        | $F239

       .byte $00 ; |        | $F24B
       .byte $1C ; |   XXX  | $F24C 66
       .byte $3E ; |  XXXXX | $F24D
       .byte $7F ; | XXXXXXX| $F24E
       .byte $7F ; | XXXXXXX| $F24F
       .byte $7F ; | XXXXXXX| $F250
       .byte $7F ; | XXX XXX| $F251
       .byte $77 ; | XXX XXX| $F252
       .byte $36 ; |  XX XX | $F253
       .byte $14 ; |   X X  | $F244
       .byte $00 ; |        | $F245
       .byte $00 ; |        | $F246
       .byte $00 ; |        | $F247
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F249
       .byte $00 ; |        | $F24A
       .byte $00 ; |        | $F24A

       .byte $00 ; |        | $F24B
       .byte $1C ; |   XXX  | $F24C 55
       .byte $3E ; |  XXXXX | $F24D
       .byte $7F ; | XXXXXXX| $F24E
       .byte $77 ; | XXX XXX| $F24F
       .byte $77 ; | XXX XXX| $F250
       .byte $63 ; | XX   XX| $F251
       .byte $63 ; | XX   XX| $F252
       .byte $22 ; |  X   X | $F253
       .byte $00 ; |        | $F244
       .byte $00 ; |        | $F245
       .byte $00 ; |        | $F246
       .byte $00 ; |        | $F247
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F249
       .byte $00 ; |        | $F24A
       .byte $00 ; |        | $F24A
;death0:
       .byte $00 ; |        | $F23A
       .byte $14 ; |   X X  | $F23B 88
       .byte $36 ; |  XX XX | $F23C
       .byte $77 ; | XXX XXX| $F23D
       .byte $7F ; | XXX XXX| $F23E
       .byte $7F ; | XXXXXXX| $F23F
       .byte $7F ; | XXXXXXX| $F240
       .byte $7F ; | XXXXXXX| $F241
       .byte $3E ; |  XXXXX | $F242
       .byte $1C ; |   XXX  | $F243
       .byte $00 ; |        | $F244
       .byte $00 ; |        | $F245
       .byte $00 ; |        | $F246
       .byte $00 ; |        | $F247
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248

;death1:
       .byte $00 ; |        | $F23A
       .byte $00 ; |        | $F23B 88
       .byte $22 ; |  X   X | $F23C
       .byte $63 ; | XX   XX| $F23D
       .byte $63 ; | XX   XX| $F23E
       .byte $77 ; | XXX XXX| $F23F
       .byte $77 ; | XXX XXX| $F240
       .byte $7F ; | XXXXXXX| $F241
       .byte $3E ; |  XXXXX | $F242
       .byte $1C ; |   XXX  | $F243
       .byte $00 ; |        | $F244
       .byte $00 ; |        | $F245
       .byte $00 ; |        | $F246
       .byte $00 ; |        | $F247
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F249
       .byte $00 ; |        | $F24A
;death2:
       .byte $00 ; |        | $F23A
       .byte $00 ; |        | $F23B B2
       .byte $00 ; |        | $F23C
       .byte $00 ; |        | $F23D
       .byte $00 ; |        | $F23E
       .byte $41 ; | X     X| $F23F
       .byte $7F ; | XXXXXXX| $F240
       .byte $7F ; | XXXXXXX| $F241
       .byte $3E ; |  XXXXX | $F242
       .byte $1C ; |   XXX  | $F243
       .byte $00 ; |        | $F244
       .byte $00 ; |        | $F245
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
;death3:
       .byte $00 ; |        | $F23A
       .byte $00 ; |        | $F23B BE
       .byte $00 ; |        | $F23C
       .byte $00 ; |        | $F23D
       .byte $00 ; |        | $F23E
       .byte $00 ; |        | $F23F
       .byte $1C ; |   XXX  | $F240
       .byte $7F ; | XXXXXXX| $F241
       .byte $3E ; |  XXXXX | $F242
       .byte $1C ; |   XXX  | $F243
       .byte $00 ; |        | $F244
       .byte $00 ; |        | $F245
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
;death4:
       .byte $00 ; |        | $F23A
       .byte $00 ; |        | $F23B CA
       .byte $00 ; |        | $F23C
       .byte $00 ; |        | $F23D
       .byte $00 ; |        | $F23E
       .byte $00 ; |        | $F23F
       .byte $08 ; |    X   | $F240
       .byte $1C ; |   XXX  | $F241
       .byte $3E ; |  XXXXX | $F242
       .byte $1C ; |   XXX  | $F243
       .byte $00 ; |        | $F244
       .byte $00 ; |        | $F245
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
;death5:
       .byte $00 ; |        | $F23A
       .byte $00 ; |        | $F23B D6
       .byte $00 ; |        | $F23C
       .byte $00 ; |        | $F23D
       .byte $00 ; |        | $F23E
       .byte $00 ; |        | $F23F
       .byte $08 ; |    X   | $F240
       .byte $08 ; |    X   | $F241
       .byte $1C ; |   XXX  | $F242
       .byte $1C ; |   XXX  | $F243
       .byte $00 ; |        | $F244
       .byte $00 ; |        | $F245
       .byte $00 ; |        | $F246
       .byte $00 ; |        | $F247
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F249
       .byte $00 ; |        | $F24A


       .byte $00 ; |        | $F23A
       .byte $08 ; |    X   | $F23B D6
       .byte $08 ; |    X   | $F23C
       .byte $49 ; | X  X  X| $F23D
       .byte $22 ; |  X   X | $F23E
       .byte $08 ; |    X   | $F23F
       .byte $22 ; |  X   X | $F240
       .byte $49 ; | X  X  X| $F241
       .byte $08 ; |    X   | $F242
       .byte $08 ; |    X   | $F243
       .byte $00 ; |        | $F244
       .byte $00 ; |        | $F245
       .byte $00 ; |        | $F246
       .byte $00 ; |        | $F247
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F249
       .byte $00 ; |        | $F24A




       .byte $00 ; |        | $F23A
       .byte $00 ; |        | $F23B 97
       .byte $00 ; |        | $F23C
       .byte $00 ; |        | $F244
       .byte $00 ; |        | $F245
       .byte $00 ; |        | $F246
       .byte $00 ; |        | $F246
       .byte $00 ; |        | $F247
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248
       .byte $00 ; |        | $F248

  ORG $1E00
  RORG $DE00

Monster1tab:
       .byte $00 ;fe0b |        |
Monster2tab:
       .byte $00 ;fe0c |        |
Monster3tab:
       .byte $00 ;fe0d |        |
Monster4tab:
       .byte $00 ;fe0e |        |
Monster5tab:
       .byte $00 ;fe0f |        |
Monster6tab:
       .byte $00 ;fe10 |        |
Monster7tab:
       .byte $00 ;fe11 |        |
Monster8tab:
       .byte $00 ;fe12 |        |
       .byte $1C ;fe09 |   XXX  |
       .byte $3E ;fe0a |  XXXXX |
       .byte $2A ;fe0b |  X X X |
       .byte $6B ;fe0c | XX X XX|
       .byte $7F ;fe0d | XXXXXXX|
       .byte $7F ;fe0e | XXXXXXX|
       .byte $7F ;fe0f | XXXXXXX|
       .byte $6E ;fe10 | XX XXX |
       .byte $44 ;fe11 | X   X  |
       .byte $00 ;fe12 |        |
       .byte $00 ;fe13 |        |
       .byte $00 ;fe14 |        |
       .byte $00 ;fe15 |        |
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $1C ;fe1a |   XXX  |
       .byte $3E ;fe1b |  XXXXX |
       .byte $2A ;fe1c |  X X X |
       .byte $6B ;fe1d | XX X XX|
       .byte $7F ;fe1e | XXXXXXX|
       .byte $7F ;fe1f | XXXXXXX|
       .byte $7F ;fe20 | XXXXXXX|
       .byte $3B ;fe21 |  XXX XX|
       .byte $11 ;fe22 |   X   X|
       .byte $00 ;fe12 |        |
       .byte $00 ;fe13 |        |
       .byte $00 ;fe14 |        |
       .byte $00 ;fe15 |        |
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $1C ;fe2b |   XXX  |
       .byte $3E ;fe2c |  XXXXX |
       .byte $2A ;fe2d |  X X X |
       .byte $7F ;fe2e | XXXXXXX|
       .byte $6B ;fe2f | XX X XX|
       .byte $55 ;fe30 | X X X X|
       .byte $7F ;fe31 | XXXXXXX|
       .byte $6E ;fe32 | XX XXXX|
       .byte $44 ;fe33 | X   XX |
       .byte $00 ;fe12 |        |
       .byte $00 ;fe13 |        |
       .byte $00 ;fe14 |        |
       .byte $00 ;fe15 |        |
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $1C ;fe3c |   XXX  |
       .byte $3E ;fe3d |  XXXXX |
       .byte $2A ;fe3e |  X X X |
       .byte $7F ;fe3f | XXXXXXX|
       .byte $6B ;fe40 | XX X XX|
       .byte $55 ;fe41 | X X X X|
       .byte $7F ;fe42 | XXXXXXX|
       .byte $3B ;fe43 | XXX XXX|
       .byte $11 ;fe44 |  X   XX|
       .byte $00 ;fe12 |        |
       .byte $00 ;fe13 |        |
       .byte $00 ;fe14 |        |
       .byte $00 ;fe15 |        |
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $0C ;fe4d |    XX  |
       .byte $08 ;fe4e |    X   |
       .byte $1C ;fe2b |   XXX  |
       .byte $2A ;fe2d |  X X X |
       .byte $7F ;fe2e | XXXXXXX|
       .byte $6B ;fe2f | XX X XX|
       .byte $55 ;fe30 | X X X X|
       .byte $6E ;fe32 | XX XXXX|
       .byte $44 ;fe33 | X   XX |
       .byte $00 ;fe12 |        |
       .byte $00 ;fe13 |        |
       .byte $00 ;fe14 |        |
       .byte $00 ;fe15 |        |
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $18 ;fe5e |   XX   |
       .byte $08 ;fe5f |    X   |
       .byte $1C ;fe3c |   XXX  |
       .byte $2A ;fe3e |  X X X |
       .byte $7F ;fe3f | XXXXXXX|
       .byte $6B ;fe40 | XX X XX|
       .byte $55 ;fe41 | X X X X|
       .byte $3B ;fe43 | XXXX XX|
       .byte $11 ;fe44 |  XX   X|
       .byte $00 ;fe67 |        |
       .byte $00 ;fe68 |        |
       .byte $00 ;fe69 |        |
       .byte $00 ;fe6a |        |
       .byte $00 ;fe6b |        |
       .byte $00 ;fe6c |        |
       .byte $00 ;fe6d |        |
       .byte $00 ;fe6e |        |
       .byte $00 ;fe6f |        |
       .byte $00 ;fe70 |        |
       .byte $36 ;fe71 |  XX XX |
       .byte $36 ;fe72 |  XX XX |
       .byte $00 ;fe73 |        |
       .byte $00 ;fe74 |        |
       .byte $00 ;fe75 |        |
       .byte $00 ;fe73 |        |
       .byte $00 ;fe74 |        |
       .byte $00 ;fe75 |        |
       .byte $00 ;fe73 |        |
LowerFruitOffset  =  Fruit1tab-117
;must be at least 41>page break
Fruit1tab:
       .byte $00 ;fe14 |        |(shared w/above)
       .byte $00 ;fe15 |        |(shared w/above)
       .byte $00 ;fe16 |        |(shared w/above)
       .byte $00 ;0328 |        |(shared w/above)
       .byte $10 ;0329 |   X    |
       .byte $18 ;032a |   XX   |
       .byte $24 ;032b |  X  X  |
       .byte $64 ;032c | XX  X  |
       .byte $F6 ;032d |XXXX XX |
       .byte $6F ;032e | XX XXXX|
       .byte $06 ;032f |     XX |
       .byte $00 ;0330 |        |
Fruit2tab:
       .byte $00 ;0331 |        |(shared w/above)
       .byte $00 ;0332 |        |(shared w/above)
       .byte $00 ;0333 |        |(shared w/above)
       .byte $00 ;0334 |        |(shared w/above)
       .byte $3C ;0335 |  XXXX  |
       .byte $7E ;0336 | XXXXXX |
       .byte $FE ;0337 |XXXXXXX |
       .byte $FE ;0338 |XXXXXXX |
       .byte $7C ;0339 | XXXXX  |
       .byte $3C ;033a |  XXXX  |
       .byte $18 ;033b |   XX   |
       .byte $00 ;033c |        |
Fruit3tab:
       .byte $00 ;033d |        |(shared w/above)
       .byte $00 ;033e |        |(shared w/above)
       .byte $00 ;033e |        |(shared w/above)
       .byte $00 ;0340 |        |(shared w/above)
       .byte $3C ;0341 |  XXXX  |
       .byte $72 ;0342 | XXX  X |
       .byte $FF ;0343 |XXXXXXXX|
       .byte $FF ;0344 |XXXXXXXX|
       .byte $FF ;0345 |XXXXXXXX|
       .byte $7E ;0346 | XXXXXX |
       .byte $3C ;0347 |  XXXX  |
       .byte $00 ;0348 |        |
Fruit4tab:
       .byte $00 ;0349 |        |(shared w/above)
       .byte $00 ;034a |        |(shared w/above)
       .byte $00 ;034b |        |(shared w/above)
       .byte $00 ;034d |        |(shared w/above)
       .byte $0C ;034e |    XX  |
       .byte $08 ;034f |    X   |
       .byte $76 ;0350 | XXX XX |
       .byte $FF ;0351 |XXXXXXXX|
       .byte $FF ;0353 |XXXXXXXX|
       .byte $7E ;0354 | XXXXXX |
       .byte $36 ;0355 |  XX XX |
       .byte $00 ;0356 |        |
Fruit5tab:
       .byte $00 ;fe14 |        |(shared w/above)
       .byte $00 ;fe15 |        |(shared w/above)
       .byte $00 ;fe16 |        |(shared w/above)
       .byte $00 ;0328 |        |(shared w/above)
       .byte $08 ;0329 |    X   |
       .byte $1C ;032a |   XXX  |
       .byte $3E ;032b |  XXXXX |
       .byte $3E ;032c |  XXXXX |
       .byte $3E ;032d |  XXXXX |
       .byte $3E ;032e |  XXXXX |
       .byte $1C ;032f |   XXX  |
       .byte $00 ;0330 |        |
Fruit6tab:
       .byte $00 ;0331 |        |(shared w/above)
       .byte $00 ;0332 |        |(shared w/above)
       .byte $00 ;0333 |        |(shared w/above)
       .byte $00 ;0334 |        |(shared w/above)
       .byte $41 ;0335 | X     X|
       .byte $6B ;0336 | XX X XX|
       .byte $3E ;0337 |  XXXXX |
       .byte $1C ;0338 |   XXX  |
       .byte $08 ;0339 |    X   |
       .byte $08 ;033a |    X   |
       .byte $08 ;033b |    X   |
       .byte $00 ;033c |        |
Fruit7tab:
       .byte $00 ;033d |        |(shared w/above)
       .byte $00 ;033e |        |(shared w/above)
       .byte $00 ;033e |        |(shared w/above)
       .byte $00 ;0340 |        |(shared w/above)
       .byte $18 ;0341 |   XX   |
       .byte $3C ;0342 |  XXXX  |
       .byte $7E ;0343 | XXXXXX |
       .byte $7E ;0344 | XXXXXX |
       .byte $FF ;0345 |XXXXXXXX|
       .byte $DB ;0346 |XX XX XX|
       .byte $66 ;0347 | XX  XX |
       .byte $00 ;0348 |        |
Fruit8tab:
       .byte $00 ;0349 |        |(shared w/above)
       .byte $00 ;034a |        |(shared w/above)
       .byte $00 ;034b |        |(shared w/above)
       .byte $00 ;034d |        |(shared w/above)
       .byte $18 ;034e |   XX   |
       .byte $24 ;034f |  X  X  |
       .byte $3C ;0350 |  XXXX  |
       .byte $18 ;0351 |   XX   |
       .byte $18 ;0352 |   XX   |
       .byte $1C ;0353 |   XXX  |
       .byte $18 ;0354 |   XX   |
       .byte $00 ;0355 |        |
       .byte $00 ;0356 |        |
       .byte $00 ;0357 |        |
       .byte $00 ;0358 |        |
Ready:
       .byte $00 ;0331 |        |(shared w/above)
       .byte $3C ;0332 |  XXXX  |
       .byte $20 ;0333 |  X     |
       .byte $2C ;0334 |  X XX  |
       .byte $24 ;0335 |  X  X  |
       .byte $3C ;0336 |  XXXX  |
       .byte $00 ;0337 |        |
       .byte $3C ;0338 |  XXXX  |
       .byte $24 ;0339 |  X  X  |
       .byte $24 ;033a |  X  X  |
       .byte $24 ;033b |  X  X  |
       .byte $3C ;033c |  XXXX  |
       .byte $00 ;0357 |        |
       .byte $00 ;0357 |        |
       .byte $00 ;0357 |        |
       .byte $00 ;0357 |        |
       .byte $00 ;0357 |        |

  ORG $1F00
  RORG $DF00

XposTbl:
       .byte $F1 ; |XXXX   X| $F17B 00
       .byte $E1 ; |XXX    X| $F17C 01
       .byte $D1 ; |XX X   X| $F17D 02
       .byte $C1 ; |XX     X| $F17E 03
       .byte $B1 ; |X XX   X| $F17F 04
       .byte $A1 ; |X X    X| $F180 05
       .byte $91 ; |X  X   X| $F181 06
       .byte $81 ; |X      X| $F182 07
       .byte $62 ; | XX   X | $F183 08
       .byte $52 ; | X X  X | $F184 09
       .byte $42 ; | X    X | $F185 0a
       .byte $32 ; |  XX  X | $F186 0b
       .byte $22 ; |  X   X | $F187 0c
       .byte $12 ; |   X  X | $F188 0d
       .byte $02 ; |      X | $F189 0e
       .byte $F2 ; |XXXX  X | $F18A 0f
       .byte $E2 ; |XXX   X | $F18B
       .byte $D2 ; |XX X  X | $F18C
       .byte $C2 ; |XX    X | $F18D
       .byte $B2 ; |X XX  X | $F18E
       .byte $A2 ; |X X   X | $F18F
       .byte $92 ; |X  X  X | $F190
       .byte $82 ; |X     X | $F191
       .byte $63 ; | XX   XX| $F192
       .byte $53 ; | X X  XX| $F193
       .byte $43 ; | X    XX| $F194
       .byte $33 ; |  XX  XX| $F195
       .byte $23 ; |  X   XX| $F196
       .byte $13 ; |   X  XX| $F197
       .byte $03 ; |      XX| $F198
       .byte $F3 ; |XXXX  XX| $F199
       .byte $E3 ; |XXX   XX| $F19A
       .byte $D3 ; |XX X  XX| $F19B
       .byte $C3 ; |XX    XX| $F19C
       .byte $B3 ; |X XX  XX| $F19D
       .byte $A3 ; |X X   XX| $F19E
       .byte $93 ; |X  X  XX| $F19F
       .byte $83 ; |X     XX| $F1A0
       .byte $64 ; | XX  X  | $F1A1
       .byte $54 ; | X X X  | $F1A2
       .byte $44 ; | X   X  | $F1A3
       .byte $34 ; |  XX X  | $F1A4
       .byte $24 ; |  X  X  | $F1A5
       .byte $14 ; |   X X  | $F1A6
       .byte $04 ; |     X  | $F1A7
       .byte $F4 ; |XXXX X  | $F1A8
       .byte $E4 ; |XXX  X  | $F1A9
       .byte $D4 ; |XX X X  | $F1AA
       .byte $C4 ; |XX   X  | $F1AB
       .byte $B4 ; |X XX X  | $F1AC
       .byte $A4 ; |X X  X  | $F1AD
       .byte $94 ; |X  X X  | $F1AE
       .byte $84 ; |X    X  | $F1AF
       .byte $65 ; | XX  X X| $F1B0
       .byte $55 ; | X X X X| $F1B1
       .byte $45 ; | X   X X| $F1B2
       .byte $35 ; |  XX X X| $F1B3
       .byte $25 ; |  X  X X| $F1B4
       .byte $15 ; |   X X X| $F1B5
       .byte $05 ; |     X X| $F1B6
       .byte $F5 ; |XXXX X X| $F1B7
       .byte $E5 ; |XXX  X X| $F1B8
       .byte $D5 ; |XX X X X| $F1B9
       .byte $C5 ; |XX   X X| $F1BA
       .byte $B5 ; |X XX X X| $F1BB
       .byte $A5 ; |X X  X X| $F1BC
       .byte $95 ; |X  X X X| $F1BD
       .byte $85 ; |X    X X| $F1BE
       .byte $66 ; | XX  XX | $F1BF
       .byte $56 ; | X X XX | $F1C0
       .byte $46 ; | X   XX | $F1C1
       .byte $36 ; |  XX XX | $F1C2
       .byte $26 ; |  X  XX | $F1C3
       .byte $16 ; |   X XX | $F1C4
       .byte $06 ; |     XX | $F1C5
       .byte $F6 ; |XXXX XX | $F1C6
       .byte $E6 ; |XXX  XX | $F1C7
       .byte $D6 ; |XX X XX | $F1C8
       .byte $C6 ; |XX   XX | $F1C9
       .byte $B6 ; |X XX XX | $F1CA
       .byte $A6 ; |X X  XX | $F1CB
       .byte $96 ; |X  X XX | $F1CC
       .byte $86 ; |X    XX | $F1CD
       .byte $67 ; | XX  XXX| $F1CE
       .byte $57 ; | X X XXX| $F1CF
       .byte $47 ; | X   XXX| $F1D0
       .byte $37 ; |  XX XXX| $F1D1
       .byte $27 ; |  X  XXX| $F1D2
       .byte $17 ; |   X XXX| $F1D3
       .byte $07 ; |     XXX| $F1D4
       .byte $F7 ; |XXXX XXX| $F1D5
       .byte $E7 ; |XXX  XXX| $F1D6
       .byte $D7 ; |XX X XXX| $F1D7
       .byte $C7 ; |XX   XXX| $F1D8
       .byte $B7 ; |X XX XXX| $F1D9
       .byte $A7 ; |X X  XXX| $F1DA
       .byte $97 ; |X  X XXX| $F1DB
       .byte $87 ; |X    XXX| $F1DC
       .byte $68 ; | XX X   | $F1DD
       .byte $58 ; | X XX   | $F1DE
       .byte $48 ; | X  X   | $F1DF
       .byte $38 ; |  XXX   | $F1E0
       .byte $28 ; |  X X   | $F1E1
       .byte $18 ; |   XX   | $F1E2
       .byte $08 ; |    X   | $F1E3
       .byte $F8 ; |XXXXX   | $F1E4
       .byte $E8 ; |XXX X   | $F1E5
       .byte $D8 ; |XX XX   | $F1E6
       .byte $C8 ; |XX  X   | $F1E7
       .byte $B8 ; |X XXX   | $F1E8
       .byte $A8 ; |X X X   | $F1E9
       .byte $98 ; |X  XX   | $F1EA
       .byte $88 ; |X   X   | $F1EB
       .byte $69 ; | XX X  X| $F1EC
       .byte $59 ; | X XX  X| $F1ED
       .byte $49 ; | X  X  X| $F1EE
       .byte $39 ; |  XXX  X| $F1EF
       .byte $29 ; |  X X  X| $F1F0
       .byte $19 ; |   XX  X| $F1F1
       .byte $09 ; |    X  X| $F1F2
       .byte $F9 ; |XXXXX  X| $F1F3
       .byte $E9 ; |XXX X  X| $F1F4
       .byte $D9 ; |XX XX  X| $F1F5
       .byte $C9 ; |XX  X  X| $F1F6
       .byte $B9 ; |X XXX  X| $F1F7
       .byte $A9 ; |X X X  X| $F1F8
       .byte $99 ; |X  XX  X| $F1F9
       .byte $89 ; |X   X  X| $F1FA
       .byte $6A ; | XX X X | $F1FB
       .byte $5A ; | X XX X | $F1FC
       .byte $4A ; | X  X X | $F1FD
       .byte $3A ; |  XXX X | $F1FE
       .byte $2A ; |  X X X | $F1FF

;fruit table locations
Mid_Fruit_lo_tab:
       .byte <Fruit1tab ; $F36D
       .byte <Fruit2tab ; $F36D
       .byte <Fruit3tab ; $F36D
       .byte <Fruit3tab ; $F36D
       .byte <Fruit4tab ; $F36D
       .byte <Fruit4tab ; $F36D
       .byte <Fruit5tab ; $F36D
       .byte <Fruit5tab ; $F36D
       .byte <Fruit6tab ; $F36D
       .byte <Fruit6tab ; $F36D
       .byte <Fruit7tab ; $F36D
       .byte <Fruit7tab ; $F36D
       .byte <Fruit8tab ; $F36D
       .byte <Fruit8tab ; $F36D
       .byte <Fruit8tab ; $F36D
       .byte <Fruit8tab ; $F36D
       .byte <Fruit8tab ; $F36D
       .byte <Fruit8tab ; $F36D
       .byte <Ready     ; $F36D

;maze1a (right side)
Maze1aTab:
;maze1a (right side)
MMaze1aTab:
       .byte $E0 ;ff4a |XXX     |
       .byte $20 ;ff4b |  X     |
       .byte $00 ;ff4c |        |
       .byte $00 ;ff4d |        |
       .byte $20 ;ff4e |  X     |
       .byte $20 ;ff4f |  X     |
       .byte $E0 ;ff50 |XXX     |
       .byte $80 ;fd63 |X       |
       .byte $80 ;fd63 |X       |
       .byte $80 ;ff51 |X       |
       .byte $00 ;ff52 |        |
       .byte $00 ;ff53 |        |<-TUNNEL
       .byte $E0 ;ff54 |XXX     |
       .byte $80 ;ff55 |X       |
       .byte $20 ;ff56 |  X     |
       .byte $20 ;ff57 |  X     |

;maze1b (right side)
Maze1bTab:
       .byte $20 ;003c |  X     |(shared w/above)
       .byte $20 ;003d |  X     |(shared w/above)
       .byte $00 ;003e |        |(shared w/above)
       .byte $00 ;003f |        |(shared w/above)
       .byte $20 ;0040 |  X     |(shared w/above)
       .byte $20 ;0041 |  X     |(shared w/above)
       .byte $80 ;0042 |X       |
       .byte $80 ;fd63 |X       |
       .byte $80 ;fd63 |X       |
       .byte $80 ;0043 |X       |
       .byte $00 ;0044 |        |
       .byte $00 ;0045 |        |
       .byte $80 ;0046 |X       |                          
       .byte $80 ;0047 |X       |
       .byte $20 ;0048 |  X     |
       .byte $20 ;0049 |  X     |
       .byte $20 ;0078 |  X     |
       .byte $20 ;0079 |  X     |
       .byte $00 ;007a |  X     |
       .byte $00 ;007b |  X     |

;maze1b (right side)
MMaze1bTab:
       .byte $20 ;003c |  X     |(shared w/above)
       .byte $20 ;003d |  X     |(shared w/above)
       .byte $00 ;003e |        |
       .byte $00 ;003f |        |
       .byte $20 ;0040 |  X     |
       .byte $20 ;0041 |  X     |
       .byte $80 ;0042 |X       |
       .byte $80 ;fd63 |X       |
       .byte $80 ;fd63 |X       |
       .byte $80 ;0043 |X       |
       .byte $00 ;0044 |        |
       .byte $00 ;0045 |        |
       .byte $80 ;0046 |X       |
       .byte $80 ;0047 |X       |
       .byte $20 ;0048 |  X     |
       .byte $20 ;0049 |  X     |

;maze1c (right side)
Maze1cTab:
; (all shared w/ 1c)

;maze1c (right side)
MMaze1cTab:
       .byte $20 ;0078 |  X     |(shared w/above)
       .byte $20 ;0079 |  X     |(shared w/above)
       .byte $00 ;007a |        |(shared w/above)
       .byte $00 ;007b |        |(shared w/above)
       .byte $20 ;007c |  X     |(shared w/above)
       .byte $20 ;007d |  X     |(shared w/above)
       .byte $80 ;0080 |X       |
       .byte $80 ;0080 |X       |
       .byte $80 ;007e |X       |
       .byte $E0 ;007f |XXX     |
       .byte $00 ;0080 |        |
       .byte $00 ;0081 |        |
       .byte $80 ;0082 |X       |
       .byte $E0 ;0083 |XXX     |
       .byte $20 ;0084 |  X     |
       .byte $20 ;0085 |  X     |
       .byte $20 ;0086 |  X     |
       .byte $E0 ;0087 |XXX     |
       .byte $00 ;0088 |        |
       .byte $00 ;0089 |        |
       .byte $20 ;008a |  X     |
       .byte $E0 ;008b |XXX     |

;maze3a (right side)
MMaze3aTab:
       .byte $8F ;fdb8 |X   XXXX|<-tunnel
       .byte $00 ;fdb9 |        |
       .byte $00 ;fdba |        |
       .byte $00 ;fdbb |        |
       .byte $00 ;fdbc |        |
       .byte $00 ;fdbd |        |
       .byte $00 ;fdbe |        |
       .byte $00 ;fdc7 |        |
       .byte $78 ;fdc0 | XXXX   |<-Bit 7=Small door in box
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;fdc1 |    X   |
       .byte $08 ;fdc1 |    X   |
       .byte $00 ;fdc2 |        |
       .byte $00 ;fdc3 |        |
       .byte $00 ;fdc4 |        |
       .byte $00 ;fdc5 |        |
       .byte $00 ;fdc6 |        |
       .byte $00 ;fdc7 |        |
       .byte $00 ;fdc8 |        |
       .byte $00 ;fdc9 |        |
       .byte $0F ;fdde |    XXXX|
       .byte $08 ;fddf |    X   |

  ORG $1FF8
  RORG $DFF8

;end-of-bank filler
       .byte $FF ; |XXXXXXXX| $DFF8
       .byte $FF ; |XXXXXXXX| $DFF9
       .byte $FF ; |XXXXXXXX| $DFFA
       .byte $FF ; |XXXXXXXX| $DFFB
       .byte $FF ; |XXXXXXXX| $DFFC
       .byte $FF ; |XXXXXXXX| $DFFD
       .byte $FF ; |XXXXXXXX| $DFFE
       .byte $FF ; |XXXXXXXX| $DFFF











  ORG  $2000
  RORG  $F000

Reposition:
       LDA    $1FF8                   ;4 call bank 1
       rts                            ;6 
ReleaseTime:
       .byte $2A ;0100 |    X X |
       .byte $53 ;0101 |      XX|
       .byte $D3 ;0102 |      XX|
       .byte $8B ;0103 |    X XX|

;flip banks
Display_Prepbank1:
       LDA    $1FF8                   ;4 call bank 1
LFC4C:
       lda    #$F0                    ;2 
       sta    $CA                     ;3 
New_Display_Start:
       lda    #$02                    ;2 
Wait4Retrace:
       ldx    INTIM                   ;4 
       bne    Wait4Retrace            ;2 
       sta    WSYNC                   ;3 
       sta    VSYNC                   ;3 
       sta    WSYNC                   ;3 
       sta    WSYNC                   ;3 
       ldx    #Tim2                   ;2 $2C...3A safe
       stx    TIM64T                  ;4 
       lsr                            ;2 
       sta    WSYNC                   ;3 
       sta    VSYNC                   ;3 

Debounce:
       lda    SWCHB                   ;2 Check P0 difficulty
       cmp    DifSw                   ;2 compare with ram
       beq    Debounce_ending         ;2 branch if the same
       sta    DifSw                   ;2 otherwise, save the state...
       lsr                            ;2 check for reset
       bcs    NotGame_mode            ;2 branch if not
Game_mode:
       lda    Lives                   ;3 Load game mode
       eor    #$40                    ;2 flip game modes
       sta    Lives                   ;3 ..save
       jsr    SaveMode                ;6 
       stx    Level                   ;3 
       bpl    Debounce_ending         ;2 always jump
NotGame_mode:
       lsr                            ;2 check for select
       bcs    NotHigher_Start_level   ;2 branch if not
Higher_Start_level:
       inc    Level                   ;3 
       lda    Level                   ;3 
       and    #$1F                    ;2 
       cmp    #$11                    ;2 
       bcc    Under5th                ;2 
       lda    #$00                    ;2 
Under5th:
       sta    Level                   ;3 
NotHigher_Start_level:
       jsr    SaveMode                ;6 
Debounce_ending:
       inc    LoTimer                 ;5 
       ldx    Control                 ;3 
       bpl    New_Display_StartB      ;2 
       jmp    Increase_Timers         ;3 
New_Display_StartB:
       cpx    #$7E                    ;2 
       beq    Debounce_return2        ;2 
       cpx    #$7F                    ;2 
       bne    Inactive2               ;2 
       lda    INPT4                   ;3 
       bmi    Debounce_return2        ;2 
       lda    #$80                    ;2 
       sta    Control                 ;3 
       bmi    Debounce_return2        ;2 
Inactive2:
       cpx    #$10                    ;2 
       bcc    Playeralright           ;2 
;Player_Death_animation:
       lda    LoTimer                 ;2 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       tay                            ;2 
       lda.wy Death,y                 ;4 load "spinning" value
       sta    PacOffset               ;3 save to player
       lda    LoTimer                 ;2 
       and    #$03                    ;2 
       tay                            ;2 
       lda    #$F0                    ;2 load offscreen value
       sta.wy MonsterY,y              ;4 save to monsters
       lda    LoTimer                 ;2 
       lsr                            ;2 
       tay                            ;2 
       lda    Deathsound,y            ;2 
       tay                            ;2 
       asl                            ;2 
       cpx    #$7C                    ;2 
       beq    Lose_Life2              ;2 
       inc    Control                 ;5 
       beq    Lose_Life2              ;2 
       sta    AUDF0                   ;3 
       sty    AUDF1                   ;3 
       ldy    #$04                    ;2 
       sty    AUDV0                   ;3 
       sty    AUDV1                   ;3 
       ldy    #$05                    ;2 
       sty    AUDC0                   ;3 
       ldy    #$01                    ;2 
       sty    AUDC1                   ;3 
       jmp    Display_Prepf           ;3 
Debounce_return2:
       jmp    Debounce_return         ;3 
Playeralright:
       lda    LoTimer                 ;3 
       and    #$0F                    ;2 
       bne    Debounce_return2        ;2 
       inx                            ;2 
       stx    Control                 ;3 
       cpx    #$08                    ;2 
       beq    Check_Level_counter     ;2 
       bne    Debounce_return2        ;2 always branch

Save_game_state:
       stx    Control                 ;3 
       bne    Debounce_return         ;2 
Check_Level_counter:
       ldx    Level                   ;3 added routine to correct level #
       inx                            ;2 
       cpx    #$12                    ;2 are we already on board 17?
       bne    Board17                 ;2 skip ahead if so
       ldx    #$10                    ;2 
Board17:
       stx    Level                   ;3 ...otherwise increase level #
       cpx    #$02                    ;2 
       beq    Set_Intermission        ;2 
       cpx    #$05                    ;2 
       beq    Set_Intermission        ;2 
       cpx    #$09                    ;2 
       beq    Set_Intermission        ;2 
       cpx    #$0D                    ;2 
       beq    Set_Intermission        ;2 
NoIntermission:
       jsr    TransferDots            ;6 initialize screen and object locations (new board)
       bne    Debounce_return         ;2 
NoPause:
       inc    Control                 ;5 
       bne    Clear_Audio_Start       ;2 save sound instead
Lose_Life2:
       lda    #$F0                    ;2 
       sta    PlayerY                 ;3 
       dec    Lives                   ;5 
       lda    Lives                   ;3 
       and    #$0F                    ;2 
       bne    Lives_remaining         ;2 
       sta    Lives                   ;3 
       ldx    #$7E                    ;2 
       bne    Save_game_state         ;2 
Lives_remaining:
       jsr    New_board               ;6 
Debounce_return:
       lda    #$00                    ;2 empty accumulator to clear sound
Clear_Audio_Start:
       ldx    #$05                    ;2 Clear all audio
Clear_Audio_Loop:
       sta    AUDC0,x                 ;4 
       dex                            ;2 
       bpl    Clear_Audio_Loop        ;2 
       jmp    Display_Prepf           ;3 
Set_Intermission:
       lda    #$00                    ;2 
       sta    HiTimer                 ;3 
       jsr    TransferDots            ;6 initialize screen and object locations (new board)
       lda    #$80                    ;2 
       sta    Control                 ;3 
       bne    NoPause                 ;2 always branch

SaveMode:
       lda    #$03                    ;3 new game - 3 lives
       tax                            ;2 
       ora    Lives                   ;3 
       and    #$43                    ;3 save game mode
       sta    Lives                   ;3 
       ldy    #$00                    ;3 
       sty    HiTimer                 ;2 clear for tune
ClearMflags:
       sty    Score-1,x               ;4 clear all score digits and total dots collected
       dex                            ;2 
       bne    ClearMflags             ;2 
;set up dots
TransferDots:
       ldx    #$2F                    ;2 
;       lda    Level                   ;3
;       and    #$01                    ;2
;       bne    TransferDots2_Loop      ;2
TransferDots_Loop:
       lda    DotPattern-1,x          ;4 transfer dot pattern to ram
       sta    RamDots-1,x             ;4 
       dex                            ;2 
       bne    TransferDots_Loop       ;2 

   IF TEST
       ldx    #$02                    ;2 
     ELSE
       ldx    #$9A                    ;2 
   ENDIF

;dotfix...empty level
       lda    DifSw                   ;3 check diff.
       eor    #$08                    ;2 B&W switch only
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       and    Level                   ;3
       and    #$01                    ;2 
       beq    yyOriginal              ;2 flip it
       ldx    #$F4                    ;2 
       stx    RamDots+$14             ;3 
       ldx    #$57                    ;2 
       stx    RamDots+$29             ;3 
       ldx    #$94                    ;2 
yyOriginal:
       stx    DotCount                ;3 clear # of dots eaten
New_board:
       ldx    #$7F                    ;2 
       stx    Control                 ;3 
       inx                            ;2 
       stx    PlayerY                 ;3 
       lda    #$BF                    ;2 
       sta    OldStick                ;3 
       ldx    #$04                    ;2 
Initlife:
       lda    Monster_colors_tab-1,x  ;4 
       sta    Color-1,x               ;4 
       lda    BoxPos-1,x              ;4 
       sta    MonsterX-1,x            ;4 
       lda    BoxPos2-1,x             ;4 
       sta    MonsterY-1,x            ;4 
       lda    #$00                    ;2 
       sta    LoTimer-1,x             ;4 LoTimer,SoundDur,MonsterDirs,Temp
       dex                            ;2 
       bne    Initlife                ;2 
       lda    HiTimer                 ;2 
       and    #$08                    ;2 
       sta    HiTimer                 ;2 
       lda    #$42                    ;2 
       sta    PlayerX                 ;3 
;Reset_board_color
       lda    Lives                   ;3 Check for PacPlus
       and    #$40                    ;2 $D0 - Green
       ora    #$80                    ;2 $80 - Blue
       sta    EnergizerTime           ;3 
       ldy    #$08                    ;2 flip it
       lda    Pacstart,y              ;4 and load Pacoffset
       sta    PacOffset               ;3 X=0
       tya                            ;2 
       rts                            ;6 




;---------monster entry points
CheckDirA:
       tay                            ;2 
CheckDirY:
       sty    PrintTemp+1             ;3 
       lda    MonsterDirs             ;3 
       and    #$03                    ;2 
       eor    #$02                    ;2 
       cmp    PrintTemp+1             ;3 reversing direction? (not allowed)
       beq    Map_OKmove              ;2 yes, illegal

;--------player entry point
LFEF5:
       lda    Dir_bit_tab2,y          ;4 
       bit    $DB                     ;3 
       bpl    LFEFF                   ;2 
       lda    Dir_test_tab1,y         ;4 
LFEFF:
       sta    PrintTemp               ;3 
       lda    TempY                   ;3 
LFF8E:
       lsr                            ;2 shift downward
       sta    Temp                    ;3 
       and    #$07                    ;2 
       beq    LFF9B                   ;2 
       lda    PrintTemp               ;3 
L14:
       cmp    #$03                    ;2 
L12:
       rts                            ;6 
LFF9B:
       lda    $DA                     ;3 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       clc                            ;2 
       adc    Temp                    ;3 
       tay                            ;2 
       cpx    #$04                    ;2 are we checking the player?
       beq    NoSchannel              ;2 yes, branch
       cpy    #$2D                    ;2 beside the box?
       bne    NoSchannelC             ;2 no, branch
       bit    TempC                   ;3
       bne    NoEyes_side             ;2 branch if not eyes (no help)
       lda    #$0C                    ;2 Eyes...disallow side movement
       bne    Schannel                ;2 always jump
NoEyes_side:
       lda    PlayerY                 ;2
       cmp    #$30                    ;2 player at the S-channel height?
       bcs    NoSchannel              ;2 branch if lower
       lda    #$05                    ;2 05 load side direction
       bne    Schannel                ;2 always jump
NoSchannelC:
       cpy    #$1F                    ;2 under the channel?
       bne    NoSchannel              ;2 branch if no
       bit    TempC                   ;3
       bmi    NoSchannel              ;2 branch if blue
       beq    NoSchannel              ;2 branch if eyes
       lda    #$03                    ;2 disallow upward movement
       bne    Schannel                ;2
NoSchannel:
       lda    DifSw                   ;3 check diff.
       and    #$08                    ;2 B&W switch only
       php                            ;3 
       lda    Level                   ;3
       and    #$01                    ;2
       bne    alternatem2             ;2
       lda    MazeMapTab1,y           ;4 
       jmp    alternatem1             ;3 <-patch here
alternatem2:
       lda    MazeMapTab2,y           ;4 XXXXXXXXXXXXXXXXXXXX
alternatem1:
       plp                            ;4 
       beq    noOriginal2             ;2 flip it
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       .byte $2C                      ;4 skip 2 bytes
noOriginal2:
       and    #$0F                    ;2

Schannel:
       and    PrintTemp               ;3 
       beq    Map_OKmove              ;2 
;Map_nomove:
       sec                            ;2 
       rts                            ;6 
Map_OKmove:
       clc                            ;2 
       rts                            ;6 



Energizer_Sub_main:
       ldx    #$03                    ;3 do all monsters
       bit    Lives                   ;3 Check for PacPlus
       bvs    PPEnergizer_Sub_main    ;2 branch if plus
;normal game energizer routine
Energizer_Gamemode:
       lda    Color,x                 ;4 
       beq    Energizer_next          ;2 skip if eyes
       lda    #$83                    ;4 otherwise, change to blue
       sta    Color,x                 ;4 and save
Energizer_next:
       clc
       lda    MonsterX,x              ;4 
       cmp    #$42                    ;2 skip if monster currently leaving the box
       beq    Reversal_next           ;2 
       bcc    nosub                   ;2 
       sec                            ;2 
       sbc    #$03                    ;2 
nosub:
       and    #$07                    ;2 skip if at an intersection already
       bne    Reversal_reverse        ;2 
       lda    MonsterY,x              ;4 
       and    #$07                    ;2 skip if at an intersection already
       beq    Reversal_next           ;2 
Reversal_reverse:
       lda    MonsterDirs             ;3 
       eor    Monster_xor,x           ;4 
       sta    MonsterDirs             ;3 
Reversal_next:
       dex                            ;2 
       bpl    Energizer_Gamemode      ;2 
       lda    TotEatenMonsters        ;3 
       and    #$F8                    ;3 
       sta    TotEatenMonsters        ;3 
       ldx    Level                   ;3 
       lda    BlueTimeTab,x           ;3 Reset engergizer time
       ora    #$80                    ;2 $80 - Blue
       sta    EnergizerTime           ;3 
       rts                            ;6 

;bluetime for Plus game
PPEnergizer_Sub_main:
       eor    LoTimer                 ;2 
       and    #$07                    ;2 
       sta    Temp                    ;3 
       lda    DotCount                ;3 
       and    #$07                    ;2 
       sta    TempC                   ;3 
PPEnergizer_Gamemode:
       cpx    Temp                    ;2 (i.e. temp)
       beq    PPEnergizer_next        ;2 
       cpx    TempC                   ;2 (i.e. temp)
       beq    PPEnergizer_next        ;2 
       lda    Color,x                 ;4 
       beq    PPEnergizer_next        ;2 skip if eyes
       lda    #$83                    ;4 otherwise, change to blue
       sta    Color,x                 ;4 and save
PPEnergizer_next:
       clc
       lda    MonsterX,x              ;4 
       cmp    #$42                    ;2 skip if monster currently leaving the box
       beq    PPReversal_next         ;2 
       bcc    PPnosub                 ;2 
       sec                            ;2 
       sbc    #$03                    ;2 
PPnosub:
       and    #$07                    ;2 skip if at an intersection already
       bne    PPReversal_reverse      ;2 
       lda    MonsterY,x              ;4 
       and    #$07                    ;2 skip if at an intersection already
       beq    PPReversal_next         ;2 
PPReversal_reverse:
       lda    MonsterDirs             ;3 
       eor    Monster_xor,x           ;4 
       sta    MonsterDirs             ;3 
PPReversal_next:
       dex                            ;2 
       bpl    PPEnergizer_Gamemode    ;2 
       lda    TotEatenMonsters        ;3 
       and    #$F8                    ;3 
       sta    TotEatenMonsters        ;3 
       lda    #$C0                    ;2 $D0 - Green
       bit    LoTimer                 ;3 
       bvs    PPEnergizer_Regularz    ;2 
       lda    #$00                    ;2 
PPEnergizer_Regularz:
       sta    Temp                    ;3 
       ldx    Level                   ;3 
       inx                            ;2 increase energizer time pointer (less bluetime)
       inx                            ;2 increase energizer time pointer (less bluetime)
       lda    BlueTimeTab,x           ;3 Reset energizer time
       bne    PPBlue                  ;3 
       ora    #$C0                    ;3 
PPBlue:
       ora    Temp                    ;3 
       sta    EnergizerTime           ;3 
       rts                            ;6 



Increase_Timers:
       lda    HiTimer                 ;3 
       and    #$08                    ;2 
       bne    SkipTune                ;2 
       jmp    Play_Tune               ;3 
SkipTune:
       lda    LoTimer                 ;3 
       tax                            ;2 
       and    #$1F                    ;2 
       bne    Adjust_Hitimer          ;2 
       lda    EnergizerTime           ;3 
       and    #$0F                    ;2 
       beq    Adjust_Hitimer          ;2 
       dec    EnergizerTime           ;5 
       cmp    #$01                    ;2 
       bne    Adjust_Hitimer          ;2 
       lda    Lives                   ;3 Check for PacPlus
       and    #$40                    ;2 $D0 - Green
       ora    #$80                    ;2 $80 - Blue
       sta    EnergizerTime           ;3 

Adjust_Hitimer:
       txa                            ;2 
       bne    Keep_Fruit              ;2 branch if low timer not zero
       lda    HiTimer                 ;3 
       clc                            ;2 
       adc    #$10                    ;2 
       ora    #$08                    ;2 
       sta    HiTimer                 ;3 
       bpl    Keep_Fruit              ;2 branch if no rollover
Timer_clear_fruit:
       lda    Control                 ;3 
       and    #$DF                    ;2 clear fruit
       sta    Control                 ;3 
Keep_Fruit:
       lda    LoTimer                 ;3 check bit 0
       and    #$01                    ;2 
       ora    #$02                    ;2 
       tax                            ;2 check every other monster per frame
Collision2:
       lda    Color,x                 ;4 monster eyes?
       beq    Collision_loop          ;2 
       lda    MonsterX,x              ;4 compare monster's horizontal position. ..
       sec                            ;2 
       sbc    PlayerX                 ;3 ...to player's
       tay                            ;2 save for zero check later
       sec                            ;2 bugfix
       sbc    #$03                    ;2 
       cmp    #$FD-3-1                ;2 
       bcc    Collision_loop          ;2 branch if under 253 (forget it)
       lda    MonsterY,x              ;4 compare monster's vertical position. ..
       sec                            ;2 bugfix
       sbc    PlayerY                 ;3 ...to player's
       sec                            ;2 bugfix
       sbc    #$03                    ;2 
       cmp    #$FD-3-1                ;2 
       bcc    Collision_loop          ;2 branch if under 253 (forget it)
       tya                            ;2 check hpos difference
       beq    Eat_Monster             ;2 branch if equal (Cornering OK)
       lda    MonsterY,x              ;4 compare monster's vertical position. ..
       cmp    PlayerY                 ;3 ...to player's
       bne    Adjust_monster_color    ;2 
Eat_Monster:
       lda    Color,x                 ;4 monster blue?
  IF CHEAT
       bpl    Adjust_monster_color    ;2 always branch
  ELSE
       bpl    Player_killed           ;2 branch if not
  ENDIF

Monster_ate:
       lda    #$10                    ;2 load note counter...
       sta    SoundDur                ;3 ...to start from the monster sound
       lda    #$00                    ;2 ...change to eyes
       sta    Color,x                 ;4 
       lda    TotEatenMonsters        ;3 load monster count
       and    #$07                    ;2 
       tay                            ;2 
       lda    MonsterBonusTab,y       ;4 load the point value using that counter
       sed                            ;2 
       clc                            ;2 
       adc    Score+1                 ;3 
       sta    Score+1                 ;3 
       lda    Score                   ;3 
       adc    #$00                    ;2 
       sta    Score                   ;3 
       cld                            ;2 
       beq    AddToScoreMEnd          ;2 If not 10,000 yet, skip ahead
       bit    Lives                   ;3 
       bmi    AddToScoreMEnd          ;2 branch if so
       inc    Lives                   ;5 if so, bump up the number of lives.
       lda    Lives                   ;3 
       ora    #$80                    ;3 set high bit to indicate that player awarded
       sta    SoundDur                ;3 ...and save it for the sound
       sta    Lives                   ;3 ...and save it
AddToScoreMEnd:
       inc    TotEatenMonsters        ;5 .bump up the number of eaten monsters
       lda    Color                   ;3 Check all of the monster flags
       ora    Color+1                 ;3  .
       ora    Color+2                 ;3  .
       ora    Color+3                 ;3  .
       bmi    Adjust_monster_color    ;2 If some still blue...skip ahead
       lda    Lives                   ;3 Check for PacPlus
       and    #$40                    ;2 $D0 - Green
       ora    #$80                    ;2 $80 - Blue
       sta    EnergizerTime           ;3 
       bne    Adjust_monster_color    ;2 always branch

Collision_loop:
       dex                            ;2 skip every other when checking collisions
       dex                            ;2 
       bpl    Collision2              ;2 
       bmi    Adjust_monster_color    ;2 always branch

Player_killed:
       lda    #$00                    ;2 
       sta    LoTimer                 ;3 
       lda    Lives                   ;3 Check for PacPlus
       and    #$40                    ;2 $D0 - Green
       ora    #$80                    ;2 $80 - Blue
       sta    EnergizerTime           ;3 
       lda    #$11                    ;2 
       sta    Control                 ;3 
       jmp    Display_Prepf           ;3 to display prep

Adjust_monster_color:
       ldx    #$03                    ;2 monster loop init
Motion_Loop_Top:
       lda    MonsterY,x              ;4 save temps
       sta    TempY                   ;3 
       lda    MonsterX,x              ;4 
       sta    TempX                   ;3 
       lda    Color,x                 ;3 
       sta    TempC                   ;3 
       beq    Motion_start            ;2 jump if eyes
;Adjust_monster_check:
       bpl    NormalColor             ;2 branch if not blue
       lda    EnergizerTime           ;3 load the energizer time
       and    #$0F                    ;3 
       bne    FlashColor              ;2 branch if so
NormalColor:
       lda    Monster_colors_tab,x    ;4 set to normal color
       bne    SaveColor               ;2 
FlashColor:
       cmp    #$05                    ;2 is it under 5 clicks?
       bcs    FlashColor2             ;2 branch to use blue color if no
       lda    LoTimer                 ;3 check bit 5 of...
       and    #$08                    ;2 low timer
       beq    FlashColor2             ;2 
       lda    #$9D                    ;3 white color
       jmp    SaveColor               ;3 bugfix
FlashColor2:
       lda    #$83                    ;3 blue color
SaveColor:
       sta    TempC                   ;3 

Motion_start:
       lda    LoTimer                 ;3 

       bit    HiTimer                 ;3 
       bpl    LLow_Time               ;2 if time not up, skip ahead
       and    #$0F                    ;2 
       beq    Save2temps              ;2 if time up, jump (move @50hz)
LLow_Time:

       and    #$03                    ;2 
       sta    Temp                    ;3 
       lda    TempC                   ;3 
       beq    Save2temps              ;2 eyes always move (60hz)
       bpl    Che_normal              ;2 not blue, jump
       cpx    Temp                    ;3 If blue...
       bne    MNoMove                 ;2 ...or skip movement
       beq    Save2temps              ;2 if equal, jump (move @15hz)

Che_normal:
       cpx    Temp                    ;2 
       bne    Save2temps              ;2 if NOT equal, jump (move @45hz)
MNoMove:
       jmp    Loop_next_monster2      ;3 

Save2temps:
       lda    TempX                   ;3 
       sec                            ;2 
       sbc    #$42                    ;2 
       beq    Check_Eyes_Box          ;2 
       cmp    #$F4-12-1               ;2 
       bcc    Yaxis_Check             ;2 
       lda    TempY                   ;3 
       sec                            ;2 
       sbc    #$48                    ;2 
       cmp    #$F8-8-1                ;2 
       bcc    Yaxis_Check2            ;2 
;"Hold" routine - to keep monsters in the box and send them out individually
       lda    ReleaseTime,x           ;4 Check timer:
       cmp    LoTimer                 ;2 If LoTimer is higher...
       bcs    Yaxis_Check             ;2 then branch
       lda    #$42                    ;2 
Save_Box_X:
       sta    TempX                   ;3 
       lda    #$00                    ;2 save UP as the direction
Skip_Box_X:
       sta    PrintTemp+1             ;3 
       jmp    NewDir                  ;3 jump to the end of the loop



Check_Eyes_Box:
       lda    TempY                   ;3 
Check_Eyes_Box2:
       cmp    #$30                    ;2 Above the box?
       bne    Yaxis_Check2            ;2 
       lda    TempC                   ;3 
       bne    Check_Eyes_Boxno        ;2 branch if not eyes
       lda    #$4C                    ;2 
       sta    TempC                   ;3 
       sta    TempY                   ;3 save the new Y
       bne    Save_Box_X              ;2 save to MonsterY and go to end
Check_Eyes_Boxno:
       lda    Temp                    ;3 reverse direction
       ora    #$01                    ;2 
       bne    Skip_Box_X              ;2 save direction, go to end of loop
Yaxis_Check:
       lda    TempY                   ;3 
Yaxis_Check2:
       and    #$07                    ;2 
       bne    Motion_Loop_End         ;2 
       tay                            ;2 y=0
       lda    TempX                   ;3 
       cmp    #$44                    ;2 
       bcc    LFF85a                  ;2 
       dey                            ;2 y=FF
       lda    #$84                    ;2 
       sec                            ;2 Bugfix2
       sbc    TempX                   ;3 
LFF85a:
       cmp    #$3F                    ;2 
       bcc    LFF8Ba                  ;2 
       lda    #$3F                    ;2 
LFF8Ba:
       sty    $DB                     ;3 
       sta    $DA                     ;3 
       and    #$07                    ;2 
Motion_Loop_End:
       bne    Move_monster_routine    ;2 



;Get_Color
       ldy    TempC                   ;3 
       beq    Red_M_AI                ;2 branch ahead if eyes
       bmi    MoveRandom              ;2 
       txa                            ;2 is it the red monster?
       beq    Match_release_value     ;2 skip ahead if so
       bit    DifSw                   ;2 Check P0 difficulty
       bvc    MoveRandom              ;2 if B-position, always random
Match_release_value:
       lda    ReleaseTime,x           ;4 Check timer:
       cmp    LoTimer                 ;2 If LoTimer is higher...
       bcs    MoveRandom              ;2 then branch

Red_M_AI:
;match rows...
       tya                            ;2 Y still holds color
       bne    NoEyesY                 ;2 branch ahead if not eyes
       lda    #$30                    ;2 use box location
       bne    SmartY                  ;2 skip next 2
NoEyesY:
;home corner routine for vertical
;       lda    HiTimer                 ;2
;       cmp    #$10                    ;2 
;       bcs    Smartpy                 ;2 skip next 2
;       lda    YCorner,x               ;4
;       bne    SmartY                  ;2 skip next 2
;Smartpy
       lda    PlayerY                 ;3 
SmartY:
       ldy    #$00                    ;2 
       cmp    TempY                   ;3 compare Y differences
       beq    EqualRow                ;2 
       bcc    Check_monster_vert      ;2 
       ldy    #$02                    ;2
Check_monster_vert:
       jsr    CheckDirY               ;6 check vertical direction
       bcs    NewDir
;same row or vertical direction not allowed
EqualRow:
       ldy    #$01                    ;2 if PlayerX > MonsterX, store direction 1
       lda    TempC                   ;3 
       bne    NoEyesX                 ;2 branch ahead if not eyes
       lda    #$42                    ;2 use box location
       bne    SmartX                  ;2 skip next 2
NoEyesX:
;home corner routine for horizontal
;       lda    HiTimer                 ;2
;       cmp    #$10                    ;2 
;       bcs    Smartpx                 ;2 skip next 2
;       lda    XCorner,x               ;4
;       bne    SmartX                  ;2 skip next 2
;Smartpx:
       lda    PlayerX                 ;3 
SmartX:
       cmp    TempX                   ;3 
       bpl    MoveGetPermissions      ;2 
       ldy    #$03                    ;2 if PlayerX < MonsterX, store direction 3
MoveGetPermissions:
       jsr    CheckDirY               ;6 
       bcs    NewDir                  ;2 
MoveRandom:
       lda    HiTimer                 ;3 order reversed to strip top nybble
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       clc                            ;2 Bugfix2
       adc    Temp                    ;3 
       eor    LoTimer                 ;3 
       lsr                            ;2 
       and    #$03                    ;2 
       tay                            ;2 
MoveAngle:
       sty    PrintTemp+11            ;3 
       lda    Bit_chk_5,y             ;4 +/-90 deg. or same dir
       clc                            ;2 
       adc    MonsterDirs             ;3 
       and    #$03                    ;2 
       jsr    CheckDirA               ;6 
       bcs    NewDir                  ;2 
       ldy    PrintTemp+11            ;3 
       iny                            ;2 
       bne    MoveAngle               ;2 jump always




NewDir:
       lda    MonsterDirs             ;3 
       and    #$FC                    ;2 
       ora    PrintTemp+1             ;3 
       sta    MonsterDirs             ;3 
Move_monster_routine:
       lda    MonsterDirs             ;3 
       and    #$03                    ;2 
       beq    Move_monster_up         ;2 00 branch if moving up
       cmp    #$02                    ;2 
       beq    Move_monster_down       ;2 02 branch if moving down
       tay                            ;2 
       lda    TempY                   ;3 
       cmp    #$50                    ;2 same height as tunnel?
       bne    OK_none                 ;2 
       lda    TempX                   ;3 
       cmp    #$10                    ;2 
       bcc    LFF23                   ;2 
       cmp    #$74                    ;2 
       bcc    OK_none                 ;2 
LFF23:
       lda    LoTimer                 ;3 
       and    #$04                    ;2 
       beq    Loop_next_monster       ;2 
OK_none:
       dey                            ;2 01->00 & 03->02
       beq    Move_monster_right      ;2 01 branch if moving right
;03 left
       ldy    TempX                   ;3 
       dey                            ;2 move monster left
       cpy    #$FF                    ;2 did we go through the left tunnel?
       bne    x_save                  ;2 
       ldy    #$84                    ;2 if so, flip to the right
x_save:
       sty    TempX                   ;3 
       jmp    Loop_next_monster       ;3 bugfix
Move_monster_right:
       ldy    TempX                   ;3 
       iny                            ;2 move monster right
       cpy    #$85                    ;2 did we go through the right tunnel?
       bne    x_save                  ;2 
       ldy    #$00                    ;2 if so, flip to the left
       sty    TempX                   ;3 
       jmp    Loop_next_monster       ;3 bugfix

Move_monster_down:
       ldy    TempY                   ;3 move monster down
       iny                            ;2 
       cpy    #$A1                    ;2 did we go through the lower tunnel?
       bne    y_save                  ;2 
       ldy    #$00                    ;2 if so, flip to the top
y_save:
       sty    TempY                   ;3 
       jmp    Loop_next_monster       ;3 bugfix
Move_monster_up:
       ldy    TempY                   ;3 move monster up
       dey                            ;2 
       cpy    #$FF                    ;2 did we go through the upper tunnel?
       bne    y_save                  ;2 
       ldy    #$A0                    ;2 if so, flip to the bottom
       sty    TempY                   ;3 
Loop_next_monster:
       lda    TempC                   ;3 
       sta    Color,x                 ;3 
       lda    TempY                   ;3 
       sta    MonsterY,x              ;4 
       lda    TempX                   ;3 
       sta    MonsterX,x              ;4 
Loop_next_monster2:
       lda    MonsterDirs             ;3 
       rol                            ;2 
       rol    MonsterDirs             ;5 
       rol                            ;2 
       rol    MonsterDirs             ;5 
       dex                            ;2 all monsters done?
       bmi    Sound_routine           ;2 if done, branch
       jmp    Motion_Loop_Top         ;3 ...or go back up and do the next one

Sound_routine:
;siren sounds, bluetime, eyes
       ldy    HiTimer                 ;3 
       lda    EnergizerTime           ;3 energizer active?
       and    #$0F                    ;3 
       tax                            ;2 
       lda    LoTimer                 ;3 
       and    #$1F                    ;3 
       cpx    #$00                    ;3 
       bne    Background_energizer    ;2 branch if so
RegularSiren:
       tax                            ;2 
       lda    Level                   ;3 
       lsr                            ;2 
       sta    Temp                    ;3 
       lda    SirenData,x             ;4 
       sec                            ;2 
       sbc    Temp                    ;3 
;quick siren
       cpy    #$3F                    ;2 
       bcc    Background_playsound1   ;2 branch if not
       sec                            ;2 Bugfix2
       sbc    #$01                    ;3 faster siren
       cpy    #$7F                    ;2 
       bcc    Background_playsound1   ;2 branch if not
       sec                            ;2 Bugfix2
       sbc    #$01                    ;3 quickest siren
       jmp    Background_playsound1   ;3 bugfix
Background_energizer:
       sta    TempC                   ;3 
       txa                            ;2 
       lsr                            ;2 
       sta    Temp                    ;3 
       lda    Color                   ;4 Check all of the monster flags
       and    Color+1                 ;4  .
       and    Color+2                 ;4  .
       and    Color+3                 ;4  .
       beq    Background_playsound    ;2 branch if any are eyes
Background_Energizer_sound:
       lda    TempC                   ;3 
       and    #$07                    ;3 
       eor    EnergizerTime           ;3 
       clc                            ;2 Bugfix2
       adc    Temp                    ;3 
       ldy    #$0C                    ;3 
       bne    Background_playsound2   ;3 jump always
Background_playsound:
       lda    TempC                   ;3 
Background_playsound1:
       ldy    #$04                    ;3 
Background_playsound2:
       ldx    #$02                    ;3 
       stx    AUDV0                   ;3 
       sta    AUDF0                   ;3 store a,x,y to the sound registers
       sty    AUDC0                   ;3 
Background_mix:
       ldy    SoundDur                ;3 load note counter
       beq    Sound_routine_clear     ;2 exit if no sound
       dec    SoundDur                ;3 reduce note counter
       ldx    #$05                    ;2 Use voice control 5 for extra life
       tya                            ;2 
       cpy    #$40                    ;2 
       bcc    Sound_routine2          ;2 
       bne    Sound_saveCtr           ;2 
       ldy    #$00                    ;2 
       sty    SoundDur                ;3 clear note counter
Sound_saveCtr:
       and    #$08                    ;2 
       bne    Play_Sound              ;2 
       tax                            ;2 Clear sound during 8/60 intervals for extra life
       beq    Play_Sound              ;2 always jump
Sound_routine2:
       lda    SoundFreqTab,y          ;4 change label to share data for sound if desired
       inx                            ;2 Use voice control 6 for dots
       cpy    #$04                    ;2 
       bcc    Play_Sound              ;2 
       inx                            ;2 Use voice control 7 for fruits & monsters
       bne    Play_Sound              ;2 always jump
Sound_routine_clear:
       lda    #$00                    ;2 
       tax                            ;2 
Play_Sound:
       sta    AUDF1                   ;3 store a,x,y to the sound registers
       stx    AUDV1                   ;3 use control for volume as well
       stx    AUDC1                   ;3 
R_Diff_Check:
       bit    DifSw                   ;4 Check P0 difficulty
       bpl    Check_fruit_eaten       ;2 if B-position, fast speed
       lda    LoTimer                 ;3 compare against fast timer
       and    #$03                    ;2 
       cmp    #$02                    ;2 added to solve animation skip
       beq    Skip_Player_jump        ;3 ...or go back (skip player movement)
       bit    Control                 ;3 
       bvc    Check_fruit_eaten       ;2 
       lda    Control                 ;3 
       and    #$BF                    ;2 
       sta    Control                 ;3 
Skip_Player_jump:
       jmp    Display_Preps           ;3 Dot eaten...skip player movement this frame

Check_fruit_eaten:
       lda    PlayerY                 ;3 
       sta    TempY                   ;3 
       lda    #$00                    ;2 
       sta    TempC                   ;3 
       lda    PlayerX                 ;3 
       sta    TempX                   ;3 
       lda    Control                 ;3 
       and    #$20                    ;2 
       beq    Read_Controller         ;2 
       lda    TempX                   ;3 
       cmp    #$42                    ;2 
       bne    Read_Controller         ;2 
       lda    TempY                   ;3 
       cmp    #$60                    ;2 
       bne    Read_Controller         ;2 
       lda    Control                 ;3 
       and    #$DF                    ;2 
       sta    Control                 ;3 
       bit    Lives                   ;3 Check for PacPlus
       bvc    Eat_Fruit               ;2 branch if regular
       jsr    Energizer_Sub_main      ;6 make all monsters blue
       inc    TotEatenMonsters        ;5 .bump up to get correct point value
Eat_Fruit:
       lda    #$18                    ;2 
       sta    SoundDur                ;3 Sound of eaten fruit
       ldx    Level                   ;3 
       lda    FruitPoints,x           ;4 load the value of the fruit
       sed                            ;2 
       clc                            ;2 
       adc    Score+1                 ;3 
       sta    Score+1                 ;3 
       lda    Score                   ;3 
       adc    #$00                    ;2 
       sta    Score                   ;3 
       cld                            ;2 
       beq    Read_Controller         ;2 If not 10,000 yet, skip ahead
       bit    Lives                   ;3 
       bmi    Read_Controller         ;2 branch if so
       inc    Lives                   ;5 if so, bump up the number of lives.
       lda    Lives                   ;4 
       ora    #$80                    ;3 set high bit to indicate that player awarded
       sta    SoundDur                ;3 ...and save it for the sound
       sta    Lives                   ;4 ...and save it


Read_Controller:
       lda    TempX                   ;3 PlayerX
       ldy    #$00                    ;2 y=0
       cmp    #$44                    ;2 
       bcc    LFF85b                  ;2 
       dey                            ;2 y=FF
       lda    #$84                    ;2 
       sec                            ;2 Bugfix2
       sbc    TempX                   ;3 
LFF85b:
       cmp    #$3F                    ;2 
       bcc    LFF8Bb                  ;2 
       lda    #$3F                    ;2 
LFF8Bb:
       sty    $DB                     ;3 
       sta    $DA                     ;3 
       lda    SWCHA                   ;4 
       sta    $B3                     ;3 
       and    #$F0                    ;2 
       cmp    #$F0                    ;2 
       beq    Check_old_stick         ;2 
       ldx    #$04                    ;2 
       lda    #$00                    ;2 
       sta    PrintTemp+11            ;3 
LFF31:
       tay                            ;2 
       lda    DirBitTestTab,y         ;4 
       and    $B3                     ;3 
       bne    LFF63                   ;2 
       tya                            ;2 
       lsr                            ;2 
       bcc    LFF4B                   ;2 
       lda    TempY                   ;3 
       and    #$07                    ;2 
       bne    LFF63                   ;2 
       lda    $DA                     ;3 
       and    #$07                    ;2 
       bne    LFF5C                   ;2 
       beq    LFF57                   ;2 
LFF4B:
       lda    $DA                     ;3 
       and    #$07                    ;2 
       bne    LFF63                   ;2 
       lda    TempY                   ;3 
       and    #$07                    ;2 
       bne    LFF5C                   ;2 
LFF57:
       jsr    LFEF5                   ;6 
       bcc    LFF63                   ;2 
LFF5C:
       ldy    PrintTemp+11            ;3 
       lda    DirBitTestTab,y         ;4 
       bne    LFF6D                   ;2 
LFF63:
       inc    PrintTemp+11            ;5 
       lda    PrintTemp+11            ;3 
       cmp    #$04                    ;2 
       bne    LFF31                   ;2 
       lda    #$00                    ;2 
LFF6D:
       eor    #$FF                    ;2 
       sta    $B2                     ;3 
       cmp    #$FF                    ;2 
       bne    Position_adjust_start   ;2 
Check_old_stick:
       lda    OldStick                ;3 
       sta    $B3                     ;3 
       ldx    #$04                    ;2 
       lda    #$00                    ;2 
       sta    PrintTemp+11            ;3 
LFF31a:
       tay                            ;2 
       lda    DirBitTestTab,y         ;4 
       and    $B3                     ;3 
       bne    LFF63a                  ;2 
       tya                            ;2 
       lsr                            ;2 
       bcc    LFF4Ba                  ;2 
       lda    TempY                   ;3 
       and    #$07                    ;2 
       bne    LFF63a                  ;2 
       lda    $DA                     ;3 
       and    #$07                    ;2 
       bne    LFF5Ca                  ;2 
       beq    LFF57a                  ;2 
LFF4Ba:
       lda    $DA                     ;3 
       and    #$07                    ;2 
       bne    LFF63a                  ;2 
       lda    TempY                   ;3 
       and    #$07                    ;2 
       bne    LFF5Ca                  ;2 
LFF57a:
       jsr    LFEF5                   ;6 
       bcc    LFF63a                  ;2 
LFF5Ca:
       ldy    PrintTemp+11            ;3 
       lda    DirBitTestTab,y         ;4 
       bne    LFF6Da                  ;2 
LFF63a:
       inc    PrintTemp+11            ;5 
       lda    PrintTemp+11            ;3 
       cmp    #$04                    ;2 
       bne    LFF31a                  ;2 
       lda    #$00                    ;2 
LFF6Da:
       eor    #$FF                    ;2 
       sta    $B2                     ;3 

Position_adjust_start:
       ldy    #$00                    ;2 
       sty    PacOffset               ;3 
       ldx    TempX                   ;3 PlayerX
       lda    $B2                     ;3 
       sta    OldStick                ;3 
       bmi    Check_Player_Left       ;2 
Move_Player_Right:
       ldy    #$22                    ;2 offset
       inx                            ;2 move player right
       jmp    Check_Prev_player       ;3 bugfix
Check_Player_Left:
       asl                            ;2 
       bmi    Check_Player_Down       ;2 
Move_Player_Left:
       ldy    #$44                    ;2 
       dex                            ;2 move player left
       jmp    Check_Prev_player       ;3 bugfix
Check_Player_Down:
       asl                            ;2 
       bmi    Check_Player_Up         ;2 
       ldy    #$66                    ;2 
       inc    TempY                   ;5 
       jmp    Check_Prev_player       ;3 bugfix
Check_Player_Up:
       asl                            ;2 
       bmi    Check_Prev_player       ;2 
       ldy    #$88                    ;2 
       dec    TempY                   ;5 move player up
Check_Prev_player:
       lda    TempY                   ;3
       cmp    PlayerY                 ;3 check our previous location
       bne    Player_animation_check  ;2 if both equal, skip animation
       cpx    PlayerX                 ;2 .
       beq    Copy_Temps2player       ;2 if both equal, skip animation
Player_animation_check:
       lda    LoTimer                 ;3 
       lsr                            ;2 
       and    #$03                    ;2 
       beq    NoMouth                 ;2 
       and    #$01                    ;2 
       beq    Copy_Temps2player       ;2 
       tya                            ;2 
       sec                            ;2 
       sbc    #$11                    ;2 flip to next bitmap
NoMouth:
       tay                            ;2 00 no mouth
Copy_Temps2player:
       txa                            ;2
       cmp    #$FF                    ;2 did we go through the left tunnel?
       bne    ccheckrightboundry      ;2 
       lda    #$84                    ;2 if so, flip to the right
       jmp    CCheck_Tunnel_Exit      ;3 
ccheckrightboundry:
       cmp    #$85                    ;2 did we go through the right tunnel?
       bne    CCheck_Tunnel_Exit      ;2 
       lda    #$00                    ;2 if so, flip to the left
CCheck_Tunnel_Exit:
       sta    PlayerX                 ;3 
       lda    TempY                   ;3
       cmp    #$FF                    ;2 did we go through the left tunnel?
       bne    cchecklowerboundry      ;2 
       lda    #$A0                    ;2 if so, flip to the right
       jmp    CheckL_Tunnel_Exit      ;3 
cchecklowerboundry:
       cmp    #$A1                    ;2 did we go through the right tunnel?
       bne    CheckL_Tunnel_Exit      ;2 
       lda    #$00                    ;2 if so, flip to the left
CheckL_Tunnel_Exit:
       sta    PlayerY                 ;3
       sty    PacOffset               ;3 store offset
       lda    PlayerY                 ;3 
       and    #$07                    ;2 
       bne    LF731                   ;2 
       lda    PlayerY                 ;3 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       tax                            ;2 
       lda    PlayerX                 ;3 
       cmp    #$4C                    ;2 
       bcc    LF730                   ;2 
       sec                            ;2 
       sbc    #$4C                    ;2 
       tay                            ;2 
       and    #$07                    ;2 
       bne    LF731                   ;2 
       tya                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       cmp    #$08                    ;2 
       bcs    LF732                   ;2 
       tay                            ;2 
       cpy    #$07                    ;2 
       bne    LF71A                   ;2 
       cpx    #$01                    ;2 
       beq    LL_Energizer_detect     ;2 
       cpx    #$0F                    ;2 
       bne    LF71A                   ;2 
       ldx    #$03                    ;2 
Energizer_detect:
       lda    RamDots+42,x            ;4 
       beq    LF759                   ;2 
       lda    #$00                    ;2 
       sta    RamDots+42,x            ;4 
       jsr    Energizer_Sub_main      ;6 
       lda    #$50                    ;2 50 pts.
       sta    SoundDur                ;3 save the sound
       bne    LF779                   ;2 
LL_Energizer_detect:
       ldx    #$02                    ;2 
       bne    Energizer_detect        ;2 
LF71A:
       lda    Right_Bit_PatternTab,y  ;4 
       and    RamDots+21,x            ;4 
       bne    No_Display_Pr           ;2 
Display_Preps_jjjmp:
       jmp    Display_Preps           ;2 
No_Display_Pr:
       lda    Right_Bit_PatternTab,y  ;4 
       eor    #$FF                    ;2 
       and    RamDots+21,x            ;4 
       sta    RamDots+21,x            ;4 
       jmp    LF76B                   ;3 

LF730:
       tay                            ;2 
       and    #$07                    ;2 
LF731:
       bne    Display_Preps_jjjmp     ;2 
       tya                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       cmp    #$08                    ;2 
LF732:
       bcs    Display_Preps           ;2 
UR_Energizer_detect:
       tay                            ;2 
       bne    LF758                   ;2 
       cpx    #$01                    ;2 
       beq    LR_Energizer_detect     ;2 
       cpx    #$0F                    ;2 
       bne    LF758                   ;2 
       ldx    #$01                    ;2 
       bne    Energizer_detect        ;2 
LR_Energizer_detect:
       dex                            ;2 
       beq    Energizer_detect        ;2 
LF758:
       lda    Left_Bit_PatternTab,y   ;4 
       and    RamDots,x               ;4 
LF759:
       beq    Display_Preps           ;2 
       lda    Left_Bit_PatternTab,y   ;4 
       eor    #$FF                    ;2 
       and    RamDots,x               ;4 
       sta    RamDots,x               ;4 
LF76B:
       lda    Control                 ;3 
       ora    #$40                    ;2 set the slowdown bit
       sta    Control                 ;3 
  IF EQUALPT
       lda    #$16                    ;2 16 pts.
  ELSE
       lda    #$10                    ;2 10 pts.
  ENDIF
LF779:
       sed                            ;2 
       clc                            ;2 
       adc    Score+2                 ;3 
       sta    Score+2                 ;3 
       lda    #$00                    ;2 
       adc    Score+1                 ;3 
       sta    Score+1                 ;3 
       lda    Score                   ;3 
       adc    #$00                    ;2 
       sta    Score                   ;3 
       cld                            ;2 
       beq    AddToScoreLEnd          ;2 If not 10,000 yet, skip ahead
       bit    Lives                   ;3 
       bmi    AddToScoreLEnd          ;2 branch if so
       inc    Lives                   ;5 if so, bump up the number of lives.
       lda    Lives                   ;4 
       ora    #$80                    ;3 set high bit to indicate that player awarded
       sta    SoundDur                ;3 ...and save it for the sound
       sta    Lives                   ;4 ...and save it
AddToScoreLEnd:
       lda    SoundDur                ;3 

       bne    Check_Dot_count         ;2 

       lda    #$03                    ;2 
       sta    SoundDur                ;3 
Check_Dot_count:
       dec    DotCount                ;5 
       lda    DotCount                ;3 
       bne    Check_Dot_countA        ;2 
       lda    #$00                    ;2 
       sta    Control                 ;3    -no dots detected-
Check_Dot_countA:
       cmp    #$33                    ;3 if 51 dots eaten...
       beq    Fruit_Wanted            ;2 
       cmp    #$65                    ;3 or 101, get fruit
       bne    Display_Preps           ;2 otherwise, skip
Fruit_Wanted:
       lda    Control                 ;3 check the control byte for...
       and    #$20                    ;2 a fruit being active (bit 5)
       bne    Display_Preps           ;2 branch if so
       lda    Control                 ;3 
       ora    #$20                    ;2 fruit wanted (add to the control byte)
       sta    Control                 ;3 
       lda    HiTimer                 ;3 
       and    #$0F                    ;2 
       ora    #$60                    ;2 give the timer something
       sta    HiTimer                 ;3 
Display_Preps:
       jmp    Display_Prepf           ;3




START:
       ldx    #$00                    ;2 
       txa                            ;2 
LoopClear:
       dex                            ;2 
       txs                            ;2 
       pha                            ;2 
       bne    LoopClear               ;2 
Display_Title:
       lda    #$1C                    ;2 
       sta    COLUPF                  ;3 
       lda    #$21                    ;2 
       sta    CTRLPF                  ;3 
Start_Frame:
       lda    #$02                    ;2 
       sta    VSYNC                   ;3 
       sta    WSYNC                   ;3 
       sta    WSYNC                   ;3 
       sta    WSYNC                   ;3 3 Scanlines of VSYNC 
       lda    #$00                    ;2 
       sta    VSYNC                   ;3 
       sta    WSYNC                   ;3 
;Display 37 Scanlines before vblank
       ldy    #37                     ;2 
PictureV:
       sta    WSYNC                   ;3 
       dey                            ;2 End of Picture ? 
       bne    PictureV                ;2 No = Continue 
       sta    VBLANK                  ;3 Enable TIA Output 
;Display 80 Scanlines 
       ldx    #80                     ;2 80 Scanlines 
Picture:
       sta    WSYNC                   ;3 
       dex                            ;2 End of Picture ? 
       bne    Picture                 ;2 No = Continue 
       sta    WSYNC                   ;3 
       ldx    #$0B                    ;2 12 pixels
Build:
       ldy    #$04                    ;2 4 scanlines each pixel
Build2:
       sta    WSYNC                   ;3 
       pha                            ;3 
       pla                            ;4 
       lda    Title1,x                ;4 
       sta    PF1                     ;3 
       lda    Title2,x                ;4 
       sta    PF2                     ;3 
       jsr    L12                     ;12
       lda    Title4,x                ;4 
       sta    PF1                     ;3 
       lda    Title5,x                ;4 
       sta    PF2                     ;3 
       dey                            ;2 
       bne    Build2                  ;2 
       dex                            ;2 
       bpl    Build                   ;2 
       sta    WSYNC                   ;3 
       lda    #$00                    ;2 
       sta    PF0                     ;3 
       sta    PF1                     ;3 
       sta    PF2                     ;3 
       sta    COLUPF                  ;3 
       ldy    #61                     ;2 61 Scanlines 
Picture2:
       sta    WSYNC                   ;3 
       dey                            ;2 End of Picture ? 
       bne    Picture2                ;2 No = Continue 
       lda    #%00000010              ;2 
       sta    VBLANK                  ;3 Disable TIA Output 
; 30 Scanlines of Overscan 
       ldx    #30                     ;2 
Overscan:
       sta    WSYNC                   ;3 
       dex                            ;2 
       bne    Overscan                ;2 
       inc    Temp                    ;5 
       lda    Temp                    ;3 
       and    SWCHA                   ;3 
       beq    Rrett                   ;2 
       jmp    Display_Title           ;2 
Rrett:
       ldx    #$06                    ;2 <-extra time if needed
       stx    TIM64T                  ;4 
       jmp    New_Display_Start       ;3 



;beginning music
Play_Tune:
       lda    Score                   ;3 
       ora    Score+1                 ;3 
       ora    Score+2                 ;3 
       beq    NoIntermiss             ;2 skip ahead to intermission routine instead
       jmp    Intermission            ;3 

NoIntermiss:
       ldy    #$05                    ;2 
       inc    SoundDur                ;2 
       lda    SoundDur                ;3 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       tax                            ;2 
       lda    CH0,x                   ;4 
       bpl    play1                   ;2 
       lda    #$08                    ;2 
       sta    HiTimer                 ;3 
       lda    #$00                    ;2 
       sta    SoundDur                ;3 
       jmp    Clear_Audio_Start       ;3
play1:
       bne    play2                   ;2 
       tay                            ;2 
play2:
       sta    AUDF0                   ;3 
       sty    AUDC0                   ;3 
       cpy    #$00                    ;2
       beq    ps0                     ;2
       ldy    #$05                    ;2 
ps0:
       sty    AUDV0                   ;3 
loadch1:
       ldy    #$01                    ;2 
       lda    CH1,x                   ;4 
       bne    playch1                 ;2
       tay                            ;2 
playch1:
       sta    AUDF1                   ;3 
       sty    AUDC1                   ;3 
       cpy    #$00                    ;2
       beq    ps1                     ;2
       ldy    #$05                    ;2 
ps1:
       sty    AUDV1                   ;3 
Display_Prepf:
end:
Display_Prep:
       lda    LoTimer                 ;3 
       and    #$03                    ;2 
       tay                            ;2 
       lda    EnergizerTime           ;3 maze color
       and    #$F0                    ;2 
       pha                            ;3 
       lda    DifSw                   ;3 save the difficultys
       and    #$C0                    ;2 CO...for the score color
       ora    #$06                    ;2 OA
       pha                            ;3 ...push it to the stack
;energizers
       lda    LoTimer                 ;3 
       and    #$10                    ;2 
       php                            ;3 
       ldx    EnergizerVtab,y         ;4 load it's vertical position
       lda    RamDots,x               ;4 load the data for that row of dots
       plp                            ;4 
       bne    Energizer_blink         ;2 
       ora.wy RamDots+42,y            ;4 ora in the energizer to the dot data
       jmp    Energizer_save          ;3 

Energizer_blink:
       and    #$6F                    ;2 AND back in the dots
Energizer_save:
       sta    RamDots,x               ;4 ...and save
       ldx    #$0A                    ;2 
;logo
       lda    Lives                   ;3 
       and    #$07                    ;2 
       bne    NoLogo                  ;2 jump unless the game is over
       bit    LoTimer                 ;3 
       bmi    NoScoreYet              ;2 if not set, skip the logo and display score

NoLogo:
       ldy    #$02                    ;2 
Convert_score:
       lda    Score,y                 ;4 load a digit...
       and    #$0F                    ;2 ...and strip off the upper nybble
       jsr    TransDigit              ;6 
       lda    Score,y                 ;4 load a digit...
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       jsr    TransDigit              ;6 
       dey                            ;2 
       bpl    Convert_score           ;2 
       bmi    Convert_End             ;2 always jump


NoScoreYet:
       ldy    $05                     ;3 
ConvertLogo:
       lda    LetterTab,y             ;4 
       sta    PrintTemp,x             ;4 use the logo bitmaps instead of digits
       lda    #>DigZ                  ;2 
       sta    PrintTemp+1,x           ;4 
       dex                            ;2 
       dex                            ;2 
       dey                            ;2 
       bpl    ConvertLogo             ;2 
       bit    Lives                   ;3 Check for PacPlus
       bvc    ConvertLogoPlus         ;2 branch if regular
       lda    #<DigT                  ;2 
       sta    PrintTemp+10            ;4 
ConvertLogoPlus:
       pla                            ;4 toss the previous color
       lda    EnergizerTime           ;3 maze color
       and    #$F0                    ;2 
       sbc    #$64                    ;3 yellow logo $80-$66
       pha                            ;3 ...and push that instead
Convert_End:
       ldy    #$07                    ;2 
       lda    Level                   ;3
       sta    WSYNC                   ;3 
;wait34Cycles 
;       dey                            ;2 
;       bne    wait34Cycles            ;2 
       and    #$01                    ;2
       sta    Temp                    ;3
       lda    DifSw                   ;3 check diff.
       and    #$08                    ;2 B&W switch only
       lsr                            ;2 
       lsr                            ;2 
       adc    Temp                    ;3 save for +2 offset

       tax                            ;2 
       lda    ExitLo,x                ;4 
       sta    IndExit                 ;3 
       lda    ExitHi,x                ;4 
       sta.w  IndExit+1               ;4 

       sta    RESP0                   ;3 = @37 
       lda    #$90 | $03              ;3 HMOVE right 7 or'd with 3 copies of the player 
       sta    RESP1                   ;3 = @42 
       sta    HMP0                    ;3 
       sty    HMP1                    ;3 x = 0 from above loop...might not be needed 
       sta    NUSIZ0                  ;3 3 close copies of player 0 
       sta    NUSIZ1                  ;3 3 close copies of player 1
       sta    WSYNC                   ;3 
       sta    HMOVE                   ;3 
       pla                            ;4 pull off the score/logo color
       tax                            ;2 ...and give to X
       pla                            ;4 pull off the maze color
       tay                            ;2 
Flash_Screen:
       lda    Control                 ;3 
       cmp    #$10                    ;2 
       bcs    Set_Playfield_Color     ;2 
       lda    LoTimer                 ;3 board finished...flash
       lsr                            ;2 
       and    #$08                    ;2 maze color light
       ora    Lives                   ;3 Check for PacPlus
       ora    #$80                    ;2 maze color dark
       and    #$C8                    ;2 maze color dark
       tay                            ;2 
Set_Playfield_Color:
       stx    COLUP0                  ;3 
       stx    COLUP1                  ;3 
       sty    RamDots+46              ;3 energizer control...use to hold temp maze color
       jmp    Display_Prepbank1       ;3 
















Intermission:
       ldx    Level                   ;3 
       cpx    #$02                    ;2 
       beq    Part1                   ;2 
       cpx    #$05                    ;2 
       beq    Part2                   ;2 
       jmp    Part3                   ;3 
Part1:
       lda    SoundDur                ;3 
       bmi    Part1_2                 ;2 
Part1_1:
       tax                            ;2 
       and    #$7F                    ;2 
       eor    #$7F                    ;2 
;pac pos
       sta    PrintTemp+1             ;3 
;monster pos
       clc                            ;2 Bugfix2
       adc    #$08                    ;2 
       sta    PrintTemp               ;3 
;pac frame
       txa                            ;2 
       and    #$0C                    ;2 
       lsr                            ;2 
       lsr                            ;2 
       tay                            ;2 
       lda    SpacO,y                 ;4 
       sta    PrintTemp+2             ;3 
;monster frame
       txa                            ;2 
       and    #$04                    ;2 
       asl                            ;2 
       asl                            ;2 
       clc                            ;2 
       adc    #<Lethal                ;2 
       sta    PrintTemp+4             ;3 
       lda    #>IGFX                  ;2 
       sta    PrintTemp+3             ;3 
       sta    PrintTemp+5             ;3 
       lda    #$1C                    ;2 
       sta    COLUP0                  ;3 
       lda    #$36                    ;2 
       sta    COLUP1                  ;3 
       jmp    Move_I                  ;3 
Part1_2:
       tax                            ;2 
       and    #$7F                    ;2 
;pac pos
       sta    PrintTemp+1             ;3 
;monster pos
       clc                            ;2 Bugfix2
       adc    #$0F                    ;2 
       sta    PrintTemp               ;3 
;pac frame
       txa                            ;2 
       and    #$0C                    ;2 
       lsr                            ;2 
       lsr                            ;2 
       tay                            ;2 
       lda    LpacO,y                 ;4 
       sta    PrintTemp+2             ;3 
;monster frame
       txa                            ;2 
       and    #$04                    ;2 
       asl                            ;2 
       asl                            ;2 
       clc                            ;2 
       adc    #<Vulnerable            ;2 
       bit    Lives                   ;3 Check for PacPlus
       bvc    NoFlag                  ;2 branch if regular
       clc                            ;2 
       adc    #$20                    ;2 
NoFlag:
       sta    PrintTemp+4             ;3 
       lda    #>IGFX                  ;2 
       sta    PrintTemp+3             ;3 
       sta    PrintTemp+5             ;3 
       lda    #$1C                    ;2 
       sta    COLUP0                  ;3 
       lda    #$80                    ;2 
       sta    COLUP1                  ;3 
       lda    #$05                    ;2 
       sta    NUSIZ0                  ;3 
       bne    GoAhead                 ;2 always jump
Part2:
       lda    SoundDur                ;3 
       bmi    Part2_2                 ;2 
Part2_1:
       tax                            ;2 
       and    #$7F                    ;2 
       eor    #$7F                    ;2 
;pac pos
       sta    PrintTemp+1             ;3 
;monster pos
       cmp    #$3B                    ;2 
       bcs    Higher                  ;2 
       lda    #<Torn                  ;2 
       sta    PrintTemp+4             ;3 
       lda    #>IGFX-1                ;2 
       sta    PrintTemp+5             ;3 
       lda    #$42                    ;2 
       sta    PrintTemp               ;3 
       bne    DoPac                   ;2 
Higher:
       clc                            ;2 Bugfix2
       adc    #$08                    ;2 
       sta    PrintTemp               ;3 
;monster frame
       txa                            ;2 
       and    #$04                    ;2 
       asl                            ;2 
       asl                            ;2 
       clc                            ;2 
       adc    #<Lethal                ;2 
       sta    PrintTemp+4             ;3 
       lda    #>IGFX                  ;2 
       sta    PrintTemp+5             ;3 
DoPac:
;pac frame
       txa                            ;2 
       and    #$0C                    ;2 
       lsr                            ;2 
       lsr                            ;2 
       tay                            ;2 
       lda    SpacO,y                 ;4 
       sta    PrintTemp+2             ;3 
       lda    #>IGFX                  ;2 
       sta    PrintTemp+3             ;3 
       lda    #$1C                    ;2 
       sta    COLUP0                  ;3 
       lda    #$36                    ;2 
       sta    COLUP1                  ;3 
       jmp    Move_I                  ;3 
Part2_2:
       lda    #<Torn2                 ;2 
       sta    PrintTemp+4             ;3 
       lda    #$42                    ;2 
       sta    PrintTemp               ;3 
       sta    PrintTemp+1             ;3 
       lda    LoTimer                 ;2 
       and    #$40                    ;2 
       lsr                            ;2 
       lsr                            ;2 
       clc                            ;2 
       adc    #<Foot                  ;2 
       sta    PrintTemp+2             ;3 
       lda    #>IGFX-1                ;2 
       sta    PrintTemp+3             ;3 
       sta    PrintTemp+5             ;3 
       lda    #$2C                    ;2 
       sta    COLUP0                  ;3 
       lda    #$36                    ;2 
       sta    COLUP1                  ;3 
GoAhead:
       bne    Move_I                  ;2 always jump
Part3:
       lda    SoundDur                ;3 
       bmi    Part3_2                 ;2 
Part3_1:
       tax                            ;2 
       and    #$7F                    ;2 
       eor    #$7F                    ;2 
;pac pos
       sta    PrintTemp+1             ;3 
;monster pos
       clc                            ;2 Bugfix2
       adc    #$08                    ;2 
       sta    PrintTemp               ;3 
;pac frame
       txa                            ;2 
       and    #$0C                    ;2 
       lsr                            ;2 
       lsr                            ;2 
       tay                            ;2 
       lda    SpacO,y                 ;4 
       sta    PrintTemp+2             ;3 
;monster frame
       txa                            ;2 
       and    #$04                    ;2 
       asl                            ;2 
       asl                            ;2 
       clc                            ;2 
       adc    #<Lethal                ;2 
       sta    PrintTemp+4             ;3 
       lda    #>IGFX                  ;2 
       sta    PrintTemp+3             ;3 
       sta    PrintTemp+5             ;3 
       lda    #$1C                    ;2 
       sta    COLUP0                  ;3 
       lda    #$36                    ;2 
       sta    COLUP1                  ;3 
       jmp    Move_I                  ;3 
Part3_2:
       tax                            ;2 
       and    #$7F                    ;2 
;monster pos
       sta    PrintTemp               ;3 
;pac pos
       sta    PrintTemp+1             ;3 
;pac frame
       txa                            ;2 
       and    #$04                    ;2 
       asl                            ;2 
       asl                            ;2 
       clc                            ;2 
       adc    #<NakedEyes             ;2 
       sta    PrintTemp+2             ;3 
;monster frame
       txa                            ;2 
       and    #$04                    ;2 
       asl                            ;2 
       asl                            ;2 
       clc                            ;2 
       adc    #<Naked                 ;2 
       sta    PrintTemp+4             ;3 
       lda    #>IGFX-1                ;2 
       sta    PrintTemp+3             ;3 
       lda    #>IGFX                  ;2 
       sta    PrintTemp+5             ;3 
       lda    #$0C                    ;2 
       sta    COLUP0                  ;3 
       lda    #$2A                    ;2 
       sta    COLUP1                  ;3 
Move_I:
       lda    PrintTemp               ;3 
       cmp    #$85                    ;2 
       bcc    P_under                 ;2 
       lda    #$F0                    ;2 
       bne    P_over                  ;2 
P_under:
       tay                            ;2 
       jsr    Reposition              ;6 
P_over:
       sta    PrintTemp               ;3 
       lda    PrintTemp+1             ;3 
       cmp    #$85                    ;2 
       bcc    M_under                 ;2 
       lda    #$F0                    ;2 
       bne    M_over                  ;2 
M_under:
       tay                            ;2 
       jsr    Reposition              ;6 
M_over:
       sta    PrintTemp+1             ;3 
       lda    #$02                    ;4 
YRetrace_Wait:
       ldy    INTIM                   ;4 
       bne    YRetrace_Wait           ;2 
       sty    WSYNC                   ;3 
       sty    VBLANK                  ;3 
       sty    WSYNC                   ;3 
;Display 37 Scanlines before vblank
       ldy    #37                     ;2 80 Scanlines 
Picturej:
       sta    WSYNC                   ;3 
       dey                            ;2 End of Picture ? 
       bne    Picturej                ;2 No = Continue 
       lda    #$00                    ;2 
       sta    VBLANK                  ;3 Enable TIA Output 
       ldy    #44                     ;2 44 Scanlines 
Top:
       sta    WSYNC                   ;3 
       dey                            ;2 
       bne    Top                     ;2 
       sty    NUSIZ1                  ;3 
       sty    GRP0                    ;3 
       sty    GRP1                    ;3 
       sty    PF0                     ;3 
       sty    PF1                     ;3 
       sty    PF2                     ;3 
       sty    COLUPF                  ;3 
       sty    COLUBK                  ;3 
       NOP                            ;2 
       NOP                            ;2 
       NOP                            ;2 
       NOP                            ;2 
       NOP                            ;2 
       lda    PrintTemp               ;3 
       tay                            ;2 
       and    #$0F                    ;2 
       sta    WSYNC                   ;3 
       tax                            ;2 
       lda    #$00                    ;2 
       NOP                            ;2 
       NOP                            ;2 
       NOP                            ;2 
       sty    HMP1                    ;3 
       NOP                            ;2 
       dex                            ;2 
Score_Done_wait:
       dex                            ;2 
       bpl    Score_Done_wait         ;2 
       sta    RESP1                   ;3 
       sta    WSYNC                   ;3 
       lda    PrintTemp+1             ;3 
       tay                            ;2 
       and    #$0F                    ;2 
       sta    WSYNC                   ;3 
       tax                            ;2 
       lda    #$00                    ;2 
       NOP                            ;2 
       NOP                            ;2 
       NOP                            ;2 
       sty    HMP0                    ;3 
       NOP                            ;2 
       dex                            ;2 
SScore_Done_wait:
       dex                            ;2 
       bpl    SScore_Done_wait        ;2 
       sta    RESP0                   ;3 
       sta    WSYNC                   ;3 
       sta    HMOVE                   ;3 
       sta    WSYNC                   ;3 
       ldy    Level                   ;3 
       cpy    #$05                    ;2 
       bne    NoNail0                 ;2 
       ldy    SoundDur                ;3 a=0
       cpy    #$3A                    ;2 
       bcc    NoNail0                 ;2 
       lda    #$0E                    ;2
NoNail0:
       sta    COLUPF                  ;3 
       inx                            ;2 x=0
       ldy    #$00                    ;2 
DispLoop:
       stx    WSYNC                   ;3 
       lda    (PrintTemp+2),y         ;5 
       sta    GRP0                    ;3 
       lda    (PrintTemp+4),y         ;5 
       sta    GRP1                    ;3 
       lda    #$00                    ;2
       sta    PF2                     ;3 
       iny                            ;2 
       jsr    L12                     ;12 
       cpy    #$0D                    ;2 
       bne    NoNail                  ;2 
       lda    #$40                    ;2
       bne    Nail                    ;2 
NoNail:
       lda    #$00                    ;2
Nail:
       sta    PF2                     ;3 
       cpy    #$10                    ;2 
       bne    DispLoop                ;2 
       stx    WSYNC                   ;3 
       stx    GRP0                    ;3 
       stx    GRP1                    ;3 
       stx    COLUP0                  ;3 
       stx    COLUP1                  ;3 
       stx    COLUPF                  ;3 
       stx    PF2                     ;3 
       ldy    #67                     ;2 65 Scanlines 
Bottom:
       sta    WSYNC                   ;3 
       dey                            ;2 End of Picture ? 
       bne    Bottom                  ;2 No = Continue 
       lda    #%00000010              ;2 
       sta    VBLANK                  ;3 Disable TIA Output 
; 30 Scanlines of Overscan 
       ldx    #30                     ;2 
Overscann:
       sta    WSYNC                   ;3 
       dex                            ;2 
       bne    Overscann               ;2 
;Play_ITune:
       ldy    #$05                    ;2 
       lda    LoTimer                 ;3 
       and    #$03                    ;2 
       beq    Donot                   ;2 
       inc    SoundDur                ;2 
Donot:
       lda    SoundDur                ;3 
       lsr                            ;2 
       lsr                            ;2 
       lsr                            ;2 
       tax                            ;2 
       lda    CCH0,x                  ;4 
       bpl    Iplay1                  ;2 
       lda    #$08                    ;2 
       sta    HiTimer                 ;3 
       lda    #$7F                    ;2 
       sta    Control                 ;3 
       lda    #$00                    ;2 
       sta    SoundDur                ;3 
       beq    I_end                   ;2 <-good end
Iplay1:
       bne    Iplay2                  ;2 
       tay                            ;2 
Iplay2:
       sta    AUDF0                   ;3 
       sty    AUDC0                   ;3 
       cpy    #$00                    ;2
       beq    Ips0                    ;2
       ldy    #$05                    ;2 
Ips0:
       sty    AUDV0                   ;3 
Iloadch1:
       ldy    #$01                    ;2 
       lda    CCH1,x                  ;4 
       bne    Iplaych1                ;2
       tay                            ;2 
Iplaych1:
       sta    AUDF1                   ;3 
       sty    AUDC1                   ;3 
       cpy    #$00                    ;2
       beq    Ips1                    ;2
       ldy    #$05                    ;2 
Ips1:
       sty    AUDV1                   ;3 
I_end:

       ldx    #$15                    ;2 <-extra time if needed
       stx    TIM64T                  ;4 
       jmp    LFC4C                   ;3 




;17
TransDigit:
       sty    Temp                    ;3 
       tay                            ;2 
       lda    DigitTab_low,y          ;4 use the result as an offset
       ldy    Temp                    ;3 
       sta    PrintTemp,x             ;5 
       lda    #>Digit1tab             ;2 (i.e. page # of all digit gfx)
       sta    PrintTemp+1,x           ;5 
       dex                            ;2 
       dex                            ;2 
       rts                            ;6 


;  ORG $2BF8
;  RORG $FBF8
;       nop


  ORG $2C39
  RORG $FC39

Monster_colors_tab:
       .byte $37 ; |  XX XXX| $F2E4
       .byte $5B ; | X XX XX| $F2E5
       .byte $2B ; |  X X XX| $F2E7
Death:
       .byte $77,$88,$99,$AA,$BB,$CC,$DD,$EE

CCH0:
       .byte $14
       .byte $14
       .byte $14
       .byte $15
       .byte $14
       .byte $14
       .byte $13
       .byte $13

       .byte $14
       .byte $14
       .byte $14
       .byte $15
       .byte $14
       .byte $14
       .byte $16
       .byte $16

       .byte $14
       .byte $14
       .byte $14
       .byte $15
       .byte $14
       .byte $14
       .byte $13
       .byte $12

       .byte $11
       .byte $14
       .byte $15
       .byte $16
       .byte $14
       .byte $14
       .byte $16
       .byte $FF



CCH1:
       .byte $14
       .byte $14
       .byte $14
       .byte $15
       .byte $14
       .byte $14
       .byte $13
       .byte $13

       .byte $14
       .byte $14
       .byte $14
       .byte $15
       .byte $14
       .byte $14
       .byte $16
       .byte $16

       .byte $14
       .byte $14
       .byte $14
       .byte $15
       .byte $14
       .byte $14
       .byte $13
       .byte $12

       .byte $11
       .byte $14
       .byte $15
       .byte $16
       .byte $14
       .byte $14
       .byte $16
       .byte $FF

CH0:
       .byte $1D
       .byte $0E
       .byte $13
       .byte $17
       .byte $0E
       .byte $13
       .byte $17
       .byte $00

       .byte $1C
       .byte $0D
       .byte $12
       .byte $16
       .byte $0D
       .byte $12
       .byte $16
       .byte $00

       .byte $1D
       .byte $0E
       .byte $13
       .byte $17
       .byte $0E
       .byte $13
       .byte $17
       .byte $00

       .byte $17
       .byte $15
       .byte $13
       .byte $15
       .byte $13
       .byte $11
       .byte $0E
       .byte $FF

Torn:
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $38 ;fe1a |  XXX   |
       .byte $7C ;fe1b | XXXXX  |
       .byte $54 ;fe1c | X X X  |
       .byte $D6 ;fe1d |XX X XX |
       .byte $FE ;fe1e |XXXXXXX |
       .byte $FE ;fe1f |XXXXXXX |
       .byte $FE ;fe20 |XXXXXXX |
       .byte $77 ;fe21 | XXX XXX|
       .byte $23 ;fe22 |  X   XX|
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
Torn2:
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $38 ;fe1a |  XXX   |
       .byte $7C ;fe1b | XXXXX  |
       .byte $54 ;fe1c | X X X  |
       .byte $D6 ;fe1d |XX X XX |
       .byte $FE ;fe1e |XXXXXXX |
       .byte $FE ;fe1f |XXXXXXX |
       .byte $FE ;fe20 |XXXXXXX |
       .byte $DC ;fe21 |XX XXX  |
       .byte $8B ;fe22 |X   X XX|
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |


NakedEyes:
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $00 ;fe09 |        |
       .byte $00 ;fe0a |        |
       .byte $36 ;fe0b |  XX XX |
       .byte $24 ;fe0c |  X  X  |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $00 ;fe09 |        |
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |

       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe09 |        |
       .byte $00 ;fe0a |        |
       .byte $1B ;fe0b |   XX XX|
       .byte $12 ;fe0c |   X  X |
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
Foot:
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $00 ;fe1a |        |
       .byte $00 ;fe1c |        |
       .byte $28 ;fe1d |  X X   |
       .byte $00 ;fe1e |        |
       .byte $00 ;fe1b |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $04 ;fe19 |     X  |
       .byte $06 ;fe22 |     XX |
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |

       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $00 ;fe1a |        |
       .byte $00 ;fe1c |        |
       .byte $00 ;fe1e |        |
       .byte $00 ;fe1e |        |
       .byte $00 ;fe1b |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $04 ;fe19 |     X  |
       .byte $06 ;fe22 |     XX |
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |



  ORG $2D00
  RORG $FD00

;intermission GFX
IGFX:
Lethal:
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $1C ;fe09 |   XXX  |
       .byte $3E ;fe0a |  XXXXX |
       .byte $2A ;fe0b |  X X X |
       .byte $6B ;fe0c | XX X XX|
       .byte $7F ;fe0d | XXXXXXX|
       .byte $7F ;fe0e | XXXXXXX|
       .byte $7F ;fe0f | XXXXXXX|
       .byte $6E ;fe10 | XX XXX |
       .byte $44 ;fe11 | X   X  |
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |

       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $1C ;fe1a |   XXX  |
       .byte $3E ;fe1b |  XXXXX |
       .byte $2A ;fe1c |  X X X |
       .byte $6B ;fe1d | XX X XX|
       .byte $7F ;fe1e | XXXXXXX|
       .byte $7F ;fe1f | XXXXXXX|
       .byte $7F ;fe20 | XXXXXXX|
       .byte $3B ;fe21 |  XXX XX|
       .byte $11 ;fe22 |   X   X|
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |

Vulnerable:
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $1C ;fe2b |   XXX  |
       .byte $3E ;fe2c |  XXXXX |
       .byte $2A ;fe2d |  X X X |
       .byte $7F ;fe2e | XXXXXXX|
       .byte $6B ;fe2f | XX X XX|
       .byte $55 ;fe30 | X X X X|
       .byte $7F ;fe31 | XXXXXXX|
       .byte $6E ;fe32 | XX XXXX|
       .byte $44 ;fe33 | X   XX |
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |

       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $1C ;fe3c |   XXX  |
       .byte $3E ;fe3d |  XXXXX |
       .byte $2A ;fe3e |  X X X |
       .byte $7F ;fe3f | XXXXXXX|
       .byte $6B ;fe40 | XX X XX|
       .byte $55 ;fe41 | X X X X|
       .byte $7F ;fe42 | XXXXXXX|
       .byte $3B ;fe43 | XXX XXX|
       .byte $11 ;fe44 |  X   XX|
       .byte $00 ;fe12 |        |
       .byte $00 ;fe13 |        |
       .byte $00 ;fe14 |        |

       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $0C ;fe4d |    XX  |
       .byte $08 ;fe4e |    X   |
       .byte $1C ;fe2b |   XXX  |
       .byte $2A ;fe2d |  X X X |
       .byte $7F ;fe2e | XXXXXXX|
       .byte $6B ;fe2f | XX X XX|
       .byte $55 ;fe30 | X X X X|
       .byte $6E ;fe32 | XX XXXX|
       .byte $44 ;fe33 | X   XX |
       .byte $00 ;fe12 |        |
       .byte $00 ;fe13 |        |
       .byte $00 ;fe14 |        |

       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $18 ;fe5e |   XX   |
       .byte $08 ;fe5f |    X   |
       .byte $1C ;fe3c |   XXX  |
       .byte $2A ;fe3e |  X X X |
       .byte $7F ;fe3f | XXXXXXX|
       .byte $6B ;fe40 | XX X XX|
       .byte $55 ;fe41 | X X X X|
       .byte $3B ;fe43 | XXXX XX|
       .byte $11 ;fe44 |  XX   X|
       .byte $00 ;fe67 |        |
       .byte $00 ;fe68 |        |
       .byte $00 ;fe69 |        |

Naked:
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe19 |        |
       .byte $00 ;fe09 |        |
       .byte $00 ;fe0a |        |
       .byte $36 ;fe0b |  XX XX |
       .byte $64 ;fe0c | XX  X  |
       .byte $7E ;fe0d | XXXXXX |
       .byte $7C ;fe0f | XXXXX  |
       .byte $7E ;fe10 | XXXXXX |
       .byte $CF ;fe11 |XX  XXXX|
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |

       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |
       .byte $00 ;fe09 |        |
       .byte $00 ;fe0a |        |
       .byte $1B ;fe0b |   XX XX|
       .byte $12 ;fe0c |   X  X |
       .byte $1F ;fe0d |   XXXXX|
       .byte $3C ;fe0f |  XXXX  |
       .byte $38 ;fe0f |  XXX   |
       .byte $7C ;fe0f | XXXXX  |
       .byte $66 ;fe10 | XX  XX |
       .byte $E3 ;fe11 |XXX   XX|
       .byte $00 ;fe16 |        |
       .byte $00 ;fe17 |        |
       .byte $00 ;fe18 |        |


Spac1:
       .byte $00 ; |        | $F213
       .byte $00 ; |        | $F214
       .byte $00 ; |        | $F215
       .byte $00 ; |        | $F207
       .byte $1C ; |   XXX  | $F208 00
       .byte $3E ; |  XXXXX | $F209
       .byte $7F ; | XXXXXXX| $F20A
       .byte $7F ; | XXXXXXX| $F20B
       .byte $7F ; | XXXXXXX| $F20C
       .byte $7F ; | XXXXXXX| $F20D
       .byte $7F ; | XXXXXXX| $F20E
       .byte $3E ; |  XXXXX | $F20F
       .byte $1C ; |   XXX  | $F210
       .byte $00 ; |        | $F211
       .byte $00 ; |        | $F216
       .byte $00 ; |        | $F217
Spac2:
       .byte $00 ; |        | $F236
       .byte $00 ; |        | $F237
       .byte $00 ; |        | $F238
       .byte $00 ; |        | $F229
       .byte $1C ; |   XXX  | $F22A 44
       .byte $3E ; |  XXXXX | $F22B
       .byte $7F ; | XXXXXXX| $F22C
       .byte $1F ; |   XXXXX| $F22D
       .byte $07 ; |     XXX| $F22E
       .byte $1F ; |   XXXXX| $F22F
       .byte $7F ; | XXXXXXX| $F230
       .byte $3E ; |  XXXXX | $F231
       .byte $1C ; |   XXX  | $F232
       .byte $00 ; |        | $F233
       .byte $00 ; |        | $F234
       .byte $00 ; |        | $F235
Spac3:
       .byte $00 ; |        | $F234
       .byte $00 ; |        | $F235
       .byte $00 ; |        | $F236
       .byte $00 ; |        | $F229
       .byte $1C ; |   XXX  | $F22A 33
       .byte $3E ; |  XXXXX | $F22B
       .byte $1F ; |   XXXXX| $F22C
       .byte $0F ; |    XXXX| $F22D
       .byte $07 ; |     XXX| $F22E
       .byte $0F ; |    XXXX| $F22F
       .byte $1F ; |   XXXXX| $F230
       .byte $3E ; |  XXXXX | $F231
       .byte $1C ; |   XXX  | $F232
       .byte $00 ; |        | $F233
       .byte $00 ; |        | $F237
       .byte $00 ; |        | $F239

Lpac1:
       .byte $00 ; |        | $F213
       .byte $18 ; |   XX   | $F214
       .byte $3C ; |  XXXX  | $F215
       .byte $7E ; | XXXXXX | $F207
       .byte $7E ; | XXXXXX | $F208 00
       .byte $FF ; |XXXXXXXX| $F209
       .byte $FF ; |XXXXXXXX| $F20A
       .byte $FF ; |XXXXXXXX| $F20B
       .byte $FF ; |XXXXXXXX| $F20C
       .byte $FF ; |XXXXXXXX| $F20D
       .byte $FF ; |XXXXXXXX| $F20E
       .byte $FF ; |XXXXXXXX| $F20F
       .byte $7E ; | XXXXXX | $F210
       .byte $7E ; | XXXXXX | $F211
       .byte $3C ; |  XXXX  | $F216
       .byte $18 ; |   XX   | $F217

Lpac2:
       .byte $00 ; |        | $F213
       .byte $18 ; |   XX   | $F214
       .byte $3C ; |  XXXX  | $F215
       .byte $7E ; | XXXXXX | $F207
       .byte $FF ; | XXXXXX | $F208 00
       .byte $FF ; |XXXXXXXX| $F209
       .byte $FF ; |XXXXXXXX| $F20A
       .byte $FE ; |XXXXXXX | $F20B
       .byte $F8 ; |XXXXX   | $F20C
       .byte $FE ; |XXXXXXX | $F20D
       .byte $FF ; |XXXXXXXX| $F20E
       .byte $FF ; |XXXXXXXX| $F20F
       .byte $7E ; | XXXXXX | $F210
       .byte $7E ; | XXXXXX | $F211
       .byte $3C ; |  XXXX  | $F216
       .byte $18 ; |   XX   | $F217

Lpac3:
       .byte $00 ; |        | $F213
       .byte $18 ; |   XX   | $F214
       .byte $3C ; |  XXXX  | $F215
       .byte $7E ; | XXXXXX | $F207
       .byte $7E ; | XXXXXX | $F208 00
       .byte $FF ; |XXXXXXXX| $F209
       .byte $FC ; |XXXXXX  | $F20A
       .byte $F0 ; |XXXX    | $F20B
       .byte $E0 ; |XXX     | $F20C
       .byte $F0 ; |XXXX    | $F20D
       .byte $FC ; |XXXXXX  | $F20E
       .byte $FF ; |XXXXXXXX| $F20F
       .byte $7E ; | XXXXXX | $F210
       .byte $7E ; | XXXXXX | $F211
       .byte $3C ; |  XXXX  | $F216
       .byte $18 ; |   XX   | $F217

ExitLo:
       .byte <LFAA2, <LLFAA2, <MLFAA2, <MLFAA2

ExitHi:
       .byte >LFAA2, >LLFAA2, >MLFAA2, >MLFAA2

;bit pattern of left half
Left_Bit_PatternTab:
       .byte $80 ; |X       | $F2EC
       .byte $40 ; | X      | $F2ED
       .byte $10 ; |   X    | $F2EE
       .byte $04 ; |     X  | $F2EF
       .byte $01 ; |       X| $F2F0
       .byte $02 ; |      X | $F2F1
       .byte $08 ; |    X   | $F2F2
       .byte $20 ; |  X     | $F2F2

SpacO:
       .byte <Spac1, <Spac2, <Spac3, <Spac2

LpacO:
       .byte <Lpac1, <Lpac2, <Lpac3, <Lpac2

;02=blue(last)
;08=red
;20=pink
;80=orange
Monster_xor:
       .byte $08,$20,$80,$02

EnergizerVtab:
       .byte $01 ; |       X| $F398
       .byte $0F ; |    XXXX| $F399
       .byte $16 ; |   X XX | $F39A
       .byte $24 ; |  X  X  | $F39B

  ORG $2E00
  RORG $FE00

CH1:
       .byte $1F
       .byte $00
       .byte $00
       .byte $14
       .byte $1F
       .byte $00
       .byte $00
       .byte $14

       .byte $1E
       .byte $00
       .byte $00
       .byte $13
       .byte $1E
       .byte $00
       .byte $00
       .byte $13

       .byte $1F
       .byte $00
       .byte $00
       .byte $14
       .byte $1F
       .byte $00
       .byte $00
       .byte $14

       .byte $15
       .byte $00
       .byte $12
       .byte $00
       .byte $10
       .byte $00
       .byte $0F
       .byte $FF

;digit GFX (numbers 0-9)
;rom addresses saved to $C0,y (low byte)...$C1,y holds value $FF (routine LF7A4)
;all must be on same page
DigitTab_low:
       .byte <Digit0tab ;0200 |X X    X| A1
       .byte <Digit1tab ;0201 |X X  XXX| A7
       .byte <Digit2tab ;0202 |X X XX X| AD
       .byte <Digit3tab ;0203 |X XX  XX| B3
       .byte <Digit4tab ;0204 |X XXX  X| B9
       .byte <Digit5tab ;0205 |X XXXXXX| BF
       .byte <Digit6tab ;0206 |XX   X X| C5
       .byte <Digit7tab ;0207 |XX  X XX| CB
       .byte <Digit8tab ;0208 |XX X   X| D1
       .byte <Digit9tab ;0209 |XX X XXX| D7

LetterTab:
       .byte <DigZ ;ffc8
       .byte <DigP ;ffc9
       .byte <DigU ;ffca
       .byte <DigC ;ffcb
       .byte <DigK ;ffcc
       .byte <DigB ;ffcd

Deathsound:
       .byte $01
Pacstart:
       .byte $22
       .byte $03
       .byte $02
       .byte $03
       .byte $04
       .byte $03
       .byte $04
       .byte $05
       .byte $44
       .byte $05
       .byte $06
       .byte $05
       .byte $06
       .byte $07
       .byte $06
       .byte $07
       .byte $08
       .byte $07
       .byte $08
       .byte $09
       .byte $08
       .byte $09
       .byte $0A
       .byte $09
       .byte $0A
       .byte $0B
       .byte $0A
       .byte $0B
       .byte $0C
       .byte $0B
       .byte $0C
       .byte $0D
       .byte $0C
       .byte $0D
       .byte $0E
       .byte $0D
       .byte $0E
       .byte $0F
       .byte $0E
       .byte $0F
       .byte $10
       .byte $0F
       .byte $10
       .byte $11
       .byte $10
       .byte $11
       .byte $12
       .byte $11
       .byte $12
       .byte $00
       .byte $1F
       .byte $00
;movement rules...bits 0000durl...8 bytes per row of dots
MazeMapTab2:
       .byte $AA ;0100 |    X X |(shared w/above)
       .byte $3B ;0101 |    X XX|
       .byte $3B ;0102 |    X XX|
       .byte $BB ;0103 |    X XX|
       .byte $3B ;0104 |    X XX|
       .byte $3B ;0105 |    X XX|
       .byte $3B ;0106 |    X XX|
       .byte $9F ;0107 |    XXXX|<-tunnel
;MazeRow03:                     ;
       .byte $EF ;0108 |    XXXX|
       .byte $3F ;0109 |    XXXX|
       .byte $3F ;010a |    XXXX|
       .byte $FF ;010b |    XXXX|
       .byte $3F ;010c |    XXXX|
       .byte $BF ;010d |    XXXX|
       .byte $3F ;010e |    XXXX|
       .byte $7F ;010f |    XXXX|
;MazeRow05:                     ;
       .byte $66 ;0110 |     XX |
       .byte $3F ;0111 |    XXXX|
       .byte $3F ;0112 |    XXXX|
       .byte $DF ;0113 |    XXXX|
       .byte $0F ;0114 |    XXXX|
       .byte $6F ;0115 |    XXXX|
       .byte $3F ;0116 |    XXXX|
       .byte $9F ;0117 |    XXXX|
;MazeRow07:                     ;
       .byte $00 ;0118 |        |
       .byte $0E ;0119 |    XXX |
       .byte $0F ;011a |    XXXX|
       .byte $CF ;011b |    XXXX|
       .byte $0F ;011c |    XXXX|
       .byte $AF ;011d |    XXXX|
       .byte $37 ;011e |     XXX|
       .byte $77 ;011f |     XXX| <- below S-channels, remove bit 2 if lethal....
;MazeRow09:                     ;
       .byte $00 ;0118 |        |
       .byte $0E ;0119 |    XXX |
       .byte $0F ;011a |    XXXX|
       .byte $CF ;011b |    XXXX|
       .byte $0F ;011c |    XXXX|
       .byte $CD ;011d |    XX X|
       .byte $00 ;011e |        |
       .byte $AA ;011f |    X X |<-circle in box
;MazeRowX1:                     ;
       .byte $33 ;0120 |      XX|
       .byte $3F ;0121 |    XXXX|
       .byte $3F ;0122 |    XXXX|
       .byte $FF ;0123 |    XXXX| <- tunnel intersection
       .byte $3F ;0124 |    XXXX|
       .byte $DD ;0125 |    XX X| <- beside the box, remove bit zero if eyes
       .byte $00 ;0126 |        |
       .byte $66 ;0127 |     XX |<-circle in box
;MazeRow11:                     ;
       .byte $00 ;0128 |        |
       .byte $0E ;0129 |    XXX |
       .byte $0F ;012a |    XXXX|
       .byte $CF ;012b |    XXXX|
       .byte $0F ;012c |    XXXX|
       .byte $EF ;012d |    XXXX|
       .byte $3B ;012e |    X XX|
       .byte $3B ;012f |    X XX|
;MazeRow13:                     ;
       .byte $AA ;0130 |    X X |
       .byte $3F ;0131 |    XXXX|
       .byte $3F ;0132 |    XXXX|
       .byte $FF ;0133 |    XXXX|
       .byte $3F ;0134 |    XXXX|
       .byte $7F ;0135 |    XXXX|
       .byte $3F ;0136 |    XXXX|
       .byte $9F ;0137 |    XXXX|
;MazeRow15:                     ;
       .byte $66 ;0138 |     XX |
       .byte $9F ;0139 |    XXXX|
       .byte $0F ;013a |    XXXX|
       .byte $EF ;013b |    XXXX|
       .byte $3F ;013c |    XXXX|
       .byte $BF ;013d |    XXXX|
       .byte $3F ;013e |    XXXX|
       .byte $7F ;013f |    XXXX|
;MazeRow17:                     ;
       .byte $AB ;0140 |    X XX|
       .byte $7F ;0141 |    XXXX|
       .byte $3F ;0142 |    XXXX|
       .byte $5F ;0143 |    XXXX|
       .byte $07 ;0144 |     XXX|
       .byte $67 ;0145 |     XXX|
       .byte $37 ;0146 |     XXX|
       .byte $9F ;0147 |    XXXX|
;MazeRow19:                     ;
       .byte $66 ;0148 |     XX |
       .byte $37 ;0149 |    XXXX|
       .byte $37 ;014a |    XXXX|
       .byte $35 ;014b |     X X|
       .byte $30 ;014c |        |
       .byte $30 ;014d |        |
       .byte $30 ;014e |        |
       .byte $7E ;014f |    XXX |

  IF FILLDOT

;dots...left side...bits follow this pattern: 80 40 10 04 01 02 08 20
;loaded into ram from $80 to $AE
DotPattern:
       .byte $FF ;00b4 |XXXXXXXX|80
       .byte $24 ;00b5 |   X   X|81
       .byte $FF ;00b6 |XXXXXXXX|82
       .byte $86 ;00b7 |X  X X  |83
       .byte $FE ;00b8 |XXXX XXX|84
       .byte $24 ;00b9 |   X   X|85
       .byte $2E ;00ba |   X XXX|86
       .byte $06 ;00ba |   X X  |87
       .byte $06 ;00bb |   X X b|88
       .byte $06 ;00bc |   X X o|89
       .byte $57 ;00bd | XXXXX x|8A
       .byte $06 ;00be |   X X  |8B
       .byte $2E ;00bf |   X XXX|8C
       .byte $06 ;00bf |   X X  |8D
       .byte $FF ;00c0 |XXXXXXXX|8E
       .byte $24 ;00c1 |   X   X|8F
       .byte $EF ;00c2 |XX XXXXX|90
       .byte $46 ;00c3 | X X X  |91
       .byte $FE ;00c4 |XXXX XXX|92
       .byte $A0 ;00c5 |X      X|93
       .byte $FF ;00c6 |XXXXXXXX|94
;dots...right side...bits follow this pattern: 40 80 20 08 02 01 04 10
       .byte $FF ;00c7 |XXXXXXXX|95
       .byte $42 ;00c8 |X   X   |96
       .byte $FF ;00c9 |XXXXXXXX|97
       .byte $32 ;00ca |  X X  X|98
       .byte $F7 ;00cb |XXX XXXX|99
       .byte $42 ;00cc |X   X   |9A
       .byte $E2 ;00cd |XXX X   |9B
       .byte $22 ;00cd |  X X   |9C
       .byte $22 ;00ce |b X X   |9D
       .byte $22 ;00cf |o X X   |9E
       .byte $2F ;00d0 |x XXXXX |9F
       .byte $22 ;00d1 |  X X   |A0
       .byte $E2 ;00d1 |XXX X   |A1
       .byte $22 ;00d2 |  X X   |A2
       .byte $FF ;00d3 |XXXXXXXX|A3
       .byte $42 ;00d4 |X   X   |A4
       .byte $FE ;00d5 |XXXXX XX|A5
       .byte $26 ;00d6 |  X X X |A6
       .byte $F7 ;00d7 |XXX XXXX|A7
       .byte $50 ;00d8 |X      X|A8
       .byte $FF ;00d9 |XXXXXXXX|A9

    ELSE

;dots...left side...bits follow this pattern: 80 40 10 04 01 02 08 20
;loaded into ram from $80 to $AE
DotPattern:
       .byte $FF ;00b4 |XXXXXXXX|80
       .byte $24 ;00b5 |   X   X|81
       .byte $FF ;00b6 |XXXXXXXX|82
       .byte $86 ;00b7 |X  X X  |83
       .byte $FE ;00b8 |XXXX XXX|84
       .byte $24 ;00b9 |   X   X|85
       .byte $04 ;00ba |   X    |86
       .byte $04 ;00ba |   X    |87
       .byte $04 ;00bb |   X   b|88
       .byte $04 ;00bc |   X   o|89
       .byte $04 ;00bd |   X   x|8A
       .byte $04 ;00be |   X    |8B
       .byte $04 ;00bf |   X    |8C
       .byte $04 ;00bf |   X    |8D
       .byte $FF ;00c0 |XXXXXXXX|8E
       .byte $24 ;00c1 |   X   X|8F
       .byte $EF ;00c2 |XX XXXXX|90
       .byte $46 ;00c3 | X X X  |91
       .byte $FE ;00c4 |XXXX XXX|92
       .byte $A0 ;00c5 |X      X|93
       .byte $FF ;00c6 |XXXXXXXX|94
;dots...right side...bits follow this pattern: 40 80 20 08 02 01 04 10
       .byte $FF ;00c7 |XXXXXXXX|95
       .byte $42 ;00c8 |X   X   |96
       .byte $FF ;00c9 |XXXXXXXX|97
       .byte $32 ;00ca |  X X  X|98
       .byte $F7 ;00cb |XXX XXXX|99
       .byte $42 ;00cc |X   X   |9A
       .byte $02 ;00cd |    X   |9B
       .byte $02 ;00cd |    X   |9C
       .byte $02 ;00ce |b   X   |9D
       .byte $02 ;00cf |o   X   |9E
       .byte $02 ;00d0 |x   X   |9F
       .byte $02 ;00d1 |    X   |A0
       .byte $02 ;00d1 |    X   |A1
       .byte $02 ;00d2 |    X   |A2
       .byte $FF ;00d3 |XXXXXXXX|A3
       .byte $42 ;00d4 |X   X   |A4
       .byte $FE ;00d5 |XXXXX XX|A5
       .byte $26 ;00d6 |  X X X |A6
       .byte $F7 ;00d7 |XXX XXXX|A7
       .byte $50 ;00d8 |X      X|A8
       .byte $FF ;00d9 |XXXXXXXX|A9

  ENDIF

;u/l energizer column
       .byte $80 ;00da |X       |AA
;l/l energizer column
       .byte $80 ;00db |X       |AB
;u/r energizer column
       .byte $10 ;00dc |   X    |AC
;l/r energizer column
       .byte $10 ;00dd |   X    |AD
       .byte $B4 ;00de |X XX X  |AE


Dir_bit_tab2:
       .byte $04 ; |     X  | $F3A4
       .byte $02 ; |      X | $F3A5
       .byte $08 ; |    X   | $F3A6
       .byte $01 ; |       X| $F398

BoxPos2:
       .byte $32,$45,$50,$50

BoxPos:
       .byte $42,$42,$38,$4C

Dir_test_tab1:
       .byte $04 ; |     X  | $F3A8
       .byte $01 ; |       X| $F3A9
       .byte $08 ; |    X   | $F3AA
;bonus points awarded per monster/10
MonsterBonusTab:
       .byte $02 ;ffd1 |      X | (200)
       .byte $04 ;ffd2 |     X  | (400)
       .byte $08 ;ffd3 |    X   | (800)
       .byte $16 ;ffd4 |   X XX | (1600)
       .byte $32 ;ffd5 |  XX  X | (3200)

  ORG $2F00
  RORG $FF00

;movement rules...bits 0000durl...8 bytes per row of dots
MazeMapTab1:
       .byte $AA ;0100 |    X X |
       .byte $33 ;0101 |      XX|
       .byte $33 ;0102 |      XX|
       .byte $BB ;0103 |    X XX|
       .byte $33 ;0104 |      XX|
       .byte $33 ;0105 |      XX|
       .byte $33 ;0106 |      XX|
       .byte $9B ;0107 |    X XX|
;MazeRow03:                     |
       .byte $EF ;0108 |    XXXX|
       .byte $33 ;0109 |      XX|
       .byte $33 ;010a |      XX|
       .byte $FF ;010b |    XXXX|
       .byte $33 ;010c |      XX|
       .byte $BB ;010d |    X XX|
       .byte $33 ;010e |      XX|
       .byte $75 ;010f |     X X|
;MazeRow05:                     ;
       .byte $66 ;0110 |     XX |
       .byte $3B ;0111 |    X XX|
       .byte $33 ;0112 |      XX|
       .byte $DD ;0113 |    XX X|
       .byte $00 ;0114 |        |
       .byte $66 ;0115 |     XX |
       .byte $33 ;0116 |      XX|
       .byte $99 ;0117 |    X  X|
;MazeRow07:                     ;
       .byte $00 ;0118 |        |
       .byte $0C ;0119 |    XX  |
       .byte $00 ;011a |        |
       .byte $CC ;011b |    XX  |
       .byte $00 ;011c |        |
       .byte $AA ;011d |    X X |
       .byte $33 ;011e |      XX|
       .byte $77 ;011f |     XXX| <- below S-channels, remove bit 2 if lethal
;MazeRow09:                     ;
       .byte $00 ;0118 |        |
       .byte $0E ;0119 |    XXX |
       .byte $03 ;011a |      XX|
       .byte $CF ;011b |    XXXX|
       .byte $03 ;011c |      XX|
       .byte $CD ;011d |    XX X|
       .byte $00 ;011e |        |
       .byte $AA ;011f |    X X |<-circle in box
;MazeRowX1:                     ;
       .byte $33 ;0120 |      XX|
       .byte $3D ;0121 |    XX X|
       .byte $30 ;0122 |        |
       .byte $FE ;0123 |    XXX | <- tunnel intersection
       .byte $33 ;0124 |      XX|
       .byte $DD ;0125 |    XX X| <- beside the box, remove bit zero if eyes
       .byte $00 ;0126 |        |
       .byte $66 ;0127 |     XX |<-circle in box
;MazeRow11:
       .byte $00 ;0128 |        |
       .byte $0C ;0129 |    XX  |
       .byte $00 ;012a |        |
       .byte $CC ;012b |    XX  |
       .byte $00 ;012c |        |
       .byte $E6 ;012d |     XX |
       .byte $33 ;012e |      XX|
       .byte $3B ;012f |    X XX|
;MazeRow13:
       .byte $AA ;0130 |    X X |
       .byte $37 ;0131 |     XXX|
       .byte $33 ;0132 |      XX|
       .byte $FF ;0133 |    XXXX|
       .byte $33 ;0134 |      XX|
       .byte $73 ;0135 |      XX|
       .byte $33 ;0136 |      XX|
       .byte $9D ;0137 |    XX X|
;MazeRow15:
       .byte $66 ;0138 |     XX |
       .byte $99 ;0139 |    X  X|
       .byte $00 ;013a |        |
       .byte $EE ;013b |    XXX |
       .byte $33 ;013c |      XX|
       .byte $BB ;013d |    X XX|
       .byte $33 ;013e |      XX|
       .byte $77 ;013f |     XXX|
;MazeRow17:                     ;
       .byte $AB ;0140 |    X XX|
       .byte $77 ;0141 |     XXX|
       .byte $33 ;0142 |      XX|
       .byte $5D ;0143 |    XX X|
       .byte $00 ;0144 |        |
       .byte $6E ;0145 |    XXX |
       .byte $33 ;0146 |      XX|
       .byte $99 ;0147 |    X  X|
;MazeRow19:                     ;
       .byte $66 ;0148 |     XX |
       .byte $33 ;0149 |      XX|
       .byte $33 ;014a |      XX|
       .byte $37 ;014b |     XXX|
       .byte $33 ;014c |      XX|
       .byte $37 ;014d |     XXX|
       .byte $33 ;014e |      XX|
       .byte $77 ;014f |     XXX|

Title1:
       .byte %00000000
       .byte %00000000
       .byte %00000000
       .byte %00000000
       .byte %00000100
       .byte %00000000
       .byte %00000000
       .byte %01100100
       .byte %01100100
       .byte %01111100
       .byte %01100100
       .byte %01100100
Title2:
       .byte %00111110
       .byte %00000110
       .byte %00011110
       .byte %00000110
       .byte %00111110
       .byte %00000000
       .byte %00000000
       .byte %00111110
       .byte %00110100
       .byte %00111000
       .byte %00110000
       .byte %00100000
Title4:
       .byte %00000000
       .byte %00000000
       .byte %00000000
       .byte %00000000
       .byte %00000000
       .byte %00000000
       .byte %00000000
       .byte %00100110
       .byte %00010110
       .byte %00001110
       .byte %00010110
       .byte %00100110
Title5:
       .byte %01111111
       .byte %01111111
       .byte %01110111
       .byte %01100011
       .byte %01000001
       .byte %00000000
       .byte %00000000
       .byte %00111000
       .byte %01111100
       .byte %01100000
       .byte %01111100
       .byte %00111000

SirenData:
       .byte $1B ;0108 |    XXX |
       .byte $1B ;0109 |      XX|
       .byte $1B ;010a |      XX|
       .byte $1B ;010b |    XXXX|
       .byte $1C ;010c |      XX|
       .byte $1C ;010d |    X XX|
       .byte $1C ;010e |      XX|
       .byte $1C ;010f |     XXX|
       .byte $1D ;0110 |     XX |
       .byte $1D ;0111 |      XX|
       .byte $1D ;0112 |      XX|
       .byte $1D ;0113 |    XX X|
       .byte $1E ;0114 |        |
       .byte $1E ;0115 |     XX |
       .byte $1E ;0116 |      XX|
       .byte $1E ;0117 |    X  X|
       .byte $1F ;0118 |        |
       .byte $1F ;0119 |        |
       .byte $1F ;011a |        |
       .byte $1F ;011b |    XX  |
       .byte $1E ;011c |        |
       .byte $1E ;011d |    X X |
       .byte $1E ;011e |      XX|
       .byte $1E ;011f |     XXX|
       .byte $1D ;0118 |        |
       .byte $1D ;0119 |        |
       .byte $1D ;011a |        |
       .byte $1D ;011b |    XX  |
       .byte $1C ;011c |        |
       .byte $1C ;011d |    XX  |
       .byte $1C ;011e |        |
       .byte $1C ;011f |    X X |



;54
;blue time table...#sec. blue/#sec.white
;00   -no effect-
;01  0 sec./flicker
;02  0 sec./ 1 sec.
;03  0 sec./ 2 sec.
;04  0 sec./2.5sec.
;05 flicker/ 3 sec.
;06  1 sec./ 3 sec.
;07  2 sec./ 3 sec.
;08  3 sec./ 3 sec.
;09  4 sec./ 3 sec.
;0A 4.5sec./ 3 sec.
;0B  5 sec./ 3 sec.
;0C 5.5sec./ 3 sec.
;0D  6 sec./ 3 sec.
;0E  7 sec./ 3 sec.
;0F  8 sec./ 3 sec.
BlueTimeTab:
       .byte $0F ;ff4a |XXX     |...................................
       .byte $0E ;ff4b |  X     |                                  |
       .byte $0D ;ff4c |  X     |                                  |
       .byte $0C ;ff4d |  X     |                                  |
       .byte $09 ;ff4e |  X     |                                  |
       .byte $0F ;ff4f |  X     |                                  |
       .byte $09 ;ff50 |XXX     |                                  |
       .byte $07 ;fd63 |        |                                  |
       .byte $05 ;fd63 |        |                                  |
       .byte $0F ;ff51 |        |                      (Bluetime, lower nybble)
       .byte $06 ;ff52 |        |                                  |
       .byte $04 ;ff53 |        |                                  |
       .byte $03 ;ff54 |XXX     |                                  |
       .byte $06 ;ff55 |        |                                  |
       .byte $01 ;ff56 |  X     |                                  |
       .byte $04 ;ff57 |  X     |                                  |
       .byte $00 ;003c |  X     |(shared)                          |
       .byte $00 ;003d |  X     |(shared)                          |
       .byte $00 ;003e |  X     |(shared)                          |

SoundFreqTab:                   ;                                  |
       .byte $00 ;003f |  X     |(shared)...................................
       .byte $1E ;0040 |  X     |(shared)                                  |
       .byte $18 ;0041 |  X     |(shared)                                  |
       .byte $14 ;0042 |        |                                          |
       .byte $06 ;fd63 |        |                                          |
       .byte $06 ;fd63 |        |                                          |
       .byte $08 ;0043 |        |                                          |
       .byte $0A ;0044 |        |                                          |
       .byte $0C ;0045 |        |                                          |
       .byte $0E ;0046 |        |                          (sound effects data, lower nybble)
       .byte $10 ;0047 |        |                                          |
       .byte $12 ;0048 |  X     |                                          |
       .byte $14 ;0049 |  X     |                                          |
       .byte $16 ;0078 |  X     |(shared)                                  |
       .byte $18 ;0079 |  X     |(shared)                                  |
       .byte $1A ;007a |  X     |(shared)                                  |
       .byte $1C ;007b |  X     |(shared)                                  |
       .byte $1A ;007c |  X     |(shared)                                  |
       .byte $18 ;007d |  X     |(shared)                                  |
       .byte $16 ;0080 |        |                                          |
       .byte $14 ;0080 |        |                                          |
       .byte $12 ;007e |        |                                          |
       .byte $10 ;007f |XXX     |                                          |
       .byte $0E ;0080 |        |                                          |
       .byte $0C ;0081 |        |                                          |
       .byte $0C ;0082 |        |...........................................

DirBitTestTab:
       .byte $10 ; |   X    | $F2E8
       .byte $80 ; |X       | $F2E9
       .byte $20 ; |  X     | $F2EA
;bit pattern of right half
Right_Bit_PatternTab:
       .byte $40 ; | X      | $F2F4
       .byte $80 ; |X       | $F2F5
       .byte $20 ; |  X     | $F2F6
       .byte $08 ; |    X   | $F2F7
       .byte $02 ; |      X | $F2F8
       .byte $01 ; |       X| $F2F9
       .byte $04 ; |     X  | $F2FA
       .byte $10 ; |   X    | $F2FB

;points=(decimal value)x10+10
FruitPoints:
       .byte $01 ;037d |    X  X| Cherries
       .byte $03 ;037e |   XXX X| Strawberry
       .byte $05 ;037f |  XX   X| Orange1
       .byte $05 ;0380 |  XX   X| Orange2
       .byte $07 ;0381 | X   X X| Apple1
       .byte $07 ;0382 | X   X X| Apple2
       .byte $10 ;0383 | XX   XX| Grapes1
       .byte $10 ;0384 | XX   XX| Grapes2
       .byte $20 ;0385 |X  X X X| Lime1
       .byte $20 ;0386 |X  X X X| Lime2
       .byte $30 ;0387 |XX   XXX| Grapefruit1
       .byte $30 ;0388 |XX   XXX| Grapefruit2
       .byte $50 ;0389 |XXXXX  X| Crabapple1
       .byte $50 ;038a |XXXXX  X| Crabapple2
       .byte $50 ;038b |XXXXX  X| Crabapple3
       .byte $50 ;038c |XXXXX  X| Crabapple4
       .byte $50 ;038d |XXXXX  X| Crabapple5+
       .byte $50 ;038d |XXXXX  X| Crabapple5+

Bit_chk_5:
       .byte $00 ; |        | $F392
       .byte $FF ; |XXXXXXXX| $F393
       .byte $00 ; |        | $F394
       .byte $01 ; |       X| $F395
       .byte $00 ; |        | $F396
       .byte $FF ; |XXXXXXXX| $F393


  ORG $2FF8
  RORG $FFF8

       .byte $00 ; |        | $F28D
       .byte $00 ; |        | $F28E
       .byte $00 ; |        | $F28D
       .byte $00 ; |        | $F28E
       .word START
       .byte $00 ; |        | $F28D
       .byte $00 ; |        | $F28E

